#include "nest-refs-client.h"
#include "nest-refs-server.h"

static const CORBA::Long _oc_OctetSequence[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    22, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x4f637465), ACE_NTOHL(0x74536571), ACE_NTOHL(0x75656e63), ACE_NTOHL(0x653a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:OctetSequence:1.0 */,
    14, ACE_NTOHL(0x4f637465), ACE_NTOHL(0x74536571), ACE_NTOHL(0x75656e63), ACE_NTOHL(0x65000000) /* name = OctetSequence */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_octet,
      0
};

static CORBA::TypeCode _tc_TAO_tc_OctetSequence (CORBA::tk_alias, sizeof(_oc_OctetSequence), (char *) &_oc_OctetSequence, 0, sizeof(OctetSequence ));

CORBA::TypeCode_ptr _tc_OctetSequence = &_tc_TAO_tc_OctetSequence;

OctetSequence::OctetSequence()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

OctetSequence::OctetSequence(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = OctetSequence::allocbuf(this->_maximum);
}

OctetSequence::OctetSequence(CORBA::ULong max, CORBA::ULong length, CORBA::Octet *buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

OctetSequence::OctetSequence(const OctetSequence &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  CORBA::Octet  *tmp1 = OctetSequence::allocbuf(this->_maximum);
  
  CORBA::Octet  * const tmp2 = ACE_reinterpret_cast(CORBA::Octet  * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  
  this->_buffer = tmp1;
}

OctetSequence::~OctetSequence()
{
  this->_deallocate_buffer();
}

OctetSequence &OctetSequence::operator=(const OctetSequence &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      CORBA::Octet  *tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
      
      OctetSequence::freebuf(tmp);
      this->_buffer = OctetSequence::allocbuf(rhs._maximum);
    }
  
  }
  else
    this->_buffer = OctetSequence::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Octet  *tmp1 = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  CORBA::Octet  * const tmp2 = ACE_reinterpret_cast(CORBA::Octet  * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  return *this;
}

CORBA::Octet &OctetSequence::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Octet  * tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  return tmp[i];
}

const CORBA::Octet &OctetSequence::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Octet  * const tmp = ACE_reinterpret_cast(CORBA::Octet  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Octet *OctetSequence::allocbuf(CORBA::ULong size)
{
  CORBA::Octet  *tmp;
  tmp = new CORBA::Octet [size];
  return tmp;
}

void OctetSequence::freebuf(CORBA::Octet *buffer)
{
  delete [] buffer;
}

void OctetSequence::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Octet  *tmp = OctetSequence::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Octet  *old = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      OctetSequence::freebuf(old);
  }
  this->_buffer = tmp;
}

void OctetSequence::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  CORBA::Octet  *tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  
  OctetSequence::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean OctetSequence::release() const
{
  return this->_release;
}

CORBA::ULong OctetSequence::maximum() const
{
  return this->_maximum;
}

CORBA::ULong OctetSequence::length() const
{
  return this->_length;
}

void OctetSequence::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void OctetSequence::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
}

CORBA::Octet *OctetSequence::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Octet  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = OctetSequence::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Octet *OctetSequence::get_buffer() const
{
  return ACE_const_cast(const CORBA::Octet  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const OctetSequence &o)
{
  OctetSequence  *_any_val;
  ACE_NEW(_any_val, OctetSequence  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_OctetSequence, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, OctetSequence *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_OctetSequence, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, OctetSequence *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_OctetSequence, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (OctetSequence  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, OctetSequence , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_OctetSequence, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_OctetSequence, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

OctetSequence_var::OctetSequence_var()
  : ptr_(0)
{}

OctetSequence_var::OctetSequence_var(OctetSequence *p)
 : ptr_(p)
{}

OctetSequence_var::OctetSequence_var(const OctetSequence_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new OctetSequence (*a.ptr_);
  else
    this->ptr_ = 0;
}

OctetSequence_var::~OctetSequence_var()
{
  delete this->ptr_;
}

OctetSequence_var &OctetSequence_var::operator=(OctetSequence *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

OctetSequence_var &OctetSequence_var::operator=(const OctetSequence_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new OctetSequence (*p.ptr_);
  }
  return *this;
}

CORBA::Octet &OctetSequence_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Octet &OctetSequence_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

OctetSequence *OctetSequence_var::operator->()
{
  return this->ptr_;
}

const OctetSequence *OctetSequence_var::operator->() const
{
  return this->ptr_;
}

OctetSequence_var::operator const OctetSequence &() const
{
  return *this->ptr_;
}

OctetSequence_var::operator OctetSequence &()
{
  return *this->ptr_;
}

OctetSequence_var::operator OctetSequence &() const
{
  return *this->ptr_;
}

const OctetSequence &OctetSequence_var::in() const
{
  return *this->ptr_;
}

OctetSequence &OctetSequence_var::inout()
{
  return *this->ptr_;
}

OctetSequence *&OctetSequence_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

OctetSequence *OctetSequence_var::_retn()
{
  OctetSequence  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

OctetSequence *OctetSequence_var::ptr() const
{
  return this->ptr_;
}

OctetSequence_out::OctetSequence_out(OctetSequence *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

OctetSequence_out::OctetSequence_out(OctetSequence_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

OctetSequence_out::OctetSequence_out(const OctetSequence_out &r)
  : ptr_(ACE_const_cast(OctetSequence_out &,r).ptr_)
{}

OctetSequence_out &OctetSequence_out::operator=(const OctetSequence_out &r)
{
  this->ptr_ = ACE_const_cast(OctetSequence_out &,r).ptr_;
  return *this;
}

OctetSequence_out &OctetSequence_out::operator=(OctetSequence *r)
{
  this->ptr_ = r;
  return *this;
}

OctetSequence_out::operator OctetSequence *&()
{
  return this->ptr_;
}

OctetSequence *&OctetSequence_out::ptr()
{
  return this->ptr_;
}

CORBA::Octet &OctetSequence_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Octet &OctetSequence_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

OctetSequence *OctetSequence_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_test[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    13, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x74657374), ACE_NTOHL(0x3a312e30), ACE_NTOHL(0x00000000) /* repository ID = IDL:test:1.0 */,
    5, ACE_NTOHL(0x74657374), ACE_NTOHL(0x00000000) /* name = test */
};

static CORBA::TypeCode _tc_TAO_tc_test (CORBA::tk_objref, sizeof(_oc_test), (char *) &_oc_test, 0, sizeof(test ));

CORBA::TypeCode_ptr _tc_test = &_tc_TAO_tc_test;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<test >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<test >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

test_ptr test::_duplicate(test_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

test_ptr test::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return test::_nil();
  if( !obj->_is_a("IDL:test:1.0", _env) )
    return test::_nil();
  return test::_unchecked_narrow(obj, _env);
}

test_ptr test::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(_obj) )
    return test::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (_obj->_is_collocated () && _obj->_servant() != 0)
    servant = _obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new test (stub);
  return new _tao_collocated_test(
      ACE_reinterpret_cast(POA_test_ptr , servant),
      stub
    );
}

test_ptr test::_nil()
{
  return (test_ptr )NULL;
}

CORBA::Boolean test::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:test:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *test::_interface_repository_id() const
{
  return "IDL:test:1.0";
}

test::test()
{}

test::~test()
{}

void operator<<=(CORBA::Any &a, test_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = test::_duplicate(o);
    a.replace (_tc_test, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, test_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = test::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_test, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_test, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = test::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_test, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

test::test(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

test_var::test_var()
  : ptr_(test::_nil())
{}

test_var::test_var(test_ptr p)
  : ptr_(p)
{}

test_var::test_var(const test_var &a)
  : ptr_(test::_duplicate(a.ptr()))
{}

test_var::~test_var()
{
  CORBA::release(this->ptr_);
}

test_var &test_var::operator=(test_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

test_var &test_var::operator=(const test_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = test::_duplicate(p.ptr());
  }
  return *this;
}

test_ptr test_var::operator->() const
{
  return this->ptr_;
}

test_var::operator const test_ptr &() const
{
  return this->ptr_;
}

test_var::operator test_ptr &()
{
  return this->ptr_;
}

test_ptr test_var::in() const
{
  return this->ptr_;
}

test_ptr &test_var::inout()
{
  return this->ptr_;
}

test_ptr &test_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = test::_nil();
  return this->ptr_;
}

test_ptr test_var::_retn()
{
  test_ptr  val = this->ptr_;
  this->ptr_ = test::_nil();
  return val;
}

test_ptr test_var::ptr() const
{
  return this->ptr_;
}

test_out::test_out(test_ptr &r)
  : ptr_(r)
{
  this->ptr_ = test::_nil();
}

test_out::test_out(test_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = test::_nil();
}

test_out::test_out(const test_out &r)
  : ptr_(ACE_const_cast(test_out &,r).ptr_)
{}

test_out &test_out::operator=(const test_out &r)
{
  this->ptr_ = ACE_const_cast(test_out &,r).ptr_;
  return *this;
}

test_out &test_out::operator=(const test_var &r)
{
  this->ptr_ = test::_duplicate(r.ptr());
  return *this;
}

test_out &test_out::operator=(test_ptr r)
{
  this->ptr_ = r;
  return *this;
}

test_out::operator test_ptr &()
{
  return this->ptr_;
}

test_ptr &test_out::ptr()
{
  return this->ptr_;
}

test_ptr test_out::operator->()
{
  return this->ptr_;
}

int flick_marshal_stub_OctetSequence(flick_marshal_stream_t _stream, const OctetSequence *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort0);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  flick_iiopxx_encode_new_glob(1 * _data->_length, _flick_abort0);
  flick_iiopxx_encode_new_chunk(1 * _data->_length);
  flick_cdr_encode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_encode_end_chunk(1 * _data->_length);
  flick_iiopxx_encode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort0:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_OctetSequence(flick_marshal_stream_t _stream, OctetSequence *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort3);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort3);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort3);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort3:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_OctetSequence_swap(flick_marshal_stream_t _stream, OctetSequence *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort6);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort6);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort6);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_swap_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort6:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_ReferenceData(flick_marshal_stream_t _stream, const ReferenceData *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort9);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  flick_iiopxx_encode_new_glob(1 * _data->_length, _flick_abort9);
  flick_iiopxx_encode_new_chunk(1 * _data->_length);
  flick_cdr_encode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_encode_end_chunk(1 * _data->_length);
  flick_iiopxx_encode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort9:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_ReferenceData(flick_marshal_stream_t _stream, ReferenceData *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort12);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort12);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort12);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort12:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_ReferenceData_swap(flick_marshal_stream_t _stream, ReferenceData *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort15);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort15);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort15);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_swap_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort15:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_test(flick_marshal_stream_t _stream, const test_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, test , _flick_abort18);
  return 0;
  {
  _flick_abort18:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_test(flick_marshal_stream_t _stream, test_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, test , _flick_abort19);
  return 0;
  {
  _flick_abort19:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_test_swap(flick_marshal_stream_t _stream, test_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, test , _flick_abort20);
  return 0;
  {
  _flick_abort20:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

ReferenceData *test::id(/* test *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ReferenceData *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort22);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort22);
    }
    {
      flick_iiopxx_encode_new_glob(16, _flick_abort22);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort22);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort22);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t1_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort22);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t1_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t1_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (ReferenceData *)new ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort41);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort41);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort41);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort41);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort41:
                goto _flick_abort22;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort44);
              break;
              {
              _flick_abort44:
                goto _flick_abort22;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort45);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort45:
                goto _flick_abort22;
              }
            }
          }
      }
    else
      {
        int _t0_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort22);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t0_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t0_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (ReferenceData *)new ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort30);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort30);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort30);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort30);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort30:
                goto _flick_abort22;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort33);
              break;
              {
              _flick_abort33:
                goto _flick_abort22;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort34);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort34:
                goto _flick_abort22;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort22:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort21);
    _flick_abort21:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void test::id(/* test *this, */ const ReferenceData &id, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort47);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort47);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort47);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(16, id._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_iiopxx_encode_new_glob(1 * id._length, _flick_abort47);
      flick_iiopxx_encode_new_chunk(1 * id._length);
      flick_cdr_encode_bcopy(0, id._buffer, 1 * id._length);
      flick_iiopxx_encode_end_chunk(1 * id._length);
      flick_iiopxx_encode_end_glob(1 * id._length);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort47);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort47);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t3_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort47);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t3_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t3_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort65);
              break;
              {
              _flick_abort65:
                goto _flick_abort47;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort66);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort66:
                goto _flick_abort47;
              }
            }
          }
      }
    else
      {
        int _t2_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort47);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t2_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t2_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort58);
              break;
              {
              _flick_abort58:
                goto _flick_abort47;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort59);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort59:
                goto _flick_abort47;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort47:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort46);
    _flick_abort46:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

OctetSequence *test::info(/* test *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  OctetSequence *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort68);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort68);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort68);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'f', flick_char8_t );
      flick_cdr_encode_char8(12, 'o', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort68);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort68);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t5_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort68);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t5_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t5_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                OctetSequence *_t_alloc_ptr;

                _t_alloc_ptr = (OctetSequence *)new OctetSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort87);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort87);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort87);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort87);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort87:
                goto _flick_abort68;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort90);
              break;
              {
              _flick_abort90:
                goto _flick_abort68;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort91);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort91:
                goto _flick_abort68;
              }
            }
          }
      }
    else
      {
        int _t4_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort68);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t4_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t4_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                OctetSequence *_t_alloc_ptr;

                _t_alloc_ptr = (OctetSequence *)new OctetSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort76);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort76);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort76);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort76);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort76:
                goto _flick_abort68;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort79);
              break;
              {
              _flick_abort79:
                goto _flick_abort68;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort80);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort80:
                goto _flick_abort68;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort68:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort67);
    _flick_abort67:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void test::info(/* test *this, */ const OctetSequence &info, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort93);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort93);
    }
    {
      flick_iiopxx_encode_new_glob(24, _flick_abort93);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'f', flick_char8_t );
      flick_cdr_encode_char8(12, 'o', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, info._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
      flick_iiopxx_encode_new_glob(1 * info._length, _flick_abort93);
      flick_iiopxx_encode_new_chunk(1 * info._length);
      flick_cdr_encode_bcopy(0, info._buffer, 1 * info._length);
      flick_iiopxx_encode_end_chunk(1 * info._length);
      flick_iiopxx_encode_end_glob(1 * info._length);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort93);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort93);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t7_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort93);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t7_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t7_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort111);
              break;
              {
              _flick_abort111:
                goto _flick_abort93;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort112);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort112:
                goto _flick_abort93;
              }
            }
          }
      }
    else
      {
        int _t6_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort93);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t6_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t6_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort104);
              break;
              {
              _flick_abort104:
                goto _flick_abort93;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort105);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort105:
                goto _flick_abort93;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort93:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort92);
    _flick_abort92:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

