#include "recursive-server.h"

POA_obj::POA_obj()
{}

POA_obj::POA_obj(const POA_obj &rhs)
  : TAO_ServantBase(rhs)
{}

POA_obj::~POA_obj()
{}

obj *POA_obj::_this(CORBA::Environment &_env)
{
  TAO_Stub *stub = this->_create_stub(_env);
  TAO_CHECK_ENV_RETURN(_env, 0);
  return new _tao_collocated_obj(this, stub);
}

CORBA::Boolean POA_obj::_is_a(const CORBA::Char *type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)type_id, "IDL:obj:1.0")) ||
      (!ACE_OS::strcmp((char *)type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return 0;
}

void *POA_obj::_downcast(const char *logical_type_id)
{
  if(ACE_OS::strcmp(logical_type_id, "IDL:obj:1.0") == 0)
    return ACE_static_cast(POA_obj_ptr , this);
   
  if(ACE_OS::strcmp(logical_type_id, "IDL:omg.org/CORBA/Object:1.0") == 0)
    return ACE_static_cast(PortableServer::Servant, this);
  return 0;
}

const char *POA_obj::_interface_repository_id() const
{
  return "IDL:obj:1.0";
}

template <class T>
  POA_obj_tie<T>::POA_obj_tie(T &t)
  : ptr_(&t),
    poa_(PortableServer::POA::_nil()),
    rel_(0)
{}

template <class T>
  POA_obj_tie<T>::POA_obj_tie(T &t, PortableServer::POA_ptr poa)
  : ptr_(&t),
    poa_(PortableServer::POA::_duplicate(poa)),
    rel_(0)
{}

template <class T>
  POA_obj_tie<T>::POA_obj_tie(T *t, CORBA::Boolean release)
  : ptr_(&t),
    poa_(PortableServer::POA::_nil()),
    rel_(release)
{}

template <class T>
  POA_obj_tie<T>::POA_obj_tie(T *t, PortableServer::POA_ptr poa, CORBA::Boolean release)
  : ptr_(&t),
    poa_(PortableServer::POA::_duplicate(poa)),
    rel_(release)
{}

template <class T>
  POA_obj_tie<T>::~POA_obj_tie()
{
  if( this->rel_ ) delete this->ptr_;
}

template <class T>
  T *POA_obj_tie<T>::_tied_object()
{
  return this->ptr_;
}

template <class T>
  void POA_obj_tie<T>::_tied_object(T &obj)
{
  if( this->rel_ ) delete this->ptr_;
  this->ptr_ = &obj;
  this->rel_ = 0;
}

template <class T>
  void POA_obj_tie<T>::_tied_object(T &obj, CORBA::Boolean release)
{
  if( this->rel_ ) delete this->ptr_;
  this->ptr_ = obj;
  this->rel_ = release;
}

template <class T>
  CORBA::Boolean POA_obj_tie<T>::_is_owner()
{
  return this->rel_;
}

template <class T>
  void POA_obj_tie<T>::_is_owner(CORBA::Boolean b)
{
  this->rel_ = b;
}

template <class T>
  PortableServer::POA_ptr POA_obj_tie<T>::_default_POA()
{
  if( !(CORBA::is_nil(this->poa_.in())) )
    return PortableServer::POA::_duplicate(this->poa_.in());
  else
  {
    TAO_POA *poa = TAO_ORB_Core_instance()->root_poa();
    PortableServer::POA_var result = poa->_this(env);
    if( env.exception() != 0 )
      return PortableServer::POA::_nil();
    else
      return result._retn();
  }
}

template <class T>
  POA_obj_tie<T>::POA_obj_tie(const POA_obj_tie &c)
{}

template <class T>
  void POA_obj_tie<T>::operator=(const POA_obj_tie &c)
{}

template <class T>
  ::obj::my_obj_ptr POA_obj_tie<T>::get_server(/* POA_obj *this, */ CORBA::Environment &_ev)
{
  return this->ptr_->get_server (_ev);
}

template <class T>
  void POA_obj_tie<T>::set_server(/* POA_obj *this, */ ::obj::my_obj_ptr srvr, CORBA::Environment &_ev)
{
  this->ptr_->set_server (srvr, _ev);
}

template <class T>
  enum tc POA_obj_tie<T>::convert(/* POA_obj *this, */ const struct ta &a1, const struct tb &b1, CORBA::Environment &_ev)
{
  return this->ptr_->convert (a1, b1, _ev);
}

template <class T>
  CORBA::Long POA_obj_tie<T>::my_attr(/* POA_obj *this, */ CORBA::Environment &_ev)
{
  return this->ptr_->my_attr (_ev);
}

template <class T>
  void POA_obj_tie<T>::my_attr(/* POA_obj *this, */ CORBA::Long my_attr, CORBA::Environment &_ev)
{
  this->ptr_->my_attr (my_attr, _ev);
}

_tao_collocated_obj::_tao_collocated_obj(POA_obj_ptr servant, TAO_Stub *stub)
  : obj(),
    CORBA_Object(stub, servant, 1),
    servant_ (servant)
{
}

POA_obj_ptr _tao_collocated_obj::_get_servant() const
{
  return this->servant_;
}

::obj::my_obj_ptr _tao_collocated_obj::get_server(CORBA::Environment &_ev)
{
  return this->servant_->get_server (_ev);
}

void _tao_collocated_obj::set_server(::obj::my_obj_ptr srvr, CORBA::Environment &_ev)
{
  this->servant_->set_server (srvr, _ev);
}

enum tc _tao_collocated_obj::convert(const struct ta &a1, const struct tb &b1, CORBA::Environment &_ev)
{
  return this->servant_->convert (a1, b1, _ev);
}

CORBA::Long _tao_collocated_obj::my_attr(CORBA::Environment &_ev)
{
  return this->servant_->my_attr (_ev);
}

void _tao_collocated_obj::my_attr(CORBA::Long my_attr, CORBA::Environment &_ev)
{
  this->servant_->my_attr (my_attr, _ev);
}

CORBA::Boolean _tao_collocated_obj::_is_a(const char *type_id, CORBA::Environment &_ev)
{
  return this->servant_->_is_a (type_id, _ev);
}

int flick_marshal_stub_obj(flick_marshal_stream_t _stream, obj_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, obj , _flick_abort0);
  return 0;
  {
  _flick_abort0:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_obj(flick_marshal_stream_t _stream, obj_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, obj , _flick_abort1);
  return 0;
  {
  _flick_abort1:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_obj_swap(flick_marshal_stream_t _stream, obj_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, obj , _flick_abort2);
  return 0;
  {
  _flick_abort2:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

void POA_obj::_dispatch(CORBA::ServerRequest &_tao_req, void *_tao_context, CORBA::Environment &_tao_env){
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_InputCDR &_in_cdr = _tao_req.incoming();
  TAO_OutputCDR &_out_cdr = _tao_req.outgoing();
  flick_iiopxx_server_start_decode();
  _stub_state.state = FLICK_STATE_PROLOGUE;
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  if (_in_cdr.do_byte_swap()) {
  {
    unsigned int _t141_switch_tag;

    flick_iiopxx_decode_new_glob(24);
    flick_iiopxx_check_span(16, _flick_abort5);
    flick_iiopxx_decode_new_chunk(4);
    flick_cdr_swap_decode_unsigned32(0, _t141_switch_tag, unsigned int );
    flick_iiopxx_decode_end_chunk(4);
    switch ((unsigned int )_t141_switch_tag)
      {
      case (unsigned int) 11:
        {
          unsigned int _t142_switch_tag;

          flick_iiopxx_check_span(16, _flick_abort5);
          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t142_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t142_switch_tag)
            {
            case /* get_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1734702175):
              {
                unsigned int _t143_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t143_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t143_switch_tag)
                  {
                  case /* serv */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936028278):
                    {
                      unsigned short int _t144_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t144_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t144_switch_tag)
                        {
                        case /* er */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25970):
                          {
                            char _t145_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_swap_decode_char8(0, _t145_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t145_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t146_principal_len;
                                    ::obj::my_obj_ptr _return;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort384);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(5);
                                    flick_cdr_swap_decode_unsigned32(1, _t146_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(5);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t146_principal_len, _flick_abort384);
                                    flick_iiopxx_decode_new_glob(_t146_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t146_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t146_principal_len);
                                    flick_iiopxx_decode_end_glob(_t146_principal_len);
                                    /* Begin decode phase on parameters */
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _return = _local_this->get_server(_ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t147_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t147_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort384);
                                      flick_iiopxx_encode_new_glob(4, _flick_abort384);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t147_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t147_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_cdrxx_encode_IOR(iiopxx, _return, 0, obj , _flick_abort389);
                                            CORBA_object_flick_free(_return);
                                            _return = 0;
                                            break;
                                            {
                                            _flick_abort389:
                                              goto _flick_abort384;
                                            }
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort390);
                                            break;
                                            {
                                            _flick_abort390:
                                              goto _flick_abort384;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort391);
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                            {
                                            _flick_abort391:
                                              goto _flick_abort384;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort384:
                                      goto _flick_abort383;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort383:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            case /* set_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936028767):
              {
                unsigned int _t148_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t148_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t148_switch_tag)
                  {
                  case /* serv */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936028278):
                    {
                      unsigned short int _t149_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t149_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t149_switch_tag)
                        {
                        case /* er */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25970):
                          {
                            char _t150_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_swap_decode_char8(0, _t150_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t150_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t151_principal_len;
                                    ::obj::my_obj_ptr _local_srvr;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort393);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(5);
                                    flick_cdr_swap_decode_unsigned32(1, _t151_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(5);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t151_principal_len, _flick_abort393);
                                    flick_iiopxx_decode_new_glob(_t151_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t151_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t151_principal_len);
                                    flick_iiopxx_decode_end_glob(_t151_principal_len);
                                    /* Begin decode phase on parameters */
                                    flick_cdr_swapxx_decode_IOR(iiopxx, _local_srvr, 1, obj , _flick_abort393);
                                    flick_iiopxx_mark_port_for_cleanup(_local_srvr, 1);
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _local_this->set_server(_local_srvr, _ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t152_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t152_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort393);
                                      flick_iiopxx_encode_new_glob(4, _flick_abort393);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t152_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t152_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort399);
                                            break;
                                            {
                                            _flick_abort399:
                                              goto _flick_abort393;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort400);
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                            {
                                            _flick_abort400:
                                              goto _flick_abort393;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort393:
                                      goto _flick_abort392;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort392:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      case (unsigned int) 8:
        {
          unsigned int _t153_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t153_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t153_switch_tag)
            {
            case /* conv */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1668247158):
              {
                unsigned int _t154_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t154_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t154_switch_tag)
                  {
                  case /* ert */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1701999616):
                    {
                      {
                        POA_obj *_local_this;
                        unsigned int _t155_principal_len;
                        enum tc _return;
                        struct ta _local_a1;
                        flick_unsigned32_t _t156_temp_string_len;
                        CORBA::ULong _t157_array_iter;
                        CORBA::ULong _t158_array_iter;
                        CORBA::ULong _t159_array_iter;
                        flick_unsigned32_t _t160_temp_string_len;
                        CORBA::ULong _t161_array_iter;
                        CORBA::ULong _t162_array_iter;
                        struct tb _local_b1;
                        CORBA::ULong _t163_array_iter;
                        CORBA::ULong _t167_array_iter;
                        CORBA::ULong _t170_array_iter;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort402);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _t155_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(24);
                        flick_iiopxx_check_span(_t155_principal_len, _flick_abort402);
                        flick_iiopxx_decode_new_glob(_t155_principal_len);
                        flick_iiopxx_decode_new_chunk(_t155_principal_len);
                        flick_iiopxx_decode_end_chunk(_t155_principal_len);
                        flick_iiopxx_decode_end_glob(_t155_principal_len);
                        /* Begin decode phase on parameters */
                        flick_iiopxx_decode_new_glob(27);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_cdr_swap_decode_signed32(0, _local_a1.a.a, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_new_chunk_align(16, 3, 2, 0);
                        flick_iiopxx_check_span(16, _flick_abort402);
                        flick_cdr_swap_decode_float64(0, _local_a1.a.b, CORBA::Double );
                        flick_cdr_swap_decode_signed16(8, _local_a1.a.c, CORBA::Short );
                        flick_cdr_swap_decode_char8(10, _local_a1.b.a, CORBA::Char );
                        flick_cdr_swap_decode_unsigned32(12, _t156_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(27);
                        flick_iiopxx_decode_new_glob(1 * _t156_temp_string_len);
                        flick_iiopxx_check_span(1 * _t156_temp_string_len, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(1 * _t156_temp_string_len);
                        {
                          CORBA::Char *_t_alloc_ptr;

                          _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t156_temp_string_len * sizeof(CORBA::Char )));
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_a1.b.b = _t_alloc_ptr;
                        }
                        flick_cdr_swap_decode_bcopy(0, _local_a1.b.b, 1 * _t156_temp_string_len);
                        flick_iiopxx_decode_end_chunk(1 * _t156_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t156_temp_string_len);
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_cdr_swap_decode_unsigned32(0, _local_a1.b.c._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        {
                          struct ::ta::tc *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::tc *)new (struct ::ta::tc [_local_a1.b.c._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_a1.b.c._buffer = _t_alloc_ptr;
                          _local_a1.b.c._maximum = _local_a1.b.c._length;
                          _local_a1.b.c._release = 1;
                        }
                        for (_t157_array_iter = 0; _t157_array_iter < _local_a1.b.c._length; _t157_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_tc_swap(_stream, _local_a1.b.c._buffer + _t157_array_iter))
                              goto _flick_abort408;
                            continue;
                            {
                            _flick_abort408:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_decode_new_glob(28);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_signed32(0, _local_a1.c.a.a, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_new_chunk_align(20, 3, 2, 0);
                        flick_iiopxx_check_span(20, _flick_abort402);
                        flick_cdr_swap_decode_float64(0, _local_a1.c.a.b, CORBA::Double );
                        flick_cdr_swap_decode_signed16(8, _local_a1.c.a.c, CORBA::Short );
                        flick_cdr_swap_decode_char8(10, _local_a1.c.b.a, CORBA::Char );
                        flick_cdr_swap_decode_char8(11, _local_a1.c.b.b, CORBA::Char );
                        flick_cdr_swap_decode_char8(12, _local_a1.c.b.c, CORBA::Char );
                        flick_cdr_swap_decode_char8(13, _local_a1.c.b.d, CORBA::Char );
                        flick_cdr_swap_decode_unsigned32(16, _local_a1.c.b.e._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(20);
                        flick_iiopxx_decode_end_glob(28);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_a1.c.b.e._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_a1.c.b.e._buffer = _t_alloc_ptr;
                          _local_a1.c.b.e._maximum = _local_a1.c.b.e._length;
                          _local_a1.c.b.e._release = 1;
                        }
                        for (_t158_array_iter = 0; _t158_array_iter < _local_a1.c.b.e._length; _t158_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_td_swap(_stream, _local_a1.c.b.e._buffer + _t158_array_iter))
                              goto _flick_abort413;
                            continue;
                            {
                            _flick_abort413:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_decode_new_glob(4);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _local_a1.next._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(4);
                        {
                          struct ta *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ta *)new (struct ta [_local_a1.next._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_a1.next._buffer = _t_alloc_ptr;
                          _local_a1.next._maximum = _local_a1.next._length;
                          _local_a1.next._release = 1;
                        }
                        for (_t159_array_iter = 0; _t159_array_iter < _local_a1.next._length; _t159_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_swap(_stream, _local_a1.next._buffer + _t159_array_iter))
                              goto _flick_abort418;
                            continue;
                            {
                            _flick_abort418:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_decode_new_glob(24);
                        flick_iiopxx_check_span(24, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(24);
                        flick_cdr_swap_decode_signed32(0, _local_a1.d.a, CORBA::Long );
                        flick_cdr_swap_decode_float64(8, _local_a1.d.b, CORBA::Double );
                        flick_cdr_swap_decode_signed16(16, _local_a1.d.c, CORBA::Short );
                        flick_cdr_swap_decode_char8(18, _local_a1.e.a, CORBA::Char );
                        flick_cdr_swap_decode_unsigned32(20, _t160_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(24);
                        flick_iiopxx_decode_end_glob(24);
                        flick_iiopxx_decode_new_glob(1 * _t160_temp_string_len);
                        flick_iiopxx_check_span(1 * _t160_temp_string_len, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(1 * _t160_temp_string_len);
                        {
                          CORBA::Char *_t_alloc_ptr;

                          _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t160_temp_string_len * sizeof(CORBA::Char )));
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_a1.e.b = _t_alloc_ptr;
                        }
                        flick_cdr_swap_decode_bcopy(0, _local_a1.e.b, 1 * _t160_temp_string_len);
                        flick_iiopxx_decode_end_chunk(1 * _t160_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t160_temp_string_len);
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_cdr_swap_decode_unsigned32(0, _local_a1.e.c._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        {
                          struct ::ta::tc *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::tc *)new (struct ::ta::tc [_local_a1.e.c._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_a1.e.c._buffer = _t_alloc_ptr;
                          _local_a1.e.c._maximum = _local_a1.e.c._length;
                          _local_a1.e.c._release = 1;
                        }
                        for (_t161_array_iter = 0; _t161_array_iter < _local_a1.e.c._length; _t161_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_tc_swap(_stream, _local_a1.e.c._buffer + _t161_array_iter))
                              goto _flick_abort425;
                            continue;
                            {
                            _flick_abort425:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_decode_new_glob(28);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_signed32(0, _local_a1.f.a.a, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_new_chunk_align(20, 3, 2, 0);
                        flick_iiopxx_check_span(20, _flick_abort402);
                        flick_cdr_swap_decode_float64(0, _local_a1.f.a.b, CORBA::Double );
                        flick_cdr_swap_decode_signed16(8, _local_a1.f.a.c, CORBA::Short );
                        flick_cdr_swap_decode_char8(10, _local_a1.f.b.a, CORBA::Char );
                        flick_cdr_swap_decode_char8(11, _local_a1.f.b.b, CORBA::Char );
                        flick_cdr_swap_decode_char8(12, _local_a1.f.b.c, CORBA::Char );
                        flick_cdr_swap_decode_char8(13, _local_a1.f.b.d, CORBA::Char );
                        flick_cdr_swap_decode_unsigned32(16, _local_a1.f.b.e._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(20);
                        flick_iiopxx_decode_end_glob(28);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_a1.f.b.e._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_a1.f.b.e._buffer = _t_alloc_ptr;
                          _local_a1.f.b.e._maximum = _local_a1.f.b.e._length;
                          _local_a1.f.b.e._release = 1;
                        }
                        for (_t162_array_iter = 0; _t162_array_iter < _local_a1.f.b.e._length; _t162_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_td_swap(_stream, _local_a1.f.b.e._buffer + _t162_array_iter))
                              goto _flick_abort430;
                            continue;
                            {
                            _flick_abort430:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_decode_new_glob(40);
                        flick_iiopxx_check_span(40, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(40);
                        flick_cdr_swap_decode_signed32(0, _local_b1.a.a, CORBA::Long );
                        flick_cdr_swap_decode_float64(4, _local_b1.a.b, CORBA::Double );
                        flick_cdr_swap_decode_signed16(12, _local_b1.a.c, CORBA::Short );
                        flick_cdr_swap_decode_signed32(16, _local_b1.b.a.a, CORBA::Long );
                        flick_cdr_swap_decode_float64(20, _local_b1.b.a.b, CORBA::Double );
                        flick_cdr_swap_decode_signed16(28, _local_b1.b.a.c, CORBA::Short );
                        flick_cdr_swap_decode_char8(30, _local_b1.b.b.a, CORBA::Char );
                        flick_cdr_swap_decode_char8(31, _local_b1.b.b.b, CORBA::Char );
                        flick_cdr_swap_decode_char8(32, _local_b1.b.b.c, CORBA::Char );
                        flick_cdr_swap_decode_char8(33, _local_b1.b.b.d, CORBA::Char );
                        flick_cdr_swap_decode_unsigned32(36, _local_b1.b.b.e._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(40);
                        flick_iiopxx_decode_end_glob(40);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_b1.b.b.e._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_b1.b.b.e._buffer = _t_alloc_ptr;
                          _local_b1.b.b.e._maximum = _local_b1.b.b.e._length;
                          _local_b1.b.b.e._release = 1;
                        }
                        for (_t163_array_iter = 0; _t163_array_iter < _local_b1.b.b.e._length; _t163_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_td_swap(_stream, _local_b1.b.b.e._buffer + _t163_array_iter))
                              goto _flick_abort435;
                            continue;
                            {
                            _flick_abort435:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_decode_new_glob(4);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _local_b1.c._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(4);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_b1.c._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_b1.c._buffer = _t_alloc_ptr;
                          _local_b1.c._maximum = _local_b1.c._length;
                          _local_b1.c._release = 1;
                        }
                        for (_t167_array_iter = 0; _t167_array_iter < _local_b1.c._length; _t167_array_iter++)
                          {
                            CORBA::ULong _t169_array_iter;

                            flick_iiopxx_decode_new_glob(28);
                            flick_iiopxx_check_span(4, _flick_abort455);
                            flick_iiopxx_decode_new_chunk(4);
                            flick_cdr_swap_decode_signed32(0, _local_b1.c._buffer[_t167_array_iter].a.a, CORBA::Long );
                            flick_iiopxx_decode_end_chunk(4);
                            flick_iiopxx_decode_new_chunk_align(20, 3, 2, 0);
                            flick_iiopxx_check_span(20, _flick_abort455);
                            flick_cdr_swap_decode_float64(0, _local_b1.c._buffer[_t167_array_iter].a.b, CORBA::Double );
                            flick_cdr_swap_decode_signed16(8, _local_b1.c._buffer[_t167_array_iter].a.c, CORBA::Short );
                            flick_cdr_swap_decode_char8(10, _local_b1.c._buffer[_t167_array_iter].b.a, CORBA::Char );
                            flick_cdr_swap_decode_char8(11, _local_b1.c._buffer[_t167_array_iter].b.b, CORBA::Char );
                            flick_cdr_swap_decode_char8(12, _local_b1.c._buffer[_t167_array_iter].b.c, CORBA::Char );
                            flick_cdr_swap_decode_char8(13, _local_b1.c._buffer[_t167_array_iter].b.d, CORBA::Char );
                            flick_cdr_swap_decode_unsigned32(16, _local_b1.c._buffer[_t167_array_iter].b.e._length, CORBA::ULong );
                            flick_iiopxx_decode_end_chunk(20);
                            flick_iiopxx_decode_end_glob(28);
                            {
                              struct ::ta::td *_t_alloc_ptr;

                              _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_b1.c._buffer[_t167_array_iter].b.e._length]);
                              if (!_t_alloc_ptr)
                                flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort455);
                              _local_b1.c._buffer[_t167_array_iter].b.e._buffer = _t_alloc_ptr;
                              _local_b1.c._buffer[_t167_array_iter].b.e._maximum = _local_b1.c._buffer[_t167_array_iter].b.e._length;
                              _local_b1.c._buffer[_t167_array_iter].b.e._release = 1;
                            }
                            for (_t169_array_iter = 0; _t169_array_iter < _local_b1.c._buffer[_t167_array_iter].b.e._length; _t169_array_iter++)
                              {
                                if (flick_unmarshal_stub_ta_td_swap(_stream, _local_b1.c._buffer[_t167_array_iter].b.e._buffer + _t169_array_iter))
                                  goto _flick_abort465;
                                continue;
                                {
                                _flick_abort465:
                                  goto _flick_abort455;
                                }
                              }
                            continue;
                            {
                            _flick_abort455:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_decode_new_glob(4);
                        flick_iiopxx_check_span(4, _flick_abort402);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _local_b1.d._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(4);
                        {
                          struct tb *_t_alloc_ptr;

                          _t_alloc_ptr = (struct tb *)new (struct tb [_local_b1.d._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort402);
                          _local_b1.d._buffer = _t_alloc_ptr;
                          _local_b1.d._maximum = _local_b1.d._length;
                          _local_b1.d._release = 1;
                        }
                        for (_t170_array_iter = 0; _t170_array_iter < _local_b1.d._length; _t170_array_iter++)
                          {
                            if (flick_unmarshal_stub_tb_swap(_stream, _local_b1.d._buffer + _t170_array_iter))
                              goto _flick_abort470;
                            continue;
                            {
                            _flick_abort470:
                              goto _flick_abort402;
                            }
                          }
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->convert(_local_a1, _local_b1, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t171_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t171_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort402);
                          flick_iiopxx_encode_new_glob(8, _flick_abort402);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t171_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t171_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_unsigned32(0, _return, enum tc );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort477);
                                break;
                                {
                                _flick_abort477:
                                  goto _flick_abort402;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort478);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort478:
                                  goto _flick_abort402;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort402:
                          goto _flick_abort401;
                        }
                      }
                      break;
                      {
                      _flick_abort401:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      case (unsigned int) 13:
        {
          unsigned int _t172_switch_tag;

          flick_iiopxx_check_span(20, _flick_abort5);
          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t172_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t172_switch_tag)
            {
            case /* _get */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1600611700):
              {
                unsigned int _t173_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t173_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t173_switch_tag)
                  {
                  case /* _my_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1601010015):
                    {
                      unsigned int _t174_switch_tag;

                      flick_iiopxx_decode_new_chunk(4);
                      flick_cdr_decode_unsigned32(0, _t174_switch_tag, unsigned int );
                      flick_iiopxx_decode_end_chunk(4);
                      switch ((unsigned int )_t174_switch_tag)
                        {
                        case /* attr */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1635021938):
                          {
                            char _t175_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_swap_decode_char8(0, _t175_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t175_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t176_principal_len;
                                    CORBA::Long _return;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort480);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(7);
                                    flick_cdr_swap_decode_unsigned32(3, _t176_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(7);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t176_principal_len, _flick_abort480);
                                    flick_iiopxx_decode_new_glob(_t176_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t176_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t176_principal_len);
                                    flick_iiopxx_decode_end_glob(_t176_principal_len);
                                    /* Begin decode phase on parameters */
                                    _return = 0;
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _return = _local_this->my_attr(_ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t177_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t177_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort480);
                                      flick_iiopxx_encode_new_glob(8, _flick_abort480);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t177_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t177_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_new_chunk(4);
                                            flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                            flick_iiopxx_encode_end_chunk(4);
                                            flick_iiopxx_encode_end_glob(8);
                                            break;
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(8);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort486);
                                            break;
                                            {
                                            _flick_abort486:
                                              goto _flick_abort480;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort487);
                                            flick_iiopxx_encode_end_glob(8);
                                            break;
                                            {
                                            _flick_abort487:
                                              goto _flick_abort480;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort480:
                                      goto _flick_abort479;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort479:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            case /* _set */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1601398132):
              {
                unsigned int _t178_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t178_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t178_switch_tag)
                  {
                  case /* _my_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1601010015):
                    {
                      unsigned int _t179_switch_tag;

                      flick_iiopxx_decode_new_chunk(4);
                      flick_cdr_decode_unsigned32(0, _t179_switch_tag, unsigned int );
                      flick_iiopxx_decode_end_chunk(4);
                      switch ((unsigned int )_t179_switch_tag)
                        {
                        case /* attr */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1635021938):
                          {
                            char _t180_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_swap_decode_char8(0, _t180_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t180_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t181_principal_len;
                                    CORBA::Long _local_my_attr;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort489);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(7);
                                    flick_cdr_swap_decode_unsigned32(3, _t181_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(7);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t181_principal_len, _flick_abort489);
                                    flick_iiopxx_decode_new_glob(_t181_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t181_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t181_principal_len);
                                    flick_iiopxx_decode_end_glob(_t181_principal_len);
                                    /* Begin decode phase on parameters */
                                    flick_iiopxx_decode_new_glob(7);
                                    flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                                    flick_iiopxx_check_span(4, _flick_abort489);
                                    flick_cdr_swap_decode_signed32(0, _local_my_attr, CORBA::Long );
                                    flick_iiopxx_decode_end_chunk(4);
                                    flick_iiopxx_decode_end_glob(7);
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _local_this->my_attr(_local_my_attr, _ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t182_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t182_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort489);
                                      flick_iiopxx_encode_new_glob(4, _flick_abort489);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t182_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t182_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort495);
                                            break;
                                            {
                                            _flick_abort495:
                                              goto _flick_abort489;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort496);
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                            {
                                            _flick_abort496:
                                              goto _flick_abort489;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort489:
                                      goto _flick_abort488;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort488:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      case (unsigned int) 6:
        {
          unsigned int _t183_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t183_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t183_switch_tag)
            {
            case /* _is_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1600746335):
              {
                unsigned short int _t184_switch_tag;

                flick_iiopxx_decode_new_chunk(2);
                flick_cdr_decode_unsigned16(0, _t184_switch_tag, unsigned short int );
                flick_iiopxx_decode_end_chunk(2);
                switch ((unsigned short int )_t184_switch_tag)
                  {
                  case /* a */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 24832):
                    {
                      {
                        POA_obj *_local_this;
                        unsigned int _t185_principal_len;
                        CORBA::Boolean _return;
                        char *_local_type_id;
                        flick_unsigned32_t _t186_temp_string_len;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort498);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(6);
                        flick_cdr_swap_decode_unsigned32(2, _t185_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(6);
                        flick_iiopxx_decode_end_glob(24);
                        flick_iiopxx_check_span(_t185_principal_len, _flick_abort498);
                        flick_iiopxx_decode_new_glob(_t185_principal_len);
                        flick_iiopxx_decode_new_chunk(_t185_principal_len);
                        flick_iiopxx_decode_end_chunk(_t185_principal_len);
                        flick_iiopxx_decode_end_glob(_t185_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort498);
                        flick_cdr_swap_decode_unsigned32(0, _t186_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        flick_iiopxx_decode_new_glob(1 * _t186_temp_string_len);
                        flick_iiopxx_check_span(1 * _t186_temp_string_len, _flick_abort498);
                        flick_iiopxx_decode_new_chunk(1 * _t186_temp_string_len);
                        flick_cdr_swap_decode_msgptr(0, _local_type_id, CORBA::Char *);
                        flick_iiopxx_decode_end_chunk(1 * _t186_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t186_temp_string_len);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->_is_a(_local_type_id, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t187_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t187_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort498);
                          flick_iiopxx_encode_new_glob(5, _flick_abort498);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t187_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t187_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(1);
                                flick_cdr_encode_unsigned8(0, _return, CORBA::Boolean );
                                flick_iiopxx_encode_end_chunk(1);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(5);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort506);
                                break;
                                {
                                _flick_abort506:
                                  goto _flick_abort498;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort507);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                                {
                                _flick_abort507:
                                  goto _flick_abort498;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort498:
                          goto _flick_abort497;
                        }
                      }
                      break;
                      {
                      _flick_abort497:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      default:
        {
          flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
          flick_iiopxx_decode_end_glob(24);
          break;
        }
      }
  }
  } else {
  {
    unsigned int _t47_switch_tag;

    flick_iiopxx_decode_new_glob(24);
    flick_iiopxx_check_span(16, _flick_abort5);
    flick_iiopxx_decode_new_chunk(4);
    flick_cdr_decode_unsigned32(0, _t47_switch_tag, unsigned int );
    flick_iiopxx_decode_end_chunk(4);
    switch ((unsigned int )_t47_switch_tag)
      {
      case (unsigned int) 11:
        {
          unsigned int _t48_switch_tag;

          flick_iiopxx_check_span(16, _flick_abort5);
          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t48_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t48_switch_tag)
            {
            case /* get_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1734702175):
              {
                unsigned int _t49_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t49_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t49_switch_tag)
                  {
                  case /* serv */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936028278):
                    {
                      unsigned short int _t50_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t50_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t50_switch_tag)
                        {
                        case /* er */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25970):
                          {
                            char _t51_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_decode_char8(0, _t51_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t51_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t52_principal_len;
                                    ::obj::my_obj_ptr _return;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort133);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(5);
                                    flick_cdr_decode_unsigned32(1, _t52_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(5);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t52_principal_len, _flick_abort133);
                                    flick_iiopxx_decode_new_glob(_t52_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t52_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t52_principal_len);
                                    flick_iiopxx_decode_end_glob(_t52_principal_len);
                                    /* Begin decode phase on parameters */
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _return = _local_this->get_server(_ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t53_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t53_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort133);
                                      flick_iiopxx_encode_new_glob(4, _flick_abort133);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t53_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t53_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_cdrxx_encode_IOR(iiopxx, _return, 0, obj , _flick_abort138);
                                            CORBA_object_flick_free(_return);
                                            _return = 0;
                                            break;
                                            {
                                            _flick_abort138:
                                              goto _flick_abort133;
                                            }
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort139);
                                            break;
                                            {
                                            _flick_abort139:
                                              goto _flick_abort133;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort140);
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                            {
                                            _flick_abort140:
                                              goto _flick_abort133;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort133:
                                      goto _flick_abort132;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort132:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            case /* set_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936028767):
              {
                unsigned int _t54_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t54_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t54_switch_tag)
                  {
                  case /* serv */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1936028278):
                    {
                      unsigned short int _t55_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t55_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t55_switch_tag)
                        {
                        case /* er */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25970):
                          {
                            char _t56_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_decode_char8(0, _t56_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t56_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t57_principal_len;
                                    ::obj::my_obj_ptr _local_srvr;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort142);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(5);
                                    flick_cdr_decode_unsigned32(1, _t57_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(5);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t57_principal_len, _flick_abort142);
                                    flick_iiopxx_decode_new_glob(_t57_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t57_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t57_principal_len);
                                    flick_iiopxx_decode_end_glob(_t57_principal_len);
                                    /* Begin decode phase on parameters */
                                    flick_cdrxx_decode_IOR(iiopxx, _local_srvr, 1, obj , _flick_abort142);
                                    flick_iiopxx_mark_port_for_cleanup(_local_srvr, 1);
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _local_this->set_server(_local_srvr, _ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t58_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t58_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort142);
                                      flick_iiopxx_encode_new_glob(4, _flick_abort142);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t58_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t58_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort148);
                                            break;
                                            {
                                            _flick_abort148:
                                              goto _flick_abort142;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort149);
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                            {
                                            _flick_abort149:
                                              goto _flick_abort142;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort142:
                                      goto _flick_abort141;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort141:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      case (unsigned int) 8:
        {
          unsigned int _t59_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t59_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t59_switch_tag)
            {
            case /* conv */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1668247158):
              {
                unsigned int _t60_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t60_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t60_switch_tag)
                  {
                  case /* ert */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1701999616):
                    {
                      {
                        POA_obj *_local_this;
                        unsigned int _t61_principal_len;
                        enum tc _return;
                        struct ta _local_a1;
                        flick_unsigned32_t _t62_temp_string_len;
                        CORBA::ULong _t63_array_iter;
                        CORBA::ULong _t64_array_iter;
                        CORBA::ULong _t65_array_iter;
                        flick_unsigned32_t _t66_temp_string_len;
                        CORBA::ULong _t67_array_iter;
                        CORBA::ULong _t68_array_iter;
                        struct tb _local_b1;
                        CORBA::ULong _t69_array_iter;
                        CORBA::ULong _t73_array_iter;
                        CORBA::ULong _t76_array_iter;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort151);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _t61_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(24);
                        flick_iiopxx_check_span(_t61_principal_len, _flick_abort151);
                        flick_iiopxx_decode_new_glob(_t61_principal_len);
                        flick_iiopxx_decode_new_chunk(_t61_principal_len);
                        flick_iiopxx_decode_end_chunk(_t61_principal_len);
                        flick_iiopxx_decode_end_glob(_t61_principal_len);
                        /* Begin decode phase on parameters */
                        flick_iiopxx_decode_new_glob(27);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_cdr_decode_signed32(0, _local_a1.a.a, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_new_chunk_align(16, 3, 2, 0);
                        flick_iiopxx_check_span(16, _flick_abort151);
                        flick_cdr_decode_float64(0, _local_a1.a.b, CORBA::Double );
                        flick_cdr_decode_signed16(8, _local_a1.a.c, CORBA::Short );
                        flick_cdr_decode_char8(10, _local_a1.b.a, CORBA::Char );
                        flick_cdr_decode_unsigned32(12, _t62_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(27);
                        flick_iiopxx_decode_new_glob(1 * _t62_temp_string_len);
                        flick_iiopxx_check_span(1 * _t62_temp_string_len, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(1 * _t62_temp_string_len);
                        {
                          CORBA::Char *_t_alloc_ptr;

                          _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t62_temp_string_len * sizeof(CORBA::Char )));
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_a1.b.b = _t_alloc_ptr;
                        }
                        flick_cdr_decode_bcopy(0, _local_a1.b.b, 1 * _t62_temp_string_len);
                        flick_iiopxx_decode_end_chunk(1 * _t62_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t62_temp_string_len);
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_cdr_decode_unsigned32(0, _local_a1.b.c._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        {
                          struct ::ta::tc *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::tc *)new (struct ::ta::tc [_local_a1.b.c._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_a1.b.c._buffer = _t_alloc_ptr;
                          _local_a1.b.c._maximum = _local_a1.b.c._length;
                          _local_a1.b.c._release = 1;
                        }
                        for (_t63_array_iter = 0; _t63_array_iter < _local_a1.b.c._length; _t63_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_tc(_stream, _local_a1.b.c._buffer + _t63_array_iter))
                              goto _flick_abort157;
                            continue;
                            {
                            _flick_abort157:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_decode_new_glob(28);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_signed32(0, _local_a1.c.a.a, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_new_chunk_align(20, 3, 2, 0);
                        flick_iiopxx_check_span(20, _flick_abort151);
                        flick_cdr_decode_float64(0, _local_a1.c.a.b, CORBA::Double );
                        flick_cdr_decode_signed16(8, _local_a1.c.a.c, CORBA::Short );
                        flick_cdr_decode_char8(10, _local_a1.c.b.a, CORBA::Char );
                        flick_cdr_decode_char8(11, _local_a1.c.b.b, CORBA::Char );
                        flick_cdr_decode_char8(12, _local_a1.c.b.c, CORBA::Char );
                        flick_cdr_decode_char8(13, _local_a1.c.b.d, CORBA::Char );
                        flick_cdr_decode_unsigned32(16, _local_a1.c.b.e._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(20);
                        flick_iiopxx_decode_end_glob(28);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_a1.c.b.e._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_a1.c.b.e._buffer = _t_alloc_ptr;
                          _local_a1.c.b.e._maximum = _local_a1.c.b.e._length;
                          _local_a1.c.b.e._release = 1;
                        }
                        for (_t64_array_iter = 0; _t64_array_iter < _local_a1.c.b.e._length; _t64_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_td(_stream, _local_a1.c.b.e._buffer + _t64_array_iter))
                              goto _flick_abort162;
                            continue;
                            {
                            _flick_abort162:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_decode_new_glob(4);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _local_a1.next._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(4);
                        {
                          struct ta *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ta *)new (struct ta [_local_a1.next._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_a1.next._buffer = _t_alloc_ptr;
                          _local_a1.next._maximum = _local_a1.next._length;
                          _local_a1.next._release = 1;
                        }
                        for (_t65_array_iter = 0; _t65_array_iter < _local_a1.next._length; _t65_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta(_stream, _local_a1.next._buffer + _t65_array_iter))
                              goto _flick_abort167;
                            continue;
                            {
                            _flick_abort167:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_decode_new_glob(24);
                        flick_iiopxx_check_span(24, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(24);
                        flick_cdr_decode_signed32(0, _local_a1.d.a, CORBA::Long );
                        flick_cdr_decode_float64(8, _local_a1.d.b, CORBA::Double );
                        flick_cdr_decode_signed16(16, _local_a1.d.c, CORBA::Short );
                        flick_cdr_decode_char8(18, _local_a1.e.a, CORBA::Char );
                        flick_cdr_decode_unsigned32(20, _t66_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(24);
                        flick_iiopxx_decode_end_glob(24);
                        flick_iiopxx_decode_new_glob(1 * _t66_temp_string_len);
                        flick_iiopxx_check_span(1 * _t66_temp_string_len, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(1 * _t66_temp_string_len);
                        {
                          CORBA::Char *_t_alloc_ptr;

                          _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t66_temp_string_len * sizeof(CORBA::Char )));
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_a1.e.b = _t_alloc_ptr;
                        }
                        flick_cdr_decode_bcopy(0, _local_a1.e.b, 1 * _t66_temp_string_len);
                        flick_iiopxx_decode_end_chunk(1 * _t66_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t66_temp_string_len);
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_cdr_decode_unsigned32(0, _local_a1.e.c._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        {
                          struct ::ta::tc *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::tc *)new (struct ::ta::tc [_local_a1.e.c._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_a1.e.c._buffer = _t_alloc_ptr;
                          _local_a1.e.c._maximum = _local_a1.e.c._length;
                          _local_a1.e.c._release = 1;
                        }
                        for (_t67_array_iter = 0; _t67_array_iter < _local_a1.e.c._length; _t67_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_tc(_stream, _local_a1.e.c._buffer + _t67_array_iter))
                              goto _flick_abort174;
                            continue;
                            {
                            _flick_abort174:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_decode_new_glob(28);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_signed32(0, _local_a1.f.a.a, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_new_chunk_align(20, 3, 2, 0);
                        flick_iiopxx_check_span(20, _flick_abort151);
                        flick_cdr_decode_float64(0, _local_a1.f.a.b, CORBA::Double );
                        flick_cdr_decode_signed16(8, _local_a1.f.a.c, CORBA::Short );
                        flick_cdr_decode_char8(10, _local_a1.f.b.a, CORBA::Char );
                        flick_cdr_decode_char8(11, _local_a1.f.b.b, CORBA::Char );
                        flick_cdr_decode_char8(12, _local_a1.f.b.c, CORBA::Char );
                        flick_cdr_decode_char8(13, _local_a1.f.b.d, CORBA::Char );
                        flick_cdr_decode_unsigned32(16, _local_a1.f.b.e._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(20);
                        flick_iiopxx_decode_end_glob(28);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_a1.f.b.e._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_a1.f.b.e._buffer = _t_alloc_ptr;
                          _local_a1.f.b.e._maximum = _local_a1.f.b.e._length;
                          _local_a1.f.b.e._release = 1;
                        }
                        for (_t68_array_iter = 0; _t68_array_iter < _local_a1.f.b.e._length; _t68_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_td(_stream, _local_a1.f.b.e._buffer + _t68_array_iter))
                              goto _flick_abort179;
                            continue;
                            {
                            _flick_abort179:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_decode_new_glob(40);
                        flick_iiopxx_check_span(40, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(40);
                        flick_cdr_decode_signed32(0, _local_b1.a.a, CORBA::Long );
                        flick_cdr_decode_float64(4, _local_b1.a.b, CORBA::Double );
                        flick_cdr_decode_signed16(12, _local_b1.a.c, CORBA::Short );
                        flick_cdr_decode_signed32(16, _local_b1.b.a.a, CORBA::Long );
                        flick_cdr_decode_float64(20, _local_b1.b.a.b, CORBA::Double );
                        flick_cdr_decode_signed16(28, _local_b1.b.a.c, CORBA::Short );
                        flick_cdr_decode_char8(30, _local_b1.b.b.a, CORBA::Char );
                        flick_cdr_decode_char8(31, _local_b1.b.b.b, CORBA::Char );
                        flick_cdr_decode_char8(32, _local_b1.b.b.c, CORBA::Char );
                        flick_cdr_decode_char8(33, _local_b1.b.b.d, CORBA::Char );
                        flick_cdr_decode_unsigned32(36, _local_b1.b.b.e._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(40);
                        flick_iiopxx_decode_end_glob(40);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_b1.b.b.e._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_b1.b.b.e._buffer = _t_alloc_ptr;
                          _local_b1.b.b.e._maximum = _local_b1.b.b.e._length;
                          _local_b1.b.b.e._release = 1;
                        }
                        for (_t69_array_iter = 0; _t69_array_iter < _local_b1.b.b.e._length; _t69_array_iter++)
                          {
                            if (flick_unmarshal_stub_ta_td(_stream, _local_b1.b.b.e._buffer + _t69_array_iter))
                              goto _flick_abort184;
                            continue;
                            {
                            _flick_abort184:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_decode_new_glob(4);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _local_b1.c._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(4);
                        {
                          struct ::ta::td *_t_alloc_ptr;

                          _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_b1.c._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_b1.c._buffer = _t_alloc_ptr;
                          _local_b1.c._maximum = _local_b1.c._length;
                          _local_b1.c._release = 1;
                        }
                        for (_t73_array_iter = 0; _t73_array_iter < _local_b1.c._length; _t73_array_iter++)
                          {
                            CORBA::ULong _t75_array_iter;

                            flick_iiopxx_decode_new_glob(28);
                            flick_iiopxx_check_span(4, _flick_abort204);
                            flick_iiopxx_decode_new_chunk(4);
                            flick_cdr_decode_signed32(0, _local_b1.c._buffer[_t73_array_iter].a.a, CORBA::Long );
                            flick_iiopxx_decode_end_chunk(4);
                            flick_iiopxx_decode_new_chunk_align(20, 3, 2, 0);
                            flick_iiopxx_check_span(20, _flick_abort204);
                            flick_cdr_decode_float64(0, _local_b1.c._buffer[_t73_array_iter].a.b, CORBA::Double );
                            flick_cdr_decode_signed16(8, _local_b1.c._buffer[_t73_array_iter].a.c, CORBA::Short );
                            flick_cdr_decode_char8(10, _local_b1.c._buffer[_t73_array_iter].b.a, CORBA::Char );
                            flick_cdr_decode_char8(11, _local_b1.c._buffer[_t73_array_iter].b.b, CORBA::Char );
                            flick_cdr_decode_char8(12, _local_b1.c._buffer[_t73_array_iter].b.c, CORBA::Char );
                            flick_cdr_decode_char8(13, _local_b1.c._buffer[_t73_array_iter].b.d, CORBA::Char );
                            flick_cdr_decode_unsigned32(16, _local_b1.c._buffer[_t73_array_iter].b.e._length, CORBA::ULong );
                            flick_iiopxx_decode_end_chunk(20);
                            flick_iiopxx_decode_end_glob(28);
                            {
                              struct ::ta::td *_t_alloc_ptr;

                              _t_alloc_ptr = (struct ::ta::td *)new (struct ::ta::td [_local_b1.c._buffer[_t73_array_iter].b.e._length]);
                              if (!_t_alloc_ptr)
                                flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort204);
                              _local_b1.c._buffer[_t73_array_iter].b.e._buffer = _t_alloc_ptr;
                              _local_b1.c._buffer[_t73_array_iter].b.e._maximum = _local_b1.c._buffer[_t73_array_iter].b.e._length;
                              _local_b1.c._buffer[_t73_array_iter].b.e._release = 1;
                            }
                            for (_t75_array_iter = 0; _t75_array_iter < _local_b1.c._buffer[_t73_array_iter].b.e._length; _t75_array_iter++)
                              {
                                if (flick_unmarshal_stub_ta_td(_stream, _local_b1.c._buffer[_t73_array_iter].b.e._buffer + _t75_array_iter))
                                  goto _flick_abort214;
                                continue;
                                {
                                _flick_abort214:
                                  goto _flick_abort204;
                                }
                              }
                            continue;
                            {
                            _flick_abort204:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_decode_new_glob(4);
                        flick_iiopxx_check_span(4, _flick_abort151);
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _local_b1.d._length, CORBA::ULong );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(4);
                        {
                          struct tb *_t_alloc_ptr;

                          _t_alloc_ptr = (struct tb *)new (struct tb [_local_b1.d._length]);
                          if (!_t_alloc_ptr)
                            flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort151);
                          _local_b1.d._buffer = _t_alloc_ptr;
                          _local_b1.d._maximum = _local_b1.d._length;
                          _local_b1.d._release = 1;
                        }
                        for (_t76_array_iter = 0; _t76_array_iter < _local_b1.d._length; _t76_array_iter++)
                          {
                            if (flick_unmarshal_stub_tb(_stream, _local_b1.d._buffer + _t76_array_iter))
                              goto _flick_abort219;
                            continue;
                            {
                            _flick_abort219:
                              goto _flick_abort151;
                            }
                          }
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->convert(_local_a1, _local_b1, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t77_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t77_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort151);
                          flick_iiopxx_encode_new_glob(8, _flick_abort151);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t77_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t77_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_unsigned32(0, _return, enum tc );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort226);
                                break;
                                {
                                _flick_abort226:
                                  goto _flick_abort151;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort227);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort227:
                                  goto _flick_abort151;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort151:
                          goto _flick_abort150;
                        }
                      }
                      break;
                      {
                      _flick_abort150:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      case (unsigned int) 13:
        {
          unsigned int _t78_switch_tag;

          flick_iiopxx_check_span(20, _flick_abort5);
          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t78_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t78_switch_tag)
            {
            case /* _get */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1600611700):
              {
                unsigned int _t79_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t79_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t79_switch_tag)
                  {
                  case /* _my_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1601010015):
                    {
                      unsigned int _t80_switch_tag;

                      flick_iiopxx_decode_new_chunk(4);
                      flick_cdr_decode_unsigned32(0, _t80_switch_tag, unsigned int );
                      flick_iiopxx_decode_end_chunk(4);
                      switch ((unsigned int )_t80_switch_tag)
                        {
                        case /* attr */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1635021938):
                          {
                            char _t81_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_decode_char8(0, _t81_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t81_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t82_principal_len;
                                    CORBA::Long _return;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort229);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(7);
                                    flick_cdr_decode_unsigned32(3, _t82_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(7);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t82_principal_len, _flick_abort229);
                                    flick_iiopxx_decode_new_glob(_t82_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t82_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t82_principal_len);
                                    flick_iiopxx_decode_end_glob(_t82_principal_len);
                                    /* Begin decode phase on parameters */
                                    _return = 0;
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _return = _local_this->my_attr(_ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t83_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t83_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort229);
                                      flick_iiopxx_encode_new_glob(8, _flick_abort229);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t83_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t83_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_new_chunk(4);
                                            flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                            flick_iiopxx_encode_end_chunk(4);
                                            flick_iiopxx_encode_end_glob(8);
                                            break;
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(8);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort235);
                                            break;
                                            {
                                            _flick_abort235:
                                              goto _flick_abort229;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort236);
                                            flick_iiopxx_encode_end_glob(8);
                                            break;
                                            {
                                            _flick_abort236:
                                              goto _flick_abort229;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort229:
                                      goto _flick_abort228;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort228:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            case /* _set */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1601398132):
              {
                unsigned int _t84_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t84_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t84_switch_tag)
                  {
                  case /* _my_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1601010015):
                    {
                      unsigned int _t85_switch_tag;

                      flick_iiopxx_decode_new_chunk(4);
                      flick_cdr_decode_unsigned32(0, _t85_switch_tag, unsigned int );
                      flick_iiopxx_decode_end_chunk(4);
                      switch ((unsigned int )_t85_switch_tag)
                        {
                        case /* attr */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1635021938):
                          {
                            char _t86_switch_tag;

                            flick_iiopxx_decode_new_chunk(1);
                            flick_cdr_decode_char8(0, _t86_switch_tag, char );
                            flick_iiopxx_decode_end_chunk(1);
                            switch ((char )_t86_switch_tag)
                              {
                              case 0:
                                {
                                  {
                                    POA_obj *_local_this;
                                    unsigned int _t87_principal_len;
                                    CORBA::Long _local_my_attr;
                                    CORBA::Environment _ev;

                                    flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort238);
                                    /* Decode the requesting `Principal' pseudo object (client ID). */
                                    flick_iiopxx_decode_new_chunk(7);
                                    flick_cdr_decode_unsigned32(3, _t87_principal_len, unsigned int );
                                    flick_iiopxx_decode_end_chunk(7);
                                    flick_iiopxx_decode_end_glob(24);
                                    flick_iiopxx_check_span(_t87_principal_len, _flick_abort238);
                                    flick_iiopxx_decode_new_glob(_t87_principal_len);
                                    flick_iiopxx_decode_new_chunk(_t87_principal_len);
                                    flick_iiopxx_decode_end_chunk(_t87_principal_len);
                                    flick_iiopxx_decode_end_glob(_t87_principal_len);
                                    /* Begin decode phase on parameters */
                                    flick_iiopxx_decode_new_glob(7);
                                    flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                                    flick_iiopxx_check_span(4, _flick_abort238);
                                    flick_cdr_decode_signed32(0, _local_my_attr, CORBA::Long );
                                    flick_iiopxx_decode_end_chunk(4);
                                    flick_iiopxx_decode_end_glob(7);
                                    flick_iiopxx_server_end_decode();
                                    flick_corbaxx_init_environment();
                                    _local_this->my_attr(_local_my_attr, _ev);
                                    _stub_state.state = FLICK_STATE_MARSHAL;
                                    flick_iiopxx_server_start_encode();
                                    {
                                      int _t88_temp_major;

                                      flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t88_temp_major);

                                      flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort238);
                                      flick_iiopxx_encode_new_glob(4, _flick_abort238);
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _t88_temp_major, int );
                                      flick_iiopxx_encode_end_chunk(4);
                                      switch (_t88_temp_major)
                                        {
                                        case CORBA::NO_EXCEPTION:
                                          {
                                            /* Begin encode phase on parameters */
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                          }
                                        case CORBA::SYSTEM_EXCEPTION:
                                          {
                                            flick_iiopxx_encode_end_glob(4);
                                            flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort244);
                                            break;
                                            {
                                            _flick_abort244:
                                              goto _flick_abort238;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort245);
                                            flick_iiopxx_encode_end_glob(4);
                                            break;
                                            {
                                            _flick_abort245:
                                              goto _flick_abort238;
                                            }
                                          }
                                        }
                                    }
                                    flick_iiopxx_server_end_encode();
                                    break;
                                    {
                                    _flick_abort238:
                                      goto _flick_abort237;
                                    }
                                  }
                                  break;
                                  {
                                  _flick_abort237:
                                    goto _flick_abort5;
                                  }
                                }
                              default:
                                {
                                  flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                                  flick_iiopxx_decode_end_glob(24);
                                  break;
                                }
                              }
                            break;
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(24);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      case (unsigned int) 6:
        {
          unsigned int _t89_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t89_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t89_switch_tag)
            {
            case /* _is_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1600746335):
              {
                unsigned short int _t90_switch_tag;

                flick_iiopxx_decode_new_chunk(2);
                flick_cdr_decode_unsigned16(0, _t90_switch_tag, unsigned short int );
                flick_iiopxx_decode_end_chunk(2);
                switch ((unsigned short int )_t90_switch_tag)
                  {
                  case /* a */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 24832):
                    {
                      {
                        POA_obj *_local_this;
                        unsigned int _t91_principal_len;
                        CORBA::Boolean _return;
                        char *_local_type_id;
                        flick_unsigned32_t _t92_temp_string_len;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort247);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(6);
                        flick_cdr_decode_unsigned32(2, _t91_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(6);
                        flick_iiopxx_decode_end_glob(24);
                        flick_iiopxx_check_span(_t91_principal_len, _flick_abort247);
                        flick_iiopxx_decode_new_glob(_t91_principal_len);
                        flick_iiopxx_decode_new_chunk(_t91_principal_len);
                        flick_iiopxx_decode_end_chunk(_t91_principal_len);
                        flick_iiopxx_decode_end_glob(_t91_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort247);
                        flick_cdr_decode_unsigned32(0, _t92_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        flick_iiopxx_decode_new_glob(1 * _t92_temp_string_len);
                        flick_iiopxx_check_span(1 * _t92_temp_string_len, _flick_abort247);
                        flick_iiopxx_decode_new_chunk(1 * _t92_temp_string_len);
                        flick_cdr_decode_msgptr(0, _local_type_id, CORBA::Char *);
                        flick_iiopxx_decode_end_chunk(1 * _t92_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t92_temp_string_len);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->_is_a(_local_type_id, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t93_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t93_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort247);
                          flick_iiopxx_encode_new_glob(5, _flick_abort247);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t93_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t93_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(1);
                                flick_cdr_encode_unsigned8(0, _return, CORBA::Boolean );
                                flick_iiopxx_encode_end_chunk(1);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(5);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort255);
                                break;
                                {
                                _flick_abort255:
                                  goto _flick_abort247;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort256);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                                {
                                _flick_abort256:
                                  goto _flick_abort247;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort247:
                          goto _flick_abort246;
                        }
                      }
                      break;
                      {
                      _flick_abort246:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(24);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(24);
                break;
              }
            }
          break;
        }
      default:
        {
          flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
          flick_iiopxx_decode_end_glob(24);
          break;
        }
      }
  }
  }
  _stub_state.state = FLICK_STATE_EPILOGUE;
  return;
  {
  _flick_abort5:
    flick_corbaxx_server_error(cdr, iiopxx, _flick_reaper, _flick_abort4);
  _flick_abort4:
    return ;
  }
_flick_reaper:
  return ;
}

