#include "turtle-server-server.h"

POA_Server::POA_Server()
{}

POA_Server::POA_Server(const POA_Server &rhs)
  : TAO_ServantBase(rhs)
{}

POA_Server::~POA_Server()
{}

Server *POA_Server::_this(CORBA::Environment &_env)
{
  TAO_Stub *stub = this->_create_stub(_env);
  TAO_CHECK_ENV_RETURN(_env, 0);
  return new _tao_collocated_Server(this, stub);
}

CORBA::Boolean POA_Server::_is_a(const CORBA::Char *type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)type_id, "IDL:Server:1.0")) ||
      (!ACE_OS::strcmp((char *)type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return 0;
}

void *POA_Server::_downcast(const char *logical_type_id)
{
  if(ACE_OS::strcmp(logical_type_id, "IDL:Server:1.0") == 0)
    return ACE_static_cast(POA_Server_ptr , this);
   
  if(ACE_OS::strcmp(logical_type_id, "IDL:omg.org/CORBA/Object:1.0") == 0)
    return ACE_static_cast(PortableServer::Servant, this);
  return 0;
}

const char *POA_Server::_interface_repository_id() const
{
  return "IDL:Server:1.0";
}

template <class T>
  POA_Server_tie<T>::POA_Server_tie(T &t)
  : ptr_(&t),
    poa_(PortableServer::POA::_nil()),
    rel_(0)
{}

template <class T>
  POA_Server_tie<T>::POA_Server_tie(T &t, PortableServer::POA_ptr poa)
  : ptr_(&t),
    poa_(PortableServer::POA::_duplicate(poa)),
    rel_(0)
{}

template <class T>
  POA_Server_tie<T>::POA_Server_tie(T *t, CORBA::Boolean release)
  : ptr_(&t),
    poa_(PortableServer::POA::_nil()),
    rel_(release)
{}

template <class T>
  POA_Server_tie<T>::POA_Server_tie(T *t, PortableServer::POA_ptr poa, CORBA::Boolean release)
  : ptr_(&t),
    poa_(PortableServer::POA::_duplicate(poa)),
    rel_(release)
{}

template <class T>
  POA_Server_tie<T>::~POA_Server_tie()
{
  if( this->rel_ ) delete this->ptr_;
}

template <class T>
  T *POA_Server_tie<T>::_tied_object()
{
  return this->ptr_;
}

template <class T>
  void POA_Server_tie<T>::_tied_object(T &obj)
{
  if( this->rel_ ) delete this->ptr_;
  this->ptr_ = &obj;
  this->rel_ = 0;
}

template <class T>
  void POA_Server_tie<T>::_tied_object(T &obj, CORBA::Boolean release)
{
  if( this->rel_ ) delete this->ptr_;
  this->ptr_ = obj;
  this->rel_ = release;
}

template <class T>
  CORBA::Boolean POA_Server_tie<T>::_is_owner()
{
  return this->rel_;
}

template <class T>
  void POA_Server_tie<T>::_is_owner(CORBA::Boolean b)
{
  this->rel_ = b;
}

template <class T>
  PortableServer::POA_ptr POA_Server_tie<T>::_default_POA()
{
  if( !(CORBA::is_nil(this->poa_.in())) )
    return PortableServer::POA::_duplicate(this->poa_.in());
  else
  {
    TAO_POA *poa = TAO_ORB_Core_instance()->root_poa();
    PortableServer::POA_var result = poa->_this(env);
    if( env.exception() != 0 )
      return PortableServer::POA::_nil();
    else
      return result._retn();
  }
}

template <class T>
  POA_Server_tie<T>::POA_Server_tie(const POA_Server_tie &c)
{}

template <class T>
  void POA_Server_tie<T>::operator=(const POA_Server_tie &c)
{}

template <class T>
  CORBA::Long POA_Server_tie<T>::SetSize(/* POA_Server *this, */ CORBA::Long width, CORBA::Long height, CORBA::Environment &_ev)
{
  return this->ptr_->SetSize (width, height, _ev);
}

template <class T>
  CORBA::Long POA_Server_tie<T>::AddWall(/* POA_Server *this, */ CORBA::Long startx, CORBA::Long starty, CORBA::Long endx, CORBA::Long endy, CORBA::Environment &_ev)
{
  return this->ptr_->AddWall (startx, starty, endx, endy, _ev);
}

template <class T>
  CORBA::Long POA_Server_tie<T>::DelWall(/* POA_Server *this, */ CORBA::Long startx, CORBA::Long starty, CORBA::Long endx, CORBA::Long endy, CORBA::Environment &_ev)
{
  return this->ptr_->DelWall (startx, starty, endx, endy, _ev);
}

template <class T>
  CORBA::Long POA_Server_tie<T>::AddRect(/* POA_Server *this, */ CORBA::Long left, CORBA::Long top, CORBA::Long right, CORBA::Long bottom, CORBA::Long color, CORBA::Environment &_ev)
{
  return this->ptr_->AddRect (left, top, right, bottom, color, _ev);
}

template <class T>
  CORBA::Long POA_Server_tie<T>::DelRect(/* POA_Server *this, */ CORBA::Long left, CORBA::Long top, CORBA::Long right, CORBA::Long bottom, CORBA::Environment &_ev)
{
  return this->ptr_->DelRect (left, top, right, bottom, _ev);
}

template <class T>
  CORBA::Long POA_Server_tie<T>::SetTurtle(/* POA_Server *this, */ CORBA::Long x, CORBA::Long y, CORBA::Long angle, CORBA::Environment &_ev)
{
  return this->ptr_->SetTurtle (x, y, angle, _ev);
}

template <class T>
  CORBA::Long POA_Server_tie<T>::GetTurtle(/* POA_Server *this, */ ::CORBA::Long &x, ::CORBA::Long &y, ::CORBA::Long &angle, CORBA::Environment &_ev)
{
  return this->ptr_->GetTurtle (x, y, angle, _ev);
}

_tao_collocated_Server::_tao_collocated_Server(POA_Server_ptr servant, TAO_Stub *stub)
  : Server(),
    CORBA_Object(stub, servant, 1),
    servant_ (servant)
{
}

POA_Server_ptr _tao_collocated_Server::_get_servant() const
{
  return this->servant_;
}

CORBA::Long _tao_collocated_Server::SetSize(CORBA::Long width, CORBA::Long height, CORBA::Environment &_ev)
{
  return this->servant_->SetSize (width, height, _ev);
}

CORBA::Long _tao_collocated_Server::AddWall(CORBA::Long startx, CORBA::Long starty, CORBA::Long endx, CORBA::Long endy, CORBA::Environment &_ev)
{
  return this->servant_->AddWall (startx, starty, endx, endy, _ev);
}

CORBA::Long _tao_collocated_Server::DelWall(CORBA::Long startx, CORBA::Long starty, CORBA::Long endx, CORBA::Long endy, CORBA::Environment &_ev)
{
  return this->servant_->DelWall (startx, starty, endx, endy, _ev);
}

CORBA::Long _tao_collocated_Server::AddRect(CORBA::Long left, CORBA::Long top, CORBA::Long right, CORBA::Long bottom, CORBA::Long color, CORBA::Environment &_ev)
{
  return this->servant_->AddRect (left, top, right, bottom, color, _ev);
}

CORBA::Long _tao_collocated_Server::DelRect(CORBA::Long left, CORBA::Long top, CORBA::Long right, CORBA::Long bottom, CORBA::Environment &_ev)
{
  return this->servant_->DelRect (left, top, right, bottom, _ev);
}

CORBA::Long _tao_collocated_Server::SetTurtle(CORBA::Long x, CORBA::Long y, CORBA::Long angle, CORBA::Environment &_ev)
{
  return this->servant_->SetTurtle (x, y, angle, _ev);
}

CORBA::Long _tao_collocated_Server::GetTurtle(::CORBA::Long &x, ::CORBA::Long &y, ::CORBA::Long &angle, CORBA::Environment &_ev)
{
  return this->servant_->GetTurtle (x, y, angle, _ev);
}

CORBA::Boolean _tao_collocated_Server::_is_a(const char *type_id, CORBA::Environment &_ev)
{
  return this->servant_->_is_a (type_id, _ev);
}

int flick_marshal_stub_Server(flick_marshal_stream_t _stream, Server_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, Server , _flick_abort0);
  return 0;
  {
  _flick_abort0:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_Server(flick_marshal_stream_t _stream, Server_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, Server , _flick_abort1);
  return 0;
  {
  _flick_abort1:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_Server_swap(flick_marshal_stream_t _stream, Server_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, Server , _flick_abort2);
  return 0;
  {
  _flick_abort2:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

void POA_Server::_dispatch(CORBA::ServerRequest &_tao_req, void *_tao_context, CORBA::Environment &_tao_env){
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_InputCDR &_in_cdr = _tao_req.incoming();
  TAO_OutputCDR &_out_cdr = _tao_req.outgoing();
  flick_iiopxx_server_start_decode();
  _stub_state.state = FLICK_STATE_PROLOGUE;
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  if (_in_cdr.do_byte_swap()) {
  {
    unsigned int _t93_switch_tag;

    flick_iiopxx_decode_new_glob(20);
    flick_iiopxx_check_span(16, _flick_abort5);
    flick_iiopxx_decode_new_chunk(4);
    flick_cdr_swap_decode_unsigned32(0, _t93_switch_tag, unsigned int );
    flick_iiopxx_decode_end_chunk(4);
    switch ((unsigned int )_t93_switch_tag)
      {
      case (unsigned int) 8:
        {
          unsigned int _t94_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t94_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t94_switch_tag)
            {
            case /* SetS */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1399157843):
              {
                unsigned int _t95_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t95_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t95_switch_tag)
                  {
                  case /* ize */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1769628928):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t96_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_width;
                        CORBA::Long _local_height;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort231);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _t96_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t96_principal_len, _flick_abort231);
                        flick_iiopxx_decode_new_glob(_t96_principal_len);
                        flick_iiopxx_decode_new_chunk(_t96_principal_len);
                        flick_iiopxx_decode_end_chunk(_t96_principal_len);
                        flick_iiopxx_decode_end_glob(_t96_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(11);
                        flick_iiopxx_decode_new_chunk_align(8, 2, 0, 0);
                        flick_iiopxx_check_span(8, _flick_abort231);
                        flick_cdr_swap_decode_signed32(0, _local_width, CORBA::Long );
                        flick_cdr_swap_decode_signed32(4, _local_height, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(8);
                        flick_iiopxx_decode_end_glob(11);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->SetSize(_local_width, _local_height, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t97_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t97_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort231);
                          flick_iiopxx_encode_new_glob(8, _flick_abort231);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t97_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t97_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort237);
                                break;
                                {
                                _flick_abort237:
                                  goto _flick_abort231;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort238);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort238:
                                  goto _flick_abort231;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort231:
                          goto _flick_abort230;
                        }
                      }
                      break;
                      {
                      _flick_abort230:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* AddW */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1097098327):
              {
                unsigned int _t98_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t98_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t98_switch_tag)
                  {
                  case /* all */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1634495488):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t99_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_startx;
                        CORBA::Long _local_starty;
                        CORBA::Long _local_endx;
                        CORBA::Long _local_endy;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort240);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _t99_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t99_principal_len, _flick_abort240);
                        flick_iiopxx_decode_new_glob(_t99_principal_len);
                        flick_iiopxx_decode_new_chunk(_t99_principal_len);
                        flick_iiopxx_decode_end_chunk(_t99_principal_len);
                        flick_iiopxx_decode_end_glob(_t99_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(19);
                        flick_iiopxx_decode_new_chunk_align(16, 2, 0, 0);
                        flick_iiopxx_check_span(16, _flick_abort240);
                        flick_cdr_swap_decode_signed32(0, _local_startx, CORBA::Long );
                        flick_cdr_swap_decode_signed32(4, _local_starty, CORBA::Long );
                        flick_cdr_swap_decode_signed32(8, _local_endx, CORBA::Long );
                        flick_cdr_swap_decode_signed32(12, _local_endy, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(19);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->AddWall(_local_startx, _local_starty, _local_endx, _local_endy, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t100_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t100_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort240);
                          flick_iiopxx_encode_new_glob(8, _flick_abort240);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t100_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t100_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort246);
                                break;
                                {
                                _flick_abort246:
                                  goto _flick_abort240;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort247);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort247:
                                  goto _flick_abort240;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort240:
                          goto _flick_abort239;
                        }
                      }
                      break;
                      {
                      _flick_abort239:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* DelW */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1147497559):
              {
                unsigned int _t101_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t101_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t101_switch_tag)
                  {
                  case /* all */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1634495488):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t102_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_startx;
                        CORBA::Long _local_starty;
                        CORBA::Long _local_endx;
                        CORBA::Long _local_endy;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort249);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _t102_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t102_principal_len, _flick_abort249);
                        flick_iiopxx_decode_new_glob(_t102_principal_len);
                        flick_iiopxx_decode_new_chunk(_t102_principal_len);
                        flick_iiopxx_decode_end_chunk(_t102_principal_len);
                        flick_iiopxx_decode_end_glob(_t102_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(19);
                        flick_iiopxx_decode_new_chunk_align(16, 2, 0, 0);
                        flick_iiopxx_check_span(16, _flick_abort249);
                        flick_cdr_swap_decode_signed32(0, _local_startx, CORBA::Long );
                        flick_cdr_swap_decode_signed32(4, _local_starty, CORBA::Long );
                        flick_cdr_swap_decode_signed32(8, _local_endx, CORBA::Long );
                        flick_cdr_swap_decode_signed32(12, _local_endy, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(19);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->DelWall(_local_startx, _local_starty, _local_endx, _local_endy, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t103_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t103_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort249);
                          flick_iiopxx_encode_new_glob(8, _flick_abort249);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t103_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t103_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort255);
                                break;
                                {
                                _flick_abort255:
                                  goto _flick_abort249;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort256);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort256:
                                  goto _flick_abort249;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort249:
                          goto _flick_abort248;
                        }
                      }
                      break;
                      {
                      _flick_abort248:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* AddR */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1097098322):
              {
                unsigned int _t104_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t104_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t104_switch_tag)
                  {
                  case /* ect */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1701016576):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t105_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_left;
                        CORBA::Long _local_top;
                        CORBA::Long _local_right;
                        CORBA::Long _local_bottom;
                        CORBA::Long _local_color;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort258);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _t105_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t105_principal_len, _flick_abort258);
                        flick_iiopxx_decode_new_glob(_t105_principal_len);
                        flick_iiopxx_decode_new_chunk(_t105_principal_len);
                        flick_iiopxx_decode_end_chunk(_t105_principal_len);
                        flick_iiopxx_decode_end_glob(_t105_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(23);
                        flick_iiopxx_decode_new_chunk_align(20, 2, 0, 0);
                        flick_iiopxx_check_span(20, _flick_abort258);
                        flick_cdr_swap_decode_signed32(0, _local_left, CORBA::Long );
                        flick_cdr_swap_decode_signed32(4, _local_top, CORBA::Long );
                        flick_cdr_swap_decode_signed32(8, _local_right, CORBA::Long );
                        flick_cdr_swap_decode_signed32(12, _local_bottom, CORBA::Long );
                        flick_cdr_swap_decode_signed32(16, _local_color, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(20);
                        flick_iiopxx_decode_end_glob(23);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->AddRect(_local_left, _local_top, _local_right, _local_bottom, _local_color, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t106_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t106_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort258);
                          flick_iiopxx_encode_new_glob(8, _flick_abort258);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t106_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t106_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort264);
                                break;
                                {
                                _flick_abort264:
                                  goto _flick_abort258;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort265);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort265:
                                  goto _flick_abort258;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort258:
                          goto _flick_abort257;
                        }
                      }
                      break;
                      {
                      _flick_abort257:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* DelR */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1147497554):
              {
                unsigned int _t107_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t107_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t107_switch_tag)
                  {
                  case /* ect */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1701016576):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t108_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_left;
                        CORBA::Long _local_top;
                        CORBA::Long _local_right;
                        CORBA::Long _local_bottom;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort267);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_swap_decode_unsigned32(0, _t108_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t108_principal_len, _flick_abort267);
                        flick_iiopxx_decode_new_glob(_t108_principal_len);
                        flick_iiopxx_decode_new_chunk(_t108_principal_len);
                        flick_iiopxx_decode_end_chunk(_t108_principal_len);
                        flick_iiopxx_decode_end_glob(_t108_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(19);
                        flick_iiopxx_decode_new_chunk_align(16, 2, 0, 0);
                        flick_iiopxx_check_span(16, _flick_abort267);
                        flick_cdr_swap_decode_signed32(0, _local_left, CORBA::Long );
                        flick_cdr_swap_decode_signed32(4, _local_top, CORBA::Long );
                        flick_cdr_swap_decode_signed32(8, _local_right, CORBA::Long );
                        flick_cdr_swap_decode_signed32(12, _local_bottom, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(19);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->DelRect(_local_left, _local_top, _local_right, _local_bottom, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t109_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t109_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort267);
                          flick_iiopxx_encode_new_glob(8, _flick_abort267);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t109_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t109_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort273);
                                break;
                                {
                                _flick_abort273:
                                  goto _flick_abort267;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort274);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort274:
                                  goto _flick_abort267;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort267:
                          goto _flick_abort266;
                        }
                      }
                      break;
                      {
                      _flick_abort266:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(20);
                break;
              }
            }
          break;
        }
      case (unsigned int) 10:
        {
          unsigned int _t110_switch_tag;

          flick_iiopxx_check_span(16, _flick_abort5);
          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t110_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t110_switch_tag)
            {
            case /* SetT */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1399157844):
              {
                unsigned int _t111_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t111_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t111_switch_tag)
                  {
                  case /* urtl */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1970435180):
                    {
                      unsigned short int _t112_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t112_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t112_switch_tag)
                        {
                        case /* e */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25856):
                          {
                            {
                              POA_Server *_local_this;
                              unsigned int _t113_principal_len;
                              CORBA::Long _return;
                              CORBA::Long _local_x;
                              CORBA::Long _local_y;
                              CORBA::Long _local_angle;
                              CORBA::Environment _ev;

                              flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort276);
                              /* Decode the requesting `Principal' pseudo object (client ID). */
                              flick_iiopxx_decode_new_chunk(6);
                              flick_cdr_swap_decode_unsigned32(2, _t113_principal_len, unsigned int );
                              flick_iiopxx_decode_end_chunk(6);
                              flick_iiopxx_decode_end_glob(20);
                              flick_iiopxx_check_span(_t113_principal_len, _flick_abort276);
                              flick_iiopxx_decode_new_glob(_t113_principal_len);
                              flick_iiopxx_decode_new_chunk(_t113_principal_len);
                              flick_iiopxx_decode_end_chunk(_t113_principal_len);
                              flick_iiopxx_decode_end_glob(_t113_principal_len);
                              /* Begin decode phase on parameters */
                              _return = 0;
                              flick_iiopxx_decode_new_glob(15);
                              flick_iiopxx_decode_new_chunk_align(12, 2, 0, 0);
                              flick_iiopxx_check_span(12, _flick_abort276);
                              flick_cdr_swap_decode_signed32(0, _local_x, CORBA::Long );
                              flick_cdr_swap_decode_signed32(4, _local_y, CORBA::Long );
                              flick_cdr_swap_decode_signed32(8, _local_angle, CORBA::Long );
                              flick_iiopxx_decode_end_chunk(12);
                              flick_iiopxx_decode_end_glob(15);
                              flick_iiopxx_server_end_decode();
                              flick_corbaxx_init_environment();
                              _return = _local_this->SetTurtle(_local_x, _local_y, _local_angle, _ev);
                              _stub_state.state = FLICK_STATE_MARSHAL;
                              flick_iiopxx_server_start_encode();
                              {
                                int _t114_temp_major;

                                flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t114_temp_major);

                                flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort276);
                                flick_iiopxx_encode_new_glob(8, _flick_abort276);
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _t114_temp_major, int );
                                flick_iiopxx_encode_end_chunk(4);
                                switch (_t114_temp_major)
                                  {
                                  case CORBA::NO_EXCEPTION:
                                    {
                                      /* Begin encode phase on parameters */
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                      flick_iiopxx_encode_end_chunk(4);
                                      flick_iiopxx_encode_end_glob(8);
                                      break;
                                    }
                                  case CORBA::SYSTEM_EXCEPTION:
                                    {
                                      flick_iiopxx_encode_end_glob(8);
                                      flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort282);
                                      break;
                                      {
                                      _flick_abort282:
                                        goto _flick_abort276;
                                      }
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort283);
                                      flick_iiopxx_encode_end_glob(8);
                                      break;
                                      {
                                      _flick_abort283:
                                        goto _flick_abort276;
                                      }
                                    }
                                  }
                              }
                              flick_iiopxx_server_end_encode();
                              break;
                              {
                              _flick_abort276:
                                goto _flick_abort275;
                              }
                            }
                            break;
                            {
                            _flick_abort275:
                              goto _flick_abort5;
                            }
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(20);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* GetT */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1197831252):
              {
                unsigned int _t115_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t115_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t115_switch_tag)
                  {
                  case /* urtl */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1970435180):
                    {
                      unsigned short int _t116_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t116_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t116_switch_tag)
                        {
                        case /* e */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25856):
                          {
                            {
                              POA_Server *_local_this;
                              unsigned int _t117_principal_len;
                              CORBA::Long _return;
                              CORBA::Long _local_x;
                              CORBA::Long _local_y;
                              CORBA::Long _local_angle;
                              CORBA::Environment _ev;

                              flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort285);
                              /* Decode the requesting `Principal' pseudo object (client ID). */
                              flick_iiopxx_decode_new_chunk(6);
                              flick_cdr_swap_decode_unsigned32(2, _t117_principal_len, unsigned int );
                              flick_iiopxx_decode_end_chunk(6);
                              flick_iiopxx_decode_end_glob(20);
                              flick_iiopxx_check_span(_t117_principal_len, _flick_abort285);
                              flick_iiopxx_decode_new_glob(_t117_principal_len);
                              flick_iiopxx_decode_new_chunk(_t117_principal_len);
                              flick_iiopxx_decode_end_chunk(_t117_principal_len);
                              flick_iiopxx_decode_end_glob(_t117_principal_len);
                              /* Begin decode phase on parameters */
                              _return = 0;
                              flick_iiopxx_server_end_decode();
                              flick_corbaxx_init_environment();
                              _return = _local_this->GetTurtle(_local_x, _local_y, _local_angle, _ev);
                              _stub_state.state = FLICK_STATE_MARSHAL;
                              flick_iiopxx_server_start_encode();
                              {
                                int _t118_temp_major;

                                flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t118_temp_major);

                                flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort285);
                                flick_iiopxx_encode_new_glob(20, _flick_abort285);
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _t118_temp_major, int );
                                flick_iiopxx_encode_end_chunk(4);
                                switch (_t118_temp_major)
                                  {
                                  case CORBA::NO_EXCEPTION:
                                    {
                                      /* Begin encode phase on parameters */
                                      flick_iiopxx_encode_new_chunk(16);
                                      flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                      flick_cdr_encode_signed32(4, _local_x, CORBA::Long );
                                      flick_cdr_encode_signed32(8, _local_y, CORBA::Long );
                                      flick_cdr_encode_signed32(12, _local_angle, CORBA::Long );
                                      flick_iiopxx_encode_end_chunk(16);
                                      flick_iiopxx_encode_end_glob(20);
                                      break;
                                    }
                                  case CORBA::SYSTEM_EXCEPTION:
                                    {
                                      flick_iiopxx_encode_end_glob(20);
                                      flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort291);
                                      break;
                                      {
                                      _flick_abort291:
                                        goto _flick_abort285;
                                      }
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort292);
                                      flick_iiopxx_encode_end_glob(20);
                                      break;
                                      {
                                      _flick_abort292:
                                        goto _flick_abort285;
                                      }
                                    }
                                  }
                              }
                              flick_iiopxx_server_end_encode();
                              break;
                              {
                              _flick_abort285:
                                goto _flick_abort284;
                              }
                            }
                            break;
                            {
                            _flick_abort284:
                              goto _flick_abort5;
                            }
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(20);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(20);
                break;
              }
            }
          break;
        }
      case (unsigned int) 6:
        {
          unsigned int _t119_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t119_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t119_switch_tag)
            {
            case /* _is_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1600746335):
              {
                unsigned short int _t120_switch_tag;

                flick_iiopxx_decode_new_chunk(2);
                flick_cdr_decode_unsigned16(0, _t120_switch_tag, unsigned short int );
                flick_iiopxx_decode_end_chunk(2);
                switch ((unsigned short int )_t120_switch_tag)
                  {
                  case /* a */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 24832):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t121_principal_len;
                        CORBA::Boolean _return;
                        char *_local_type_id;
                        flick_unsigned32_t _t122_temp_string_len;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr_swap, _flick_abort294);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(6);
                        flick_cdr_swap_decode_unsigned32(2, _t121_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(6);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t121_principal_len, _flick_abort294);
                        flick_iiopxx_decode_new_glob(_t121_principal_len);
                        flick_iiopxx_decode_new_chunk(_t121_principal_len);
                        flick_iiopxx_decode_end_chunk(_t121_principal_len);
                        flick_iiopxx_decode_end_glob(_t121_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort294);
                        flick_cdr_swap_decode_unsigned32(0, _t122_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        flick_iiopxx_decode_new_glob(1 * _t122_temp_string_len);
                        flick_iiopxx_check_span(1 * _t122_temp_string_len, _flick_abort294);
                        flick_iiopxx_decode_new_chunk(1 * _t122_temp_string_len);
                        flick_cdr_swap_decode_msgptr(0, _local_type_id, CORBA::Char *);
                        flick_iiopxx_decode_end_chunk(1 * _t122_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t122_temp_string_len);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->_is_a(_local_type_id, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t123_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t123_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort294);
                          flick_iiopxx_encode_new_glob(5, _flick_abort294);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t123_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t123_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(1);
                                flick_cdr_encode_unsigned8(0, _return, CORBA::Boolean );
                                flick_iiopxx_encode_end_chunk(1);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(5);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort302);
                                break;
                                {
                                _flick_abort302:
                                  goto _flick_abort294;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort303);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                                {
                                _flick_abort303:
                                  goto _flick_abort294;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort294:
                          goto _flick_abort293;
                        }
                      }
                      break;
                      {
                      _flick_abort293:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(20);
                break;
              }
            }
          break;
        }
      default:
        {
          flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
          flick_iiopxx_decode_end_glob(20);
          break;
        }
      }
  }
  } else {
  {
    unsigned int _t31_switch_tag;

    flick_iiopxx_decode_new_glob(20);
    flick_iiopxx_check_span(16, _flick_abort5);
    flick_iiopxx_decode_new_chunk(4);
    flick_cdr_decode_unsigned32(0, _t31_switch_tag, unsigned int );
    flick_iiopxx_decode_end_chunk(4);
    switch ((unsigned int )_t31_switch_tag)
      {
      case (unsigned int) 8:
        {
          unsigned int _t32_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t32_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t32_switch_tag)
            {
            case /* SetS */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1399157843):
              {
                unsigned int _t33_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t33_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t33_switch_tag)
                  {
                  case /* ize */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1769628928):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t34_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_width;
                        CORBA::Long _local_height;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort82);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _t34_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t34_principal_len, _flick_abort82);
                        flick_iiopxx_decode_new_glob(_t34_principal_len);
                        flick_iiopxx_decode_new_chunk(_t34_principal_len);
                        flick_iiopxx_decode_end_chunk(_t34_principal_len);
                        flick_iiopxx_decode_end_glob(_t34_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(11);
                        flick_iiopxx_decode_new_chunk_align(8, 2, 0, 0);
                        flick_iiopxx_check_span(8, _flick_abort82);
                        flick_cdr_decode_signed32(0, _local_width, CORBA::Long );
                        flick_cdr_decode_signed32(4, _local_height, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(8);
                        flick_iiopxx_decode_end_glob(11);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->SetSize(_local_width, _local_height, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t35_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t35_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort82);
                          flick_iiopxx_encode_new_glob(8, _flick_abort82);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t35_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t35_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort88);
                                break;
                                {
                                _flick_abort88:
                                  goto _flick_abort82;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort89);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort89:
                                  goto _flick_abort82;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort82:
                          goto _flick_abort81;
                        }
                      }
                      break;
                      {
                      _flick_abort81:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* AddW */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1097098327):
              {
                unsigned int _t36_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t36_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t36_switch_tag)
                  {
                  case /* all */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1634495488):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t37_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_startx;
                        CORBA::Long _local_starty;
                        CORBA::Long _local_endx;
                        CORBA::Long _local_endy;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort91);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _t37_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t37_principal_len, _flick_abort91);
                        flick_iiopxx_decode_new_glob(_t37_principal_len);
                        flick_iiopxx_decode_new_chunk(_t37_principal_len);
                        flick_iiopxx_decode_end_chunk(_t37_principal_len);
                        flick_iiopxx_decode_end_glob(_t37_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(19);
                        flick_iiopxx_decode_new_chunk_align(16, 2, 0, 0);
                        flick_iiopxx_check_span(16, _flick_abort91);
                        flick_cdr_decode_signed32(0, _local_startx, CORBA::Long );
                        flick_cdr_decode_signed32(4, _local_starty, CORBA::Long );
                        flick_cdr_decode_signed32(8, _local_endx, CORBA::Long );
                        flick_cdr_decode_signed32(12, _local_endy, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(19);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->AddWall(_local_startx, _local_starty, _local_endx, _local_endy, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t38_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t38_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort91);
                          flick_iiopxx_encode_new_glob(8, _flick_abort91);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t38_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t38_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort97);
                                break;
                                {
                                _flick_abort97:
                                  goto _flick_abort91;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort98);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort98:
                                  goto _flick_abort91;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort91:
                          goto _flick_abort90;
                        }
                      }
                      break;
                      {
                      _flick_abort90:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* DelW */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1147497559):
              {
                unsigned int _t39_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t39_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t39_switch_tag)
                  {
                  case /* all */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1634495488):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t40_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_startx;
                        CORBA::Long _local_starty;
                        CORBA::Long _local_endx;
                        CORBA::Long _local_endy;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort100);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _t40_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t40_principal_len, _flick_abort100);
                        flick_iiopxx_decode_new_glob(_t40_principal_len);
                        flick_iiopxx_decode_new_chunk(_t40_principal_len);
                        flick_iiopxx_decode_end_chunk(_t40_principal_len);
                        flick_iiopxx_decode_end_glob(_t40_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(19);
                        flick_iiopxx_decode_new_chunk_align(16, 2, 0, 0);
                        flick_iiopxx_check_span(16, _flick_abort100);
                        flick_cdr_decode_signed32(0, _local_startx, CORBA::Long );
                        flick_cdr_decode_signed32(4, _local_starty, CORBA::Long );
                        flick_cdr_decode_signed32(8, _local_endx, CORBA::Long );
                        flick_cdr_decode_signed32(12, _local_endy, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(19);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->DelWall(_local_startx, _local_starty, _local_endx, _local_endy, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t41_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t41_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort100);
                          flick_iiopxx_encode_new_glob(8, _flick_abort100);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t41_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t41_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort106);
                                break;
                                {
                                _flick_abort106:
                                  goto _flick_abort100;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort107);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort107:
                                  goto _flick_abort100;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort100:
                          goto _flick_abort99;
                        }
                      }
                      break;
                      {
                      _flick_abort99:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* AddR */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1097098322):
              {
                unsigned int _t42_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t42_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t42_switch_tag)
                  {
                  case /* ect */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1701016576):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t43_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_left;
                        CORBA::Long _local_top;
                        CORBA::Long _local_right;
                        CORBA::Long _local_bottom;
                        CORBA::Long _local_color;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort109);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _t43_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t43_principal_len, _flick_abort109);
                        flick_iiopxx_decode_new_glob(_t43_principal_len);
                        flick_iiopxx_decode_new_chunk(_t43_principal_len);
                        flick_iiopxx_decode_end_chunk(_t43_principal_len);
                        flick_iiopxx_decode_end_glob(_t43_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(23);
                        flick_iiopxx_decode_new_chunk_align(20, 2, 0, 0);
                        flick_iiopxx_check_span(20, _flick_abort109);
                        flick_cdr_decode_signed32(0, _local_left, CORBA::Long );
                        flick_cdr_decode_signed32(4, _local_top, CORBA::Long );
                        flick_cdr_decode_signed32(8, _local_right, CORBA::Long );
                        flick_cdr_decode_signed32(12, _local_bottom, CORBA::Long );
                        flick_cdr_decode_signed32(16, _local_color, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(20);
                        flick_iiopxx_decode_end_glob(23);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->AddRect(_local_left, _local_top, _local_right, _local_bottom, _local_color, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t44_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t44_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort109);
                          flick_iiopxx_encode_new_glob(8, _flick_abort109);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t44_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t44_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort115);
                                break;
                                {
                                _flick_abort115:
                                  goto _flick_abort109;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort116);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort116:
                                  goto _flick_abort109;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort109:
                          goto _flick_abort108;
                        }
                      }
                      break;
                      {
                      _flick_abort108:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* DelR */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1147497554):
              {
                unsigned int _t45_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t45_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t45_switch_tag)
                  {
                  case /* ect */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1701016576):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t46_principal_len;
                        CORBA::Long _return;
                        CORBA::Long _local_left;
                        CORBA::Long _local_top;
                        CORBA::Long _local_right;
                        CORBA::Long _local_bottom;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort118);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(4);
                        flick_cdr_decode_unsigned32(0, _t46_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t46_principal_len, _flick_abort118);
                        flick_iiopxx_decode_new_glob(_t46_principal_len);
                        flick_iiopxx_decode_new_chunk(_t46_principal_len);
                        flick_iiopxx_decode_end_chunk(_t46_principal_len);
                        flick_iiopxx_decode_end_glob(_t46_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(19);
                        flick_iiopxx_decode_new_chunk_align(16, 2, 0, 0);
                        flick_iiopxx_check_span(16, _flick_abort118);
                        flick_cdr_decode_signed32(0, _local_left, CORBA::Long );
                        flick_cdr_decode_signed32(4, _local_top, CORBA::Long );
                        flick_cdr_decode_signed32(8, _local_right, CORBA::Long );
                        flick_cdr_decode_signed32(12, _local_bottom, CORBA::Long );
                        flick_iiopxx_decode_end_chunk(16);
                        flick_iiopxx_decode_end_glob(19);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->DelRect(_local_left, _local_top, _local_right, _local_bottom, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t47_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t47_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort118);
                          flick_iiopxx_encode_new_glob(8, _flick_abort118);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t47_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t47_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                flick_iiopxx_encode_end_chunk(4);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(8);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort124);
                                break;
                                {
                                _flick_abort124:
                                  goto _flick_abort118;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort125);
                                flick_iiopxx_encode_end_glob(8);
                                break;
                                {
                                _flick_abort125:
                                  goto _flick_abort118;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort118:
                          goto _flick_abort117;
                        }
                      }
                      break;
                      {
                      _flick_abort117:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(20);
                break;
              }
            }
          break;
        }
      case (unsigned int) 10:
        {
          unsigned int _t48_switch_tag;

          flick_iiopxx_check_span(16, _flick_abort5);
          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t48_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t48_switch_tag)
            {
            case /* SetT */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1399157844):
              {
                unsigned int _t49_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t49_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t49_switch_tag)
                  {
                  case /* urtl */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1970435180):
                    {
                      unsigned short int _t50_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t50_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t50_switch_tag)
                        {
                        case /* e */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25856):
                          {
                            {
                              POA_Server *_local_this;
                              unsigned int _t51_principal_len;
                              CORBA::Long _return;
                              CORBA::Long _local_x;
                              CORBA::Long _local_y;
                              CORBA::Long _local_angle;
                              CORBA::Environment _ev;

                              flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort127);
                              /* Decode the requesting `Principal' pseudo object (client ID). */
                              flick_iiopxx_decode_new_chunk(6);
                              flick_cdr_decode_unsigned32(2, _t51_principal_len, unsigned int );
                              flick_iiopxx_decode_end_chunk(6);
                              flick_iiopxx_decode_end_glob(20);
                              flick_iiopxx_check_span(_t51_principal_len, _flick_abort127);
                              flick_iiopxx_decode_new_glob(_t51_principal_len);
                              flick_iiopxx_decode_new_chunk(_t51_principal_len);
                              flick_iiopxx_decode_end_chunk(_t51_principal_len);
                              flick_iiopxx_decode_end_glob(_t51_principal_len);
                              /* Begin decode phase on parameters */
                              _return = 0;
                              flick_iiopxx_decode_new_glob(15);
                              flick_iiopxx_decode_new_chunk_align(12, 2, 0, 0);
                              flick_iiopxx_check_span(12, _flick_abort127);
                              flick_cdr_decode_signed32(0, _local_x, CORBA::Long );
                              flick_cdr_decode_signed32(4, _local_y, CORBA::Long );
                              flick_cdr_decode_signed32(8, _local_angle, CORBA::Long );
                              flick_iiopxx_decode_end_chunk(12);
                              flick_iiopxx_decode_end_glob(15);
                              flick_iiopxx_server_end_decode();
                              flick_corbaxx_init_environment();
                              _return = _local_this->SetTurtle(_local_x, _local_y, _local_angle, _ev);
                              _stub_state.state = FLICK_STATE_MARSHAL;
                              flick_iiopxx_server_start_encode();
                              {
                                int _t52_temp_major;

                                flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t52_temp_major);

                                flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort127);
                                flick_iiopxx_encode_new_glob(8, _flick_abort127);
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _t52_temp_major, int );
                                flick_iiopxx_encode_end_chunk(4);
                                switch (_t52_temp_major)
                                  {
                                  case CORBA::NO_EXCEPTION:
                                    {
                                      /* Begin encode phase on parameters */
                                      flick_iiopxx_encode_new_chunk(4);
                                      flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                      flick_iiopxx_encode_end_chunk(4);
                                      flick_iiopxx_encode_end_glob(8);
                                      break;
                                    }
                                  case CORBA::SYSTEM_EXCEPTION:
                                    {
                                      flick_iiopxx_encode_end_glob(8);
                                      flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort133);
                                      break;
                                      {
                                      _flick_abort133:
                                        goto _flick_abort127;
                                      }
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort134);
                                      flick_iiopxx_encode_end_glob(8);
                                      break;
                                      {
                                      _flick_abort134:
                                        goto _flick_abort127;
                                      }
                                    }
                                  }
                              }
                              flick_iiopxx_server_end_encode();
                              break;
                              {
                              _flick_abort127:
                                goto _flick_abort126;
                              }
                            }
                            break;
                            {
                            _flick_abort126:
                              goto _flick_abort5;
                            }
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(20);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            case /* GetT */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1197831252):
              {
                unsigned int _t53_switch_tag;

                flick_iiopxx_decode_new_chunk(4);
                flick_cdr_decode_unsigned32(0, _t53_switch_tag, unsigned int );
                flick_iiopxx_decode_end_chunk(4);
                switch ((unsigned int )_t53_switch_tag)
                  {
                  case /* urtl */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1970435180):
                    {
                      unsigned short int _t54_switch_tag;

                      flick_iiopxx_decode_new_chunk(2);
                      flick_cdr_decode_unsigned16(0, _t54_switch_tag, unsigned short int );
                      flick_iiopxx_decode_end_chunk(2);
                      switch ((unsigned short int )_t54_switch_tag)
                        {
                        case /* e */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 25856):
                          {
                            {
                              POA_Server *_local_this;
                              unsigned int _t55_principal_len;
                              CORBA::Long _return;
                              CORBA::Long _local_x;
                              CORBA::Long _local_y;
                              CORBA::Long _local_angle;
                              CORBA::Environment _ev;

                              flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort136);
                              /* Decode the requesting `Principal' pseudo object (client ID). */
                              flick_iiopxx_decode_new_chunk(6);
                              flick_cdr_decode_unsigned32(2, _t55_principal_len, unsigned int );
                              flick_iiopxx_decode_end_chunk(6);
                              flick_iiopxx_decode_end_glob(20);
                              flick_iiopxx_check_span(_t55_principal_len, _flick_abort136);
                              flick_iiopxx_decode_new_glob(_t55_principal_len);
                              flick_iiopxx_decode_new_chunk(_t55_principal_len);
                              flick_iiopxx_decode_end_chunk(_t55_principal_len);
                              flick_iiopxx_decode_end_glob(_t55_principal_len);
                              /* Begin decode phase on parameters */
                              _return = 0;
                              flick_iiopxx_server_end_decode();
                              flick_corbaxx_init_environment();
                              _return = _local_this->GetTurtle(_local_x, _local_y, _local_angle, _ev);
                              _stub_state.state = FLICK_STATE_MARSHAL;
                              flick_iiopxx_server_start_encode();
                              {
                                int _t56_temp_major;

                                flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t56_temp_major);

                                flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort136);
                                flick_iiopxx_encode_new_glob(20, _flick_abort136);
                                flick_iiopxx_encode_new_chunk(4);
                                flick_cdr_encode_signed32(0, _t56_temp_major, int );
                                flick_iiopxx_encode_end_chunk(4);
                                switch (_t56_temp_major)
                                  {
                                  case CORBA::NO_EXCEPTION:
                                    {
                                      /* Begin encode phase on parameters */
                                      flick_iiopxx_encode_new_chunk(16);
                                      flick_cdr_encode_signed32(0, _return, CORBA::Long );
                                      flick_cdr_encode_signed32(4, _local_x, CORBA::Long );
                                      flick_cdr_encode_signed32(8, _local_y, CORBA::Long );
                                      flick_cdr_encode_signed32(12, _local_angle, CORBA::Long );
                                      flick_iiopxx_encode_end_chunk(16);
                                      flick_iiopxx_encode_end_glob(20);
                                      break;
                                    }
                                  case CORBA::SYSTEM_EXCEPTION:
                                    {
                                      flick_iiopxx_encode_end_glob(20);
                                      flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort142);
                                      break;
                                      {
                                      _flick_abort142:
                                        goto _flick_abort136;
                                      }
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort143);
                                      flick_iiopxx_encode_end_glob(20);
                                      break;
                                      {
                                      _flick_abort143:
                                        goto _flick_abort136;
                                      }
                                    }
                                  }
                              }
                              flick_iiopxx_server_end_encode();
                              break;
                              {
                              _flick_abort136:
                                goto _flick_abort135;
                              }
                            }
                            break;
                            {
                            _flick_abort135:
                              goto _flick_abort5;
                            }
                          }
                        default:
                          {
                            flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                            flick_iiopxx_decode_end_glob(20);
                            break;
                          }
                        }
                      break;
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(20);
                break;
              }
            }
          break;
        }
      case (unsigned int) 6:
        {
          unsigned int _t57_switch_tag;

          flick_iiopxx_decode_new_chunk(4);
          flick_cdr_decode_unsigned32(0, _t57_switch_tag, unsigned int );
          flick_iiopxx_decode_end_chunk(4);
          switch ((unsigned int )_t57_switch_tag)
            {
            case /* _is_ */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1600746335):
              {
                unsigned short int _t58_switch_tag;

                flick_iiopxx_decode_new_chunk(2);
                flick_cdr_decode_unsigned16(0, _t58_switch_tag, unsigned short int );
                flick_iiopxx_decode_end_chunk(2);
                switch ((unsigned short int )_t58_switch_tag)
                  {
                  case /* a */ flick_cdr_convert_big_endian_to_local_unsigned16((unsigned short int) 24832):
                    {
                      {
                        POA_Server *_local_this;
                        unsigned int _t59_principal_len;
                        CORBA::Boolean _return;
                        char *_local_type_id;
                        flick_unsigned32_t _t60_temp_string_len;
                        CORBA::Environment _ev;

                        flick_iiopxx_server_decode_target(_local_this, 0, cdr, _flick_abort145);
                        /* Decode the requesting `Principal' pseudo object (client ID). */
                        flick_iiopxx_decode_new_chunk(6);
                        flick_cdr_decode_unsigned32(2, _t59_principal_len, unsigned int );
                        flick_iiopxx_decode_end_chunk(6);
                        flick_iiopxx_decode_end_glob(20);
                        flick_iiopxx_check_span(_t59_principal_len, _flick_abort145);
                        flick_iiopxx_decode_new_glob(_t59_principal_len);
                        flick_iiopxx_decode_new_chunk(_t59_principal_len);
                        flick_iiopxx_decode_end_chunk(_t59_principal_len);
                        flick_iiopxx_decode_end_glob(_t59_principal_len);
                        /* Begin decode phase on parameters */
                        _return = 0;
                        flick_iiopxx_decode_new_glob(7);
                        flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                        flick_iiopxx_check_span(4, _flick_abort145);
                        flick_cdr_decode_unsigned32(0, _t60_temp_string_len, flick_unsigned32_t );
                        flick_iiopxx_decode_end_chunk(4);
                        flick_iiopxx_decode_end_glob(7);
                        flick_iiopxx_decode_new_glob(1 * _t60_temp_string_len);
                        flick_iiopxx_check_span(1 * _t60_temp_string_len, _flick_abort145);
                        flick_iiopxx_decode_new_chunk(1 * _t60_temp_string_len);
                        flick_cdr_decode_msgptr(0, _local_type_id, CORBA::Char *);
                        flick_iiopxx_decode_end_chunk(1 * _t60_temp_string_len);
                        flick_iiopxx_decode_end_glob(1 * _t60_temp_string_len);
                        flick_iiopxx_server_end_decode();
                        flick_corbaxx_init_environment();
                        _return = _local_this->_is_a(_local_type_id, _ev);
                        _stub_state.state = FLICK_STATE_MARSHAL;
                        flick_iiopxx_server_start_encode();
                        {
                          int _t61_temp_major;

                          flick_corbaxx_get_major(CORBA::Environment &, _ev, int , _t61_temp_major);

                          flick_iiopxx_server_encode_target(_local_this, 0, cdr, _flick_abort145);
                          flick_iiopxx_encode_new_glob(5, _flick_abort145);
                          flick_iiopxx_encode_new_chunk(4);
                          flick_cdr_encode_signed32(0, _t61_temp_major, int );
                          flick_iiopxx_encode_end_chunk(4);
                          switch (_t61_temp_major)
                            {
                            case CORBA::NO_EXCEPTION:
                              {
                                /* Begin encode phase on parameters */
                                flick_iiopxx_encode_new_chunk(1);
                                flick_cdr_encode_unsigned8(0, _return, CORBA::Boolean );
                                flick_iiopxx_encode_end_chunk(1);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                              }
                            case CORBA::SYSTEM_EXCEPTION:
                              {
                                flick_iiopxx_encode_end_glob(5);
                                flick_corbaxx_encode_system_exception(_ev, cdr, iiopxx, _flick_abort153);
                                break;
                                {
                                _flick_abort153:
                                  goto _flick_abort145;
                                }
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort154);
                                flick_iiopxx_encode_end_glob(5);
                                break;
                                {
                                _flick_abort154:
                                  goto _flick_abort145;
                                }
                              }
                            }
                        }
                        flick_iiopxx_server_end_encode();
                        break;
                        {
                        _flick_abort145:
                          goto _flick_abort144;
                        }
                      }
                      break;
                      {
                      _flick_abort144:
                        goto _flick_abort5;
                      }
                    }
                  default:
                    {
                      flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                      flick_iiopxx_decode_end_glob(20);
                      break;
                    }
                  }
                break;
              }
            default:
              {
                flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
                flick_iiopxx_decode_end_glob(20);
                break;
              }
            }
          break;
        }
      default:
        {
          flick_stub_error(FLICK_ERROR_DECODE_SWITCH, _flick_abort5);
          flick_iiopxx_decode_end_glob(20);
          break;
        }
      }
  }
  }
  _stub_state.state = FLICK_STATE_EPILOGUE;
  return;
  {
  _flick_abort5:
    flick_corbaxx_server_error(cdr, iiopxx, _flick_reaper, _flick_abort4);
  _flick_abort4:
    return ;
  }
_flick_reaper:
  return ;
}

