#include "typedef_-client.h"
#include "typedef_-server.h"

static const CORBA::Long _oc_e[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    10, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x653a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:e:1.0 */,
    2, ACE_NTOHL(0x65000000) /* name = e */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_short,
      0
};

static CORBA::TypeCode _tc_TAO_tc_e (CORBA::tk_alias, sizeof(_oc_e), (char *) &_oc_e, 0, sizeof(e ));

CORBA::TypeCode_ptr _tc_e = &_tc_TAO_tc_e;

e::e()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

e::e(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = e::allocbuf(this->_maximum);
}

e::e(CORBA::ULong max, CORBA::ULong length, CORBA::Short *buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

e::e(const e &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  CORBA::Short  *tmp1 = e::allocbuf(this->_maximum);
  
  CORBA::Short  * const tmp2 = ACE_reinterpret_cast(CORBA::Short  * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  
  this->_buffer = tmp1;
}

e::~e()
{
  this->_deallocate_buffer();
}

e &e::operator=(const e &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      CORBA::Short  *tmp = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
      
      e::freebuf(tmp);
      this->_buffer = e::allocbuf(rhs._maximum);
    }
  
  }
  else
    this->_buffer = e::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Short  *tmp1 = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
  CORBA::Short  * const tmp2 = ACE_reinterpret_cast(CORBA::Short  * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  return *this;
}

CORBA::Short &e::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Short  * tmp = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
  return tmp[i];
}

const CORBA::Short &e::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Short  * const tmp = ACE_reinterpret_cast(CORBA::Short  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Short *e::allocbuf(CORBA::ULong size)
{
  CORBA::Short  *tmp;
  tmp = new CORBA::Short [size];
  return tmp;
}

void e::freebuf(CORBA::Short *buffer)
{
  delete [] buffer;
}

void e::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Short  *tmp = e::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Short  *old = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      e::freebuf(old);
  }
  this->_buffer = tmp;
}

void e::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  CORBA::Short  *tmp = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
  
  e::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean e::release() const
{
  return this->_release;
}

CORBA::ULong e::maximum() const
{
  return this->_maximum;
}

CORBA::ULong e::length() const
{
  return this->_length;
}

void e::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void e::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
}

CORBA::Short *e::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Short  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = e::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Short *e::get_buffer() const
{
  return ACE_const_cast(const CORBA::Short  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const e &o)
{
  e  *_any_val;
  ACE_NEW(_any_val, e  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_e, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, e *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_e, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, e *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_e, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (e  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, e , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_e, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_e, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

e_var::e_var()
  : ptr_(0)
{}

e_var::e_var(e *p)
 : ptr_(p)
{}

e_var::e_var(const e_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new e (*a.ptr_);
  else
    this->ptr_ = 0;
}

e_var::~e_var()
{
  delete this->ptr_;
}

e_var &e_var::operator=(e *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

e_var &e_var::operator=(const e_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new e (*p.ptr_);
  }
  return *this;
}

CORBA::Short &e_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Short &e_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

e *e_var::operator->()
{
  return this->ptr_;
}

const e *e_var::operator->() const
{
  return this->ptr_;
}

e_var::operator const e &() const
{
  return *this->ptr_;
}

e_var::operator e &()
{
  return *this->ptr_;
}

e_var::operator e &() const
{
  return *this->ptr_;
}

const e &e_var::in() const
{
  return *this->ptr_;
}

e &e_var::inout()
{
  return *this->ptr_;
}

e *&e_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

e *e_var::_retn()
{
  e  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

e *e_var::ptr() const
{
  return this->ptr_;
}

e_out::e_out(e *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

e_out::e_out(e_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

e_out::e_out(const e_out &r)
  : ptr_(ACE_const_cast(e_out &,r).ptr_)
{}

e_out &e_out::operator=(const e_out &r)
{
  this->ptr_ = ACE_const_cast(e_out &,r).ptr_;
  return *this;
}

e_out &e_out::operator=(e *r)
{
  this->ptr_ = r;
  return *this;
}

e_out::operator e *&()
{
  return this->ptr_;
}

e *&e_out::ptr()
{
  return this->ptr_;
}

CORBA::Short &e_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Short &e_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

e *e_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_g[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    10, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x673a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:g:1.0 */,
    2, ACE_NTOHL(0x67000000) /* name = g */,
    CORBA::tk_array,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_short,
      5
};

static CORBA::TypeCode _tc_TAO_tc_g (CORBA::tk_alias, sizeof(_oc_g), (char *) &_oc_g, 0, sizeof(g ));

CORBA::TypeCode_ptr _tc_g = &_tc_TAO_tc_g;

g_slice *g_alloc()
{
  return new g_slice [5];
}

g_slice *g_dup(const g_slice *_slice)
{
  g_slice  *_dup_array = g_alloc();
  if( !_dup_array ) return 0;
  g_copy(_dup_array, _slice);
  return _dup_array;
}

void g_copy(g_slice *_to_slice, const g_slice *_from_slice)
{
 CORBA::ULong iter0;
 for(iter0 = 0; iter0 < 5; iter0++) {
   _to_slice[iter0] = _from_slice[iter0];
 }
}

void g_free(g_slice *_slice)
{
  delete [] _slice;
}

void operator<<=(CORBA::Any &a, const g_forany &o)
{
  ACE_TRY_NEW_ENV
  {
    if(o.nocopy())
      a.replace(_tc_g, o.in(), 1, ACE_TRY_ENV);
    else
      a.replace(_tc_g, g_dup(o.in()), 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, g_forany &o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_g, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (g_slice  *)a.value();
      return 1;
    }
    else
    {
      o.out() = g_alloc();
      if(!o.in()) return 0;
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_g, o.inout(), 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_g, o.inout(), 1, ACE_TRY_ENV);
        return 1;
      }
      ACE_TRY_CHECK;
    }
  }
  ACE_CATCHANY
  {
    g_free(o._retn());
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

g_var::g_var()
  : ptr_(0)
{}

g_var::g_var(g_slice *p)
 : ptr_(p)
{}

g_var::g_var(const g_var &a)
{
  this->ptr_ = g_dup(a.ptr_);
}

g_var::~g_var()
{
  g_free(this->ptr_);
}

g_var &g_var::operator=(g_slice *p)
{
  if( this->ptr_ != p )
  {
    g_free(this->ptr_);
    this->ptr_ = p;
  }
  return *this;
}

g_var &g_var::operator=(const g_var &p)
{
  if( this != &p )
  {
    g_free(this->ptr_);
    this->ptr_ = g_dup(p.ptr_);
  }
  return *this;
}

g_slice &g_var::operator[](CORBA::ULong index)
{
  return this->ptr_[index];
}

const g_slice &g_var::operator[](CORBA::ULong index) const
{
  return this->ptr_[index];
}

g_var::operator g_slice *const &() const
{
  return this->ptr_;
}

g_var::operator g_slice *&()
{
  return this->ptr_;
}

const g_slice *g_var::in() const
{
  return this->ptr_;
}

g_slice *g_var::inout()
{
  return this->ptr_;
}

g_slice *&g_var::out()
{
  g_free(this->ptr_);
  this->ptr_ = (g_slice  *)0;
  return this->ptr_;
}

g_slice *g_var::_retn()
{
  g_slice  *tmp = this->ptr_;
  this->ptr_ = (g_slice  *)0;
  return tmp;
}

g_slice *g_var::ptr() const
{
  return this->ptr_;
}

g_forany::g_forany()
  : ptr_(0),
    nocopy_(0)
{}

g_forany::g_forany(g_slice *p, CORBA::Boolean nocopy)
  : ptr_(p),
    nocopy_(nocopy)
{}

g_forany::g_forany(const g_forany &a)
{
  this->ptr_ = g_dup(a.ptr_);
  this->nocopy_ = a.nocopy_;
}

g_forany::~g_forany()
{
}

g_forany &g_forany::operator=(g_slice *p)
{
  if( this->ptr_ != p )
  {
    g_free(this->ptr_);
    this->ptr_ = p;
  }
  return *this;
}

g_forany &g_forany::operator=(const g_forany &p)
{
  if( this != &p )
  {
    g_free(this->ptr_);
    this->ptr_ = g_dup(p.ptr_);
    this->nocopy_ = p.nocopy_;
  }
  return *this;
}

g_slice &g_forany::operator[](CORBA::ULong index)
{
  return this->ptr_[index];
}

const g_slice &g_forany::operator[](CORBA::ULong index) const
{
  return this->ptr_[index];
}

g_forany::operator g_slice *const &() const
{
  return this->ptr_;
}

g_forany::operator g_slice *&()
{
  return this->ptr_;
}

const g_slice *g_forany::in() const
{
  return this->ptr_;
}

g_slice *g_forany::inout()
{
  return this->ptr_;
}

g_slice *&g_forany::out()
{
  g_free(this->ptr_);
  this->ptr_ = (g_slice  *)0;
  return this->ptr_;
}

g_slice *g_forany::_retn()
{
  g_slice  *tmp = this->ptr_;
  this->ptr_ = (g_slice  *)0;
  return tmp;
}

g_slice *g_forany::ptr() const
{
  return this->ptr_;
}

CORBA::Boolean g_forany::nocopy() const
{
  return this->nocopy_;
}

static const CORBA::Long _oc_h[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    10, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x683a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:h:1.0 */,
    2, ACE_NTOHL(0x68000000) /* name = h */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_short,
      5
};

static CORBA::TypeCode _tc_TAO_tc_h (CORBA::tk_alias, sizeof(_oc_h), (char *) &_oc_h, 0, sizeof(h ));

CORBA::TypeCode_ptr _tc_h = &_tc_TAO_tc_h;

h::h()
  : _maximum(5),
    _length(0),
    _buffer(h::allocbuf(5)),
    _release(1)
{
}

h::h(CORBA::ULong length, CORBA::Short *buffer, CORBA::Boolean release)
  : _maximum(5),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

h::h(const h &o)
  : _maximum(5),
    _length(o._length),
    _release(1)
{
  CORBA::Short  *tmp1 = h::allocbuf(this->_maximum);
  
  CORBA::Short  * const tmp2 = ACE_reinterpret_cast(CORBA::Short  * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  
  this->_buffer = tmp1;
}

h::~h()
{
  this->_deallocate_buffer();
}

h &h::operator=(const h &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
  
  }
  else
    this->_buffer = h::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Short  *tmp1 = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
  CORBA::Short  * const tmp2 = ACE_reinterpret_cast(CORBA::Short  * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  return *this;
}

CORBA::Short &h::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Short  * tmp = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
  return tmp[i];
}

const CORBA::Short &h::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Short  * const tmp = ACE_reinterpret_cast(CORBA::Short  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Short *h::allocbuf(CORBA::ULong size)
{
  CORBA::Short  *tmp;
  tmp = new CORBA::Short [size];
  return tmp;
}

void h::freebuf(CORBA::Short *buffer)
{
  delete [] buffer;
}

void h::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Short  *tmp = h::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Short  *old = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      h::freebuf(old);
  }
  this->_buffer = tmp;
}

void h::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  CORBA::Short  *tmp = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
  
  h::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean h::release() const
{
  return this->_release;
}

CORBA::ULong h::maximum() const
{
  return 5;
}

CORBA::ULong h::length() const
{
  return this->_length;
}

void h::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    return;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void h::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
}

CORBA::Short *h::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Short  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = h::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Short  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Short *h::get_buffer() const
{
  return ACE_const_cast(const CORBA::Short  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const h &o)
{
  h  *_any_val;
  ACE_NEW(_any_val, h  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_h, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, h *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_h, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, h *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_h, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (h  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, h , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_h, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_h, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

h_var::h_var()
  : ptr_(0)
{}

h_var::h_var(h *p)
 : ptr_(p)
{}

h_var::h_var(const h_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new h (*a.ptr_);
  else
    this->ptr_ = 0;
}

h_var::~h_var()
{
  delete this->ptr_;
}

h_var &h_var::operator=(h *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

h_var &h_var::operator=(const h_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new h (*p.ptr_);
  }
  return *this;
}

CORBA::Short &h_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Short &h_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

h *h_var::operator->()
{
  return this->ptr_;
}

const h *h_var::operator->() const
{
  return this->ptr_;
}

h_var::operator const h &() const
{
  return *this->ptr_;
}

h_var::operator h &()
{
  return *this->ptr_;
}

h_var::operator h &() const
{
  return *this->ptr_;
}

const h &h_var::in() const
{
  return *this->ptr_;
}

h &h_var::inout()
{
  return *this->ptr_;
}

h *&h_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

h *h_var::_retn()
{
  h  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

h *h_var::ptr() const
{
  return this->ptr_;
}

h_out::h_out(h *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

h_out::h_out(h_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

h_out::h_out(const h_out &r)
  : ptr_(ACE_const_cast(h_out &,r).ptr_)
{}

h_out &h_out::operator=(const h_out &r)
{
  this->ptr_ = ACE_const_cast(h_out &,r).ptr_;
  return *this;
}

h_out &h_out::operator=(h *r)
{
  this->ptr_ = r;
  return *this;
}

h_out::operator h *&()
{
  return this->ptr_;
}

h *&h_out::ptr()
{
  return this->ptr_;
}

CORBA::Short &h_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Short &h_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

h *h_out::operator->()
{
  return this->ptr_;
}

int flick_marshal_stub_a(flick_marshal_stream_t _stream, const a *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(2, _flick_abort0);
  flick_iiopxx_encode_new_chunk(2);
  flick_cdr_encode_signed16(0, *_data, CORBA::Short );
  flick_iiopxx_encode_end_chunk(2);
  flick_iiopxx_encode_end_glob(2);
  return 0;
  {
  _flick_abort0:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_a(flick_marshal_stream_t _stream, a *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(2);
  flick_iiopxx_check_span(2, _flick_abort1);
  flick_iiopxx_decode_new_chunk(2);
  flick_cdr_decode_signed16(0, *_data, CORBA::Short );
  flick_iiopxx_decode_end_chunk(2);
  flick_iiopxx_decode_end_glob(2);
  return 0;
  {
  _flick_abort1:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_a_swap(flick_marshal_stream_t _stream, a *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(2);
  flick_iiopxx_check_span(2, _flick_abort2);
  flick_iiopxx_decode_new_chunk(2);
  flick_cdr_swap_decode_signed16(0, *_data, CORBA::Short );
  flick_iiopxx_decode_end_chunk(2);
  flick_iiopxx_decode_end_glob(2);
  return 0;
  {
  _flick_abort2:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_c(flick_marshal_stream_t _stream, const c *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(1, _flick_abort3);
  flick_iiopxx_encode_new_chunk(1);
  flick_cdr_encode_char8(0, *_data, CORBA::Char );
  flick_iiopxx_encode_end_chunk(1);
  flick_iiopxx_encode_end_glob(1);
  return 0;
  {
  _flick_abort3:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_c(flick_marshal_stream_t _stream, c *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(1);
  flick_iiopxx_check_span(1, _flick_abort4);
  flick_iiopxx_decode_new_chunk(1);
  flick_cdr_decode_char8(0, *_data, CORBA::Char );
  flick_iiopxx_decode_end_chunk(1);
  flick_iiopxx_decode_end_glob(1);
  return 0;
  {
  _flick_abort4:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_c_swap(flick_marshal_stream_t _stream, c *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(1);
  flick_iiopxx_check_span(1, _flick_abort5);
  flick_iiopxx_decode_new_chunk(1);
  flick_cdr_swap_decode_char8(0, *_data, CORBA::Char );
  flick_iiopxx_decode_end_chunk(1);
  flick_iiopxx_decode_end_glob(1);
  return 0;
  {
  _flick_abort5:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_e(flick_marshal_stream_t _stream, const e *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort6);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  flick_iiopxx_encode_new_glob(2 * _data->_length, _flick_abort6);
  flick_iiopxx_encode_new_chunk(2 * _data->_length);
  flick_cdr_encode_bcopy(0, _data->_buffer, 2 * _data->_length);
  flick_iiopxx_encode_end_chunk(2 * _data->_length);
  flick_iiopxx_encode_end_glob(2 * _data->_length);
  return 0;
  {
  _flick_abort6:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_e(flick_marshal_stream_t _stream, e *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort9);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(2 * _data->_length);
  flick_iiopxx_check_span(2 * _data->_length, _flick_abort9);
  flick_iiopxx_decode_new_chunk(2 * _data->_length);
  {
    CORBA::Short *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Short *)new (CORBA::Short [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort9);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 2 * _data->_length);
  flick_iiopxx_decode_end_chunk(2 * _data->_length);
  flick_iiopxx_decode_end_glob(2 * _data->_length);
  return 0;
  {
  _flick_abort9:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_e_swap(flick_marshal_stream_t _stream, e *_data)
{
  CORBA::ULong _t0_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort12);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(2 * _data->_length);
  {
    CORBA::Short *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Short *)new (CORBA::Short [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort12);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_iiopxx_check_span(_data->_length * 2, _flick_abort12);
  for (_t0_array_iter = 0; _t0_array_iter < _data->_length; _t0_array_iter++)
    {
      flick_iiopxx_decode_new_chunk(2);
      flick_cdr_swap_decode_signed16(0, _data->_buffer[_t0_array_iter], CORBA::Short );
      flick_iiopxx_decode_end_chunk(2);
      continue;
    }
  flick_iiopxx_decode_end_glob(2 * _data->_length);
  return 0;
  {
  _flick_abort12:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_f(flick_marshal_stream_t _stream, const f *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort18);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_float32(0, *_data, CORBA::Float );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  return 0;
  {
  _flick_abort18:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_f(flick_marshal_stream_t _stream, f *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort19);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_float32(0, *_data, CORBA::Float );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  return 0;
  {
  _flick_abort19:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_f_swap(flick_marshal_stream_t _stream, f *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort20);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_float32(0, *_data, CORBA::Float );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  return 0;
  {
  _flick_abort20:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_g(flick_marshal_stream_t _stream, const g *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(10, _flick_abort21);
  flick_iiopxx_encode_new_chunk(10);
  flick_cdr_encode_bcopy(0, *_data, 10);
  flick_iiopxx_encode_end_chunk(10);
  flick_iiopxx_encode_end_glob(10);
  return 0;
  {
  _flick_abort21:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_g(flick_marshal_stream_t _stream, g *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(10);
  flick_iiopxx_check_span(10, _flick_abort24);
  flick_iiopxx_decode_new_chunk(10);
  flick_cdr_decode_bcopy(0, *_data, 10);
  flick_iiopxx_decode_end_chunk(10);
  flick_iiopxx_decode_end_glob(10);
  return 0;
  {
  _flick_abort24:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_g_swap(flick_marshal_stream_t _stream, g *_data)
{
  flick_unsigned32_t _t1_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(10);
  flick_iiopxx_check_span(5 * 2, _flick_abort27);
  for (_t1_array_iter = 0; _t1_array_iter < 5; _t1_array_iter++)
    {
      flick_iiopxx_decode_new_chunk(2);
      flick_cdr_swap_decode_signed16(0, (*_data)[_t1_array_iter], CORBA::Short );
      flick_iiopxx_decode_end_chunk(2);
      continue;
    }
  flick_iiopxx_decode_end_glob(10);
  return 0;
  {
  _flick_abort27:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_h(flick_marshal_stream_t _stream, const h *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(14, _flick_abort33);
  flick_iiopxx_encode_new_chunk(4 + 2 * _data->_length);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 5)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort33);
  flick_cdr_encode_bcopy(4, _data->_buffer, 2 * _data->_length);
  flick_iiopxx_encode_end_chunk(4 + 2 * _data->_length);
  flick_iiopxx_encode_end_glob(14);
  return 0;
  {
  _flick_abort33:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_h(flick_marshal_stream_t _stream, h *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(14);
  flick_iiopxx_check_span(4, _flick_abort36);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 5)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort36);
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_check_span(2 * _data->_length, _flick_abort36);
  flick_iiopxx_decode_new_chunk(2 * _data->_length);
  {
    CORBA::Short *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Short *)new (CORBA::Short [5]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort36);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = 5;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 2 * _data->_length);
  flick_iiopxx_decode_end_chunk(2 * _data->_length);
  flick_iiopxx_decode_end_glob(14);
  return 0;
  {
  _flick_abort36:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_h_swap(flick_marshal_stream_t _stream, h *_data)
{
  CORBA::ULong _t2_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(14);
  flick_iiopxx_check_span(4, _flick_abort39);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  if (_data->_length > 5)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort39);
  {
    CORBA::Short *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Short *)new (CORBA::Short [5]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort39);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = 5;
    _data->_release = 1;
  }
  flick_iiopxx_check_span(_data->_length * 2, _flick_abort39);
  for (_t2_array_iter = 0; _t2_array_iter < _data->_length; _t2_array_iter++)
    {
      flick_iiopxx_decode_new_chunk(2);
      flick_cdr_swap_decode_signed16(0, _data->_buffer[_t2_array_iter], CORBA::Short );
      flick_iiopxx_decode_end_chunk(2);
      continue;
    }
  flick_iiopxx_decode_end_glob(14);
  return 0;
  {
  _flick_abort39:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

