#include "impldef-client.h"
#include "impldef-server.h"

static const CORBA::Long _oc_CORBA_StringSequence[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    29, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f5374), ACE_NTOHL(0x72696e67), ACE_NTOHL(0x53657175), ACE_NTOHL(0x656e6365), ACE_NTOHL(0x3a312e30), ACE_NTOHL(0x00000000) /* repository ID = IDL:CORBA/StringSequence:1.0 */,
    15, ACE_NTOHL(0x53747269), ACE_NTOHL(0x6e675365), ACE_NTOHL(0x7175656e), ACE_NTOHL(0x63650000) /* name = StringSequence */,
    CORBA::tk_sequence,
    16 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_string,
      0,
      0
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_StringSequence (CORBA::tk_alias, sizeof(_oc_CORBA_StringSequence), (char *) &_oc_CORBA_StringSequence, 0, sizeof(::CORBA::StringSequence ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_StringSequence, &_tc_TAO_tc_CORBA_StringSequence)
TAO_NAMESPACE_END
CORBA::StringSequence::StringSequence()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

CORBA::StringSequence::StringSequence(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = CORBA::StringSequence::allocbuf(this->_maximum);
}

CORBA::StringSequence::StringSequence(CORBA::ULong max, CORBA::ULong length, char **buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

CORBA::StringSequence::StringSequence(const ::CORBA::StringSequence &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  char * *tmp1 = CORBA::StringSequence::allocbuf(this->_maximum);
  
  char * * const tmp2 = ACE_reinterpret_cast(char * * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = CORBA::string_dup(tmp2[i]);
  
  this->_buffer = tmp1;
}

CORBA::StringSequence::~StringSequence()
{
  this->_deallocate_buffer();
}

::CORBA::StringSequence &CORBA::StringSequence::operator=(const ::CORBA::StringSequence &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      char * *tmp = ACE_reinterpret_cast(char * *, this->_buffer);
      
      for(CORBA::ULong i = 0; i < this->_length; i++)
      {
        CORBA::string_free(tmp[i]);
        tmp[i] = (char *)0;
      }
      
      CORBA::StringSequence::freebuf(tmp);
      this->_buffer = CORBA::StringSequence::allocbuf(rhs._maximum);
    }
  
  }
  else
    this->_buffer = CORBA::StringSequence::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  char * *tmp1 = ACE_reinterpret_cast(char * *, this->_buffer);
  char * * const tmp2 = ACE_reinterpret_cast(char * * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = CORBA::string_dup(tmp2[i]);
  return *this;
}

char **CORBA::StringSequence::allocbuf(CORBA::ULong size)
{
  char **buf = new char *[size];
  for(CORBA::ULong i=0; i < size; i++)
    buf[i] = 0;
  return buf;
}

void CORBA::StringSequence::freebuf(char **buffer)
{
  delete [] buffer;
}

void CORBA::StringSequence::_allocate_buffer(CORBA::ULong length)
{
  char * *tmp = CORBA::StringSequence::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    char * *old = ACE_reinterpret_cast(char * *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      CORBA::StringSequence::freebuf(old);
  }
  this->_buffer = tmp;
}

void CORBA::StringSequence::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  char * *tmp = ACE_reinterpret_cast(char * *, this->_buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++)
  {
    CORBA::string_free(tmp[i]);
    tmp[i] = (char *)0;
  }
  
  CORBA::StringSequence::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean CORBA::StringSequence::release() const
{
  return this->_release;
}

CORBA::ULong CORBA::StringSequence::maximum() const
{
  return this->_maximum;
}

CORBA::ULong CORBA::StringSequence::length() const
{
  return this->_length;
}

void CORBA::StringSequence::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void CORBA::StringSequence::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
  char * *tmp = ACE_reinterpret_cast(char * *, this->_buffer);
  
  for(CORBA::ULong i = length1; i < length2; i++)
  {
    CORBA::string_free(tmp[i]);
    tmp[i] = (char *)0;
  }
}

char **CORBA::StringSequence::get_buffer(CORBA::Boolean orphan)
{
  char * *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = CORBA::StringSequence::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(char * *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(char * *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const char **CORBA::StringSequence::get_buffer() const
{
  return ACE_const_cast(const char * * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const ::CORBA::StringSequence &o)
{
  ::CORBA::StringSequence  *_any_val;
  ACE_NEW(_any_val, ::CORBA::StringSequence  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_StringSequence, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::CORBA::StringSequence *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_StringSequence, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::StringSequence *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(CORBA::_tc_StringSequence, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::CORBA::StringSequence  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::CORBA::StringSequence , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(CORBA::_tc_StringSequence, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(CORBA::_tc_StringSequence, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

TAO_SeqElem_String_Manager CORBA::StringSequence::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  char * * tmp = ACE_reinterpret_cast(char * *, this->_buffer);
  return TAO_SeqElem_String_Manager(tmp + i,
                                    this->_release);
}

CORBA::StringSequence_var::StringSequence_var()
  : ptr_(0)
{}

CORBA::StringSequence_var::StringSequence_var(::CORBA::StringSequence *p)
 : ptr_(p)
{}

CORBA::StringSequence_var::StringSequence_var(const ::CORBA::StringSequence_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new ::CORBA::StringSequence (*a.ptr_);
  else
    this->ptr_ = 0;
}

CORBA::StringSequence_var::~StringSequence_var()
{
  delete this->ptr_;
}

::CORBA::StringSequence_var &CORBA::StringSequence_var::operator=(::CORBA::StringSequence *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

::CORBA::StringSequence_var &CORBA::StringSequence_var::operator=(const ::CORBA::StringSequence_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new ::CORBA::StringSequence (*p.ptr_);
  }
  return *this;
}

::CORBA::StringSequence *CORBA::StringSequence_var::operator->()
{
  return this->ptr_;
}

const ::CORBA::StringSequence *CORBA::StringSequence_var::operator->() const
{
  return this->ptr_;
}

CORBA::StringSequence_var::operator const ::CORBA::StringSequence &() const
{
  return *this->ptr_;
}

CORBA::StringSequence_var::operator ::CORBA::StringSequence &()
{
  return *this->ptr_;
}

CORBA::StringSequence_var::operator ::CORBA::StringSequence &() const
{
  return *this->ptr_;
}

const ::CORBA::StringSequence &CORBA::StringSequence_var::in() const
{
  return *this->ptr_;
}

::CORBA::StringSequence &CORBA::StringSequence_var::inout()
{
  return *this->ptr_;
}

::CORBA::StringSequence *&CORBA::StringSequence_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

::CORBA::StringSequence *CORBA::StringSequence_var::_retn()
{
  ::CORBA::StringSequence  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

::CORBA::StringSequence *CORBA::StringSequence_var::ptr() const
{
  return this->ptr_;
}

TAO_SeqElem_String_Manager CORBA::StringSequence_var::operator[](CORBA::ULong i)
{
  return this->ptr_->operator[](i);
}

CORBA::StringSequence_out::StringSequence_out(::CORBA::StringSequence *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

CORBA::StringSequence_out::StringSequence_out(::CORBA::StringSequence_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

CORBA::StringSequence_out::StringSequence_out(const ::CORBA::StringSequence_out &r)
  : ptr_(ACE_const_cast(::CORBA::StringSequence_out &,r).ptr_)
{}

::CORBA::StringSequence_out &CORBA::StringSequence_out::operator=(const ::CORBA::StringSequence_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::StringSequence_out &,r).ptr_;
  return *this;
}

::CORBA::StringSequence_out &CORBA::StringSequence_out::operator=(::CORBA::StringSequence *r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::StringSequence_out::operator ::CORBA::StringSequence *&()
{
  return this->ptr_;
}

::CORBA::StringSequence *&CORBA::StringSequence_out::ptr()
{
  return this->ptr_;
}

::CORBA::StringSequence *CORBA::StringSequence_out::operator->()
{
  return this->ptr_;
}

TAO_SeqElem_String_Manager CORBA::StringSequence_out::operator[](CORBA::ULong i)
{
  return this->ptr_->operator[](i);
}

static const CORBA::Long _oc_CORBA_OctetSequence[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    28, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4f63), ACE_NTOHL(0x74657453), ACE_NTOHL(0x65717565), ACE_NTOHL(0x6e63653a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/OctetSequence:1.0 */,
    14, ACE_NTOHL(0x4f637465), ACE_NTOHL(0x74536571), ACE_NTOHL(0x75656e63), ACE_NTOHL(0x65000000) /* name = OctetSequence */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_octet,
      0
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_OctetSequence (CORBA::tk_alias, sizeof(_oc_CORBA_OctetSequence), (char *) &_oc_CORBA_OctetSequence, 0, sizeof(::CORBA::OctetSequence ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_OctetSequence, &_tc_TAO_tc_CORBA_OctetSequence)
TAO_NAMESPACE_END
CORBA::OctetSequence::OctetSequence()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

CORBA::OctetSequence::OctetSequence(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = CORBA::OctetSequence::allocbuf(this->_maximum);
}

CORBA::OctetSequence::OctetSequence(CORBA::ULong max, CORBA::ULong length, CORBA::Octet *buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

CORBA::OctetSequence::OctetSequence(const ::CORBA::OctetSequence &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  CORBA::Octet  *tmp1 = CORBA::OctetSequence::allocbuf(this->_maximum);
  
  CORBA::Octet  * const tmp2 = ACE_reinterpret_cast(CORBA::Octet  * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  
  this->_buffer = tmp1;
}

CORBA::OctetSequence::~OctetSequence()
{
  this->_deallocate_buffer();
}

::CORBA::OctetSequence &CORBA::OctetSequence::operator=(const ::CORBA::OctetSequence &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      CORBA::Octet  *tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
      
      CORBA::OctetSequence::freebuf(tmp);
      this->_buffer = CORBA::OctetSequence::allocbuf(rhs._maximum);
    }
  
  }
  else
    this->_buffer = CORBA::OctetSequence::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Octet  *tmp1 = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  CORBA::Octet  * const tmp2 = ACE_reinterpret_cast(CORBA::Octet  * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  return *this;
}

CORBA::Octet &CORBA::OctetSequence::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Octet  * tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  return tmp[i];
}

const CORBA::Octet &CORBA::OctetSequence::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Octet  * const tmp = ACE_reinterpret_cast(CORBA::Octet  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Octet *CORBA::OctetSequence::allocbuf(CORBA::ULong size)
{
  CORBA::Octet  *tmp;
  tmp = new CORBA::Octet [size];
  return tmp;
}

void CORBA::OctetSequence::freebuf(CORBA::Octet *buffer)
{
  delete [] buffer;
}

void CORBA::OctetSequence::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Octet  *tmp = CORBA::OctetSequence::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Octet  *old = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      CORBA::OctetSequence::freebuf(old);
  }
  this->_buffer = tmp;
}

void CORBA::OctetSequence::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  CORBA::Octet  *tmp = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
  
  CORBA::OctetSequence::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean CORBA::OctetSequence::release() const
{
  return this->_release;
}

CORBA::ULong CORBA::OctetSequence::maximum() const
{
  return this->_maximum;
}

CORBA::ULong CORBA::OctetSequence::length() const
{
  return this->_length;
}

void CORBA::OctetSequence::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void CORBA::OctetSequence::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
}

CORBA::Octet *CORBA::OctetSequence::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Octet  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = CORBA::OctetSequence::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Octet  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Octet *CORBA::OctetSequence::get_buffer() const
{
  return ACE_const_cast(const CORBA::Octet  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const ::CORBA::OctetSequence &o)
{
  ::CORBA::OctetSequence  *_any_val;
  ACE_NEW(_any_val, ::CORBA::OctetSequence  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_OctetSequence, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::CORBA::OctetSequence *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_OctetSequence, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::OctetSequence *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(CORBA::_tc_OctetSequence, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::CORBA::OctetSequence  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::CORBA::OctetSequence , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(CORBA::_tc_OctetSequence, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(CORBA::_tc_OctetSequence, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::OctetSequence_var::OctetSequence_var()
  : ptr_(0)
{}

CORBA::OctetSequence_var::OctetSequence_var(::CORBA::OctetSequence *p)
 : ptr_(p)
{}

CORBA::OctetSequence_var::OctetSequence_var(const ::CORBA::OctetSequence_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new ::CORBA::OctetSequence (*a.ptr_);
  else
    this->ptr_ = 0;
}

CORBA::OctetSequence_var::~OctetSequence_var()
{
  delete this->ptr_;
}

::CORBA::OctetSequence_var &CORBA::OctetSequence_var::operator=(::CORBA::OctetSequence *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

::CORBA::OctetSequence_var &CORBA::OctetSequence_var::operator=(const ::CORBA::OctetSequence_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new ::CORBA::OctetSequence (*p.ptr_);
  }
  return *this;
}

CORBA::Octet &CORBA::OctetSequence_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Octet &CORBA::OctetSequence_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::OctetSequence *CORBA::OctetSequence_var::operator->()
{
  return this->ptr_;
}

const ::CORBA::OctetSequence *CORBA::OctetSequence_var::operator->() const
{
  return this->ptr_;
}

CORBA::OctetSequence_var::operator const ::CORBA::OctetSequence &() const
{
  return *this->ptr_;
}

CORBA::OctetSequence_var::operator ::CORBA::OctetSequence &()
{
  return *this->ptr_;
}

CORBA::OctetSequence_var::operator ::CORBA::OctetSequence &() const
{
  return *this->ptr_;
}

const ::CORBA::OctetSequence &CORBA::OctetSequence_var::in() const
{
  return *this->ptr_;
}

::CORBA::OctetSequence &CORBA::OctetSequence_var::inout()
{
  return *this->ptr_;
}

::CORBA::OctetSequence *&CORBA::OctetSequence_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

::CORBA::OctetSequence *CORBA::OctetSequence_var::_retn()
{
  ::CORBA::OctetSequence  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

::CORBA::OctetSequence *CORBA::OctetSequence_var::ptr() const
{
  return this->ptr_;
}

CORBA::OctetSequence_out::OctetSequence_out(::CORBA::OctetSequence *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

CORBA::OctetSequence_out::OctetSequence_out(::CORBA::OctetSequence_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

CORBA::OctetSequence_out::OctetSequence_out(const ::CORBA::OctetSequence_out &r)
  : ptr_(ACE_const_cast(::CORBA::OctetSequence_out &,r).ptr_)
{}

::CORBA::OctetSequence_out &CORBA::OctetSequence_out::operator=(const ::CORBA::OctetSequence_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::OctetSequence_out &,r).ptr_;
  return *this;
}

::CORBA::OctetSequence_out &CORBA::OctetSequence_out::operator=(::CORBA::OctetSequence *r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::OctetSequence_out::operator ::CORBA::OctetSequence *&()
{
  return this->ptr_;
}

::CORBA::OctetSequence *&CORBA::OctetSequence_out::ptr()
{
  return this->ptr_;
}

CORBA::Octet &CORBA::OctetSequence_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Octet &CORBA::OctetSequence_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::OctetSequence *CORBA::OctetSequence_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_LongSequence[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    27, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4c6f), ACE_NTOHL(0x6e675365), ACE_NTOHL(0x7175656e), ACE_NTOHL(0x63653a31), ACE_NTOHL(0x2e300000) /* repository ID = IDL:CORBA/LongSequence:1.0 */,
    13, ACE_NTOHL(0x4c6f6e67), ACE_NTOHL(0x53657175), ACE_NTOHL(0x656e6365), ACE_NTOHL(0x00000000) /* name = LongSequence */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_long,
      0
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_LongSequence (CORBA::tk_alias, sizeof(_oc_CORBA_LongSequence), (char *) &_oc_CORBA_LongSequence, 0, sizeof(::CORBA::LongSequence ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_LongSequence, &_tc_TAO_tc_CORBA_LongSequence)
TAO_NAMESPACE_END
CORBA::LongSequence::LongSequence()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

CORBA::LongSequence::LongSequence(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = CORBA::LongSequence::allocbuf(this->_maximum);
}

CORBA::LongSequence::LongSequence(CORBA::ULong max, CORBA::ULong length, CORBA::Long *buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

CORBA::LongSequence::LongSequence(const ::CORBA::LongSequence &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  CORBA::Long  *tmp1 = CORBA::LongSequence::allocbuf(this->_maximum);
  
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  
  this->_buffer = tmp1;
}

CORBA::LongSequence::~LongSequence()
{
  this->_deallocate_buffer();
}

::CORBA::LongSequence &CORBA::LongSequence::operator=(const ::CORBA::LongSequence &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      
      CORBA::LongSequence::freebuf(tmp);
      this->_buffer = CORBA::LongSequence::allocbuf(rhs._maximum);
    }
  
  }
  else
    this->_buffer = CORBA::LongSequence::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Long  *tmp1 = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  return *this;
}

CORBA::Long &CORBA::LongSequence::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  return tmp[i];
}

const CORBA::Long &CORBA::LongSequence::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * const tmp = ACE_reinterpret_cast(CORBA::Long  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Long *CORBA::LongSequence::allocbuf(CORBA::ULong size)
{
  CORBA::Long  *tmp;
  tmp = new CORBA::Long [size];
  return tmp;
}

void CORBA::LongSequence::freebuf(CORBA::Long *buffer)
{
  delete [] buffer;
}

void CORBA::LongSequence::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Long  *tmp = CORBA::LongSequence::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Long  *old = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      CORBA::LongSequence::freebuf(old);
  }
  this->_buffer = tmp;
}

void CORBA::LongSequence::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  
  CORBA::LongSequence::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean CORBA::LongSequence::release() const
{
  return this->_release;
}

CORBA::ULong CORBA::LongSequence::maximum() const
{
  return this->_maximum;
}

CORBA::ULong CORBA::LongSequence::length() const
{
  return this->_length;
}

void CORBA::LongSequence::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void CORBA::LongSequence::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
}

CORBA::Long *CORBA::LongSequence::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Long  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = CORBA::LongSequence::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Long *CORBA::LongSequence::get_buffer() const
{
  return ACE_const_cast(const CORBA::Long  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const ::CORBA::LongSequence &o)
{
  ::CORBA::LongSequence  *_any_val;
  ACE_NEW(_any_val, ::CORBA::LongSequence  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_LongSequence, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, ::CORBA::LongSequence *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(CORBA::_tc_LongSequence, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::LongSequence *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(CORBA::_tc_LongSequence, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (::CORBA::LongSequence  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, ::CORBA::LongSequence , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(CORBA::_tc_LongSequence, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(CORBA::_tc_LongSequence, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::LongSequence_var::LongSequence_var()
  : ptr_(0)
{}

CORBA::LongSequence_var::LongSequence_var(::CORBA::LongSequence *p)
 : ptr_(p)
{}

CORBA::LongSequence_var::LongSequence_var(const ::CORBA::LongSequence_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new ::CORBA::LongSequence (*a.ptr_);
  else
    this->ptr_ = 0;
}

CORBA::LongSequence_var::~LongSequence_var()
{
  delete this->ptr_;
}

::CORBA::LongSequence_var &CORBA::LongSequence_var::operator=(::CORBA::LongSequence *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

::CORBA::LongSequence_var &CORBA::LongSequence_var::operator=(const ::CORBA::LongSequence_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new ::CORBA::LongSequence (*p.ptr_);
  }
  return *this;
}

CORBA::Long &CORBA::LongSequence_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &CORBA::LongSequence_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::LongSequence *CORBA::LongSequence_var::operator->()
{
  return this->ptr_;
}

const ::CORBA::LongSequence *CORBA::LongSequence_var::operator->() const
{
  return this->ptr_;
}

CORBA::LongSequence_var::operator const ::CORBA::LongSequence &() const
{
  return *this->ptr_;
}

CORBA::LongSequence_var::operator ::CORBA::LongSequence &()
{
  return *this->ptr_;
}

CORBA::LongSequence_var::operator ::CORBA::LongSequence &() const
{
  return *this->ptr_;
}

const ::CORBA::LongSequence &CORBA::LongSequence_var::in() const
{
  return *this->ptr_;
}

::CORBA::LongSequence &CORBA::LongSequence_var::inout()
{
  return *this->ptr_;
}

::CORBA::LongSequence *&CORBA::LongSequence_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

::CORBA::LongSequence *CORBA::LongSequence_var::_retn()
{
  ::CORBA::LongSequence  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

::CORBA::LongSequence *CORBA::LongSequence_var::ptr() const
{
  return this->ptr_;
}

CORBA::LongSequence_out::LongSequence_out(::CORBA::LongSequence *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

CORBA::LongSequence_out::LongSequence_out(::CORBA::LongSequence_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

CORBA::LongSequence_out::LongSequence_out(const ::CORBA::LongSequence_out &r)
  : ptr_(ACE_const_cast(::CORBA::LongSequence_out &,r).ptr_)
{}

::CORBA::LongSequence_out &CORBA::LongSequence_out::operator=(const ::CORBA::LongSequence_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::LongSequence_out &,r).ptr_;
  return *this;
}

::CORBA::LongSequence_out &CORBA::LongSequence_out::operator=(::CORBA::LongSequence *r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::LongSequence_out::operator ::CORBA::LongSequence *&()
{
  return this->ptr_;
}

::CORBA::LongSequence *&CORBA::LongSequence_out::ptr()
{
  return this->ptr_;
}

CORBA::Long &CORBA::LongSequence_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &CORBA::LongSequence_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

::CORBA::LongSequence *CORBA::LongSequence_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_ImplementationDef[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    32, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f496d), ACE_NTOHL(0x706c656d), ACE_NTOHL(0x656e7461), ACE_NTOHL(0x74696f6e), ACE_NTOHL(0x4465663a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/ImplementationDef:1.0 */,
    18, ACE_NTOHL(0x496d706c), ACE_NTOHL(0x656d656e), ACE_NTOHL(0x74617469), ACE_NTOHL(0x6f6e4465), ACE_NTOHL(0x66000000) /* name = ImplementationDef */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_ImplementationDef (CORBA::tk_objref, sizeof(_oc_CORBA_ImplementationDef), (char *) &_oc_CORBA_ImplementationDef, 0, sizeof(::CORBA::ImplementationDef ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_ImplementationDef, &_tc_TAO_tc_CORBA_ImplementationDef)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::ImplementationDef >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::ImplementationDef >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_duplicate(::CORBA::ImplementationDef_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return CORBA::ImplementationDef::_nil();
  if( !obj->_is_a("IDL:CORBA/ImplementationDef:1.0", _env) )
    return CORBA::ImplementationDef::_nil();
  return CORBA::ImplementationDef::_unchecked_narrow(obj, _env);
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::ImplementationDef::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (_obj->_is_collocated () && _obj->_servant() != 0)
    servant = _obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new ::CORBA::ImplementationDef (stub);
  return new POA_CORBA::_tao_collocated_ImplementationDef(
      ACE_reinterpret_cast(::POA_CORBA::ImplementationDef_ptr , servant),
      stub
    );
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef::_nil()
{
  return (::CORBA::ImplementationDef_ptr )NULL;
}

CORBA::Boolean CORBA::ImplementationDef::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ImplementationDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::ImplementationDef::_interface_repository_id() const
{
  return "IDL:CORBA/ImplementationDef:1.0";
}

CORBA::ImplementationDef::ImplementationDef()
{}

CORBA::ImplementationDef::~ImplementationDef()
{}

void operator<<=(CORBA::Any &a, ::CORBA::ImplementationDef_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::ImplementationDef::_duplicate(o);
    a.replace (CORBA::_tc_ImplementationDef, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::ImplementationDef_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::ImplementationDef::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_ImplementationDef, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_ImplementationDef, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::ImplementationDef::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_ImplementationDef, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::ImplementationDef::ImplementationDef(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::ImplementationDef_var::ImplementationDef_var()
  : ptr_(CORBA::ImplementationDef::_nil())
{}

CORBA::ImplementationDef_var::ImplementationDef_var(::CORBA::ImplementationDef_ptr p)
  : ptr_(p)
{}

CORBA::ImplementationDef_var::ImplementationDef_var(const ::CORBA::ImplementationDef_var &a)
  : ptr_(CORBA::ImplementationDef::_duplicate(a.ptr()))
{}

CORBA::ImplementationDef_var::~ImplementationDef_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::ImplementationDef_var &CORBA::ImplementationDef_var::operator=(::CORBA::ImplementationDef_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::ImplementationDef_var &CORBA::ImplementationDef_var::operator=(const ::CORBA::ImplementationDef_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::ImplementationDef::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::operator->() const
{
  return this->ptr_;
}

CORBA::ImplementationDef_var::operator const ::CORBA::ImplementationDef_ptr &() const
{
  return this->ptr_;
}

CORBA::ImplementationDef_var::operator ::CORBA::ImplementationDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::in() const
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr &CORBA::ImplementationDef_var::inout()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr &CORBA::ImplementationDef_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ImplementationDef::_nil();
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::_retn()
{
  ::CORBA::ImplementationDef_ptr  val = this->ptr_;
  this->ptr_ = CORBA::ImplementationDef::_nil();
  return val;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_var::ptr() const
{
  return this->ptr_;
}

CORBA::ImplementationDef_out::ImplementationDef_out(::CORBA::ImplementationDef_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::ImplementationDef::_nil();
}

CORBA::ImplementationDef_out::ImplementationDef_out(::CORBA::ImplementationDef_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ImplementationDef::_nil();
}

CORBA::ImplementationDef_out::ImplementationDef_out(const ::CORBA::ImplementationDef_out &r)
  : ptr_(ACE_const_cast(::CORBA::ImplementationDef_out &,r).ptr_)
{}

::CORBA::ImplementationDef_out &CORBA::ImplementationDef_out::operator=(const ::CORBA::ImplementationDef_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::ImplementationDef_out &,r).ptr_;
  return *this;
}

::CORBA::ImplementationDef_out &CORBA::ImplementationDef_out::operator=(const ::CORBA::ImplementationDef_var &r)
{
  this->ptr_ = CORBA::ImplementationDef::_duplicate(r.ptr());
  return *this;
}

::CORBA::ImplementationDef_out &CORBA::ImplementationDef_out::operator=(::CORBA::ImplementationDef_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::ImplementationDef_out::operator ::CORBA::ImplementationDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr &CORBA::ImplementationDef_out::ptr()
{
  return this->ptr_;
}

::CORBA::ImplementationDef_ptr CORBA::ImplementationDef_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_CreationImplDef[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    30, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4372), ACE_NTOHL(0x65617469), ACE_NTOHL(0x6f6e496d), ACE_NTOHL(0x706c4465), ACE_NTOHL(0x663a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:CORBA/CreationImplDef:1.0 */,
    16, ACE_NTOHL(0x43726561), ACE_NTOHL(0x74696f6e), ACE_NTOHL(0x496d706c), ACE_NTOHL(0x44656600) /* name = CreationImplDef */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_CreationImplDef (CORBA::tk_objref, sizeof(_oc_CORBA_CreationImplDef), (char *) &_oc_CORBA_CreationImplDef, 0, sizeof(::CORBA::CreationImplDef ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_CreationImplDef, &_tc_TAO_tc_CORBA_CreationImplDef)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::CreationImplDef >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::CreationImplDef >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_duplicate(::CORBA::CreationImplDef_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return CORBA::CreationImplDef::_nil();
  if( !obj->_is_a("IDL:CORBA/CreationImplDef:1.0", _env) )
    return CORBA::CreationImplDef::_nil();
  return CORBA::CreationImplDef::_unchecked_narrow(obj, _env);
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::CreationImplDef::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (_obj->_is_collocated () && _obj->_servant() != 0)
    servant = _obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new ::CORBA::CreationImplDef (stub);
  return new POA_CORBA::_tao_collocated_CreationImplDef(
      ACE_reinterpret_cast(::POA_CORBA::CreationImplDef_ptr , servant),
      stub
    );
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef::_nil()
{
  return (::CORBA::CreationImplDef_ptr )NULL;
}

CORBA::Boolean CORBA::CreationImplDef::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ImplementationDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/CreationImplDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::CreationImplDef::_interface_repository_id() const
{
  return "IDL:CORBA/CreationImplDef:1.0";
}

CORBA::CreationImplDef::CreationImplDef()
{}

CORBA::CreationImplDef::~CreationImplDef()
{}

void operator<<=(CORBA::Any &a, ::CORBA::CreationImplDef_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::CreationImplDef::_duplicate(o);
    a.replace (CORBA::_tc_CreationImplDef, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::CreationImplDef_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::CreationImplDef::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_CreationImplDef, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_CreationImplDef, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::CreationImplDef::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_CreationImplDef, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::CreationImplDef::CreationImplDef(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::CreationImplDef_var::CreationImplDef_var()
  : ptr_(CORBA::CreationImplDef::_nil())
{}

CORBA::CreationImplDef_var::CreationImplDef_var(::CORBA::CreationImplDef_ptr p)
  : ptr_(p)
{}

CORBA::CreationImplDef_var::CreationImplDef_var(const ::CORBA::CreationImplDef_var &a)
  : ptr_(CORBA::CreationImplDef::_duplicate(a.ptr()))
{}

CORBA::CreationImplDef_var::~CreationImplDef_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::CreationImplDef_var &CORBA::CreationImplDef_var::operator=(::CORBA::CreationImplDef_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::CreationImplDef_var &CORBA::CreationImplDef_var::operator=(const ::CORBA::CreationImplDef_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::CreationImplDef::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::operator->() const
{
  return this->ptr_;
}

CORBA::CreationImplDef_var::operator const ::CORBA::CreationImplDef_ptr &() const
{
  return this->ptr_;
}

CORBA::CreationImplDef_var::operator ::CORBA::CreationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::in() const
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr &CORBA::CreationImplDef_var::inout()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr &CORBA::CreationImplDef_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::CreationImplDef::_nil();
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::_retn()
{
  ::CORBA::CreationImplDef_ptr  val = this->ptr_;
  this->ptr_ = CORBA::CreationImplDef::_nil();
  return val;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_var::ptr() const
{
  return this->ptr_;
}

CORBA::CreationImplDef_out::CreationImplDef_out(::CORBA::CreationImplDef_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::CreationImplDef::_nil();
}

CORBA::CreationImplDef_out::CreationImplDef_out(::CORBA::CreationImplDef_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::CreationImplDef::_nil();
}

CORBA::CreationImplDef_out::CreationImplDef_out(const ::CORBA::CreationImplDef_out &r)
  : ptr_(ACE_const_cast(::CORBA::CreationImplDef_out &,r).ptr_)
{}

::CORBA::CreationImplDef_out &CORBA::CreationImplDef_out::operator=(const ::CORBA::CreationImplDef_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::CreationImplDef_out &,r).ptr_;
  return *this;
}

::CORBA::CreationImplDef_out &CORBA::CreationImplDef_out::operator=(const ::CORBA::CreationImplDef_var &r)
{
  this->ptr_ = CORBA::CreationImplDef::_duplicate(r.ptr());
  return *this;
}

::CORBA::CreationImplDef_out &CORBA::CreationImplDef_out::operator=(::CORBA::CreationImplDef_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::CreationImplDef_out::operator ::CORBA::CreationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr &CORBA::CreationImplDef_out::ptr()
{
  return this->ptr_;
}

::CORBA::CreationImplDef_ptr CORBA::CreationImplDef_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_Activator[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    24, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4163), ACE_NTOHL(0x74697661), ACE_NTOHL(0x746f723a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/Activator:1.0 */,
    10, ACE_NTOHL(0x41637469), ACE_NTOHL(0x7661746f), ACE_NTOHL(0x72000000) /* name = Activator */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_Activator (CORBA::tk_objref, sizeof(_oc_CORBA_Activator), (char *) &_oc_CORBA_Activator, 0, sizeof(::CORBA::Activator ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_Activator, &_tc_TAO_tc_CORBA_Activator)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::Activator >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::Activator >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

::CORBA::Activator_ptr CORBA::Activator::_duplicate(::CORBA::Activator_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::Activator_ptr CORBA::Activator::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return CORBA::Activator::_nil();
  if( !obj->_is_a("IDL:CORBA/Activator:1.0", _env) )
    return CORBA::Activator::_nil();
  return CORBA::Activator::_unchecked_narrow(obj, _env);
}

::CORBA::Activator_ptr CORBA::Activator::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::Activator::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (_obj->_is_collocated () && _obj->_servant() != 0)
    servant = _obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new ::CORBA::Activator (stub);
  return new POA_CORBA::_tao_collocated_Activator(
      ACE_reinterpret_cast(::POA_CORBA::Activator_ptr , servant),
      stub
    );
}

::CORBA::Activator_ptr CORBA::Activator::_nil()
{
  return (::CORBA::Activator_ptr )NULL;
}

CORBA::Boolean CORBA::Activator::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/Activator:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::Activator::_interface_repository_id() const
{
  return "IDL:CORBA/Activator:1.0";
}

CORBA::Activator::Activator()
{}

CORBA::Activator::~Activator()
{}

void operator<<=(CORBA::Any &a, ::CORBA::Activator_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::Activator::_duplicate(o);
    a.replace (CORBA::_tc_Activator, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::Activator_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::Activator::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_Activator, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_Activator, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::Activator::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_Activator, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::Activator::Activator(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::Activator_var::Activator_var()
  : ptr_(CORBA::Activator::_nil())
{}

CORBA::Activator_var::Activator_var(::CORBA::Activator_ptr p)
  : ptr_(p)
{}

CORBA::Activator_var::Activator_var(const ::CORBA::Activator_var &a)
  : ptr_(CORBA::Activator::_duplicate(a.ptr()))
{}

CORBA::Activator_var::~Activator_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::Activator_var &CORBA::Activator_var::operator=(::CORBA::Activator_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::Activator_var &CORBA::Activator_var::operator=(const ::CORBA::Activator_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::Activator::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::Activator_ptr CORBA::Activator_var::operator->() const
{
  return this->ptr_;
}

CORBA::Activator_var::operator const ::CORBA::Activator_ptr &() const
{
  return this->ptr_;
}

CORBA::Activator_var::operator ::CORBA::Activator_ptr &()
{
  return this->ptr_;
}

::CORBA::Activator_ptr CORBA::Activator_var::in() const
{
  return this->ptr_;
}

::CORBA::Activator_ptr &CORBA::Activator_var::inout()
{
  return this->ptr_;
}

::CORBA::Activator_ptr &CORBA::Activator_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::Activator::_nil();
  return this->ptr_;
}

::CORBA::Activator_ptr CORBA::Activator_var::_retn()
{
  ::CORBA::Activator_ptr  val = this->ptr_;
  this->ptr_ = CORBA::Activator::_nil();
  return val;
}

::CORBA::Activator_ptr CORBA::Activator_var::ptr() const
{
  return this->ptr_;
}

CORBA::Activator_out::Activator_out(::CORBA::Activator_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::Activator::_nil();
}

CORBA::Activator_out::Activator_out(::CORBA::Activator_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::Activator::_nil();
}

CORBA::Activator_out::Activator_out(const ::CORBA::Activator_out &r)
  : ptr_(ACE_const_cast(::CORBA::Activator_out &,r).ptr_)
{}

::CORBA::Activator_out &CORBA::Activator_out::operator=(const ::CORBA::Activator_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::Activator_out &,r).ptr_;
  return *this;
}

::CORBA::Activator_out &CORBA::Activator_out::operator=(const ::CORBA::Activator_var &r)
{
  this->ptr_ = CORBA::Activator::_duplicate(r.ptr());
  return *this;
}

::CORBA::Activator_out &CORBA::Activator_out::operator=(::CORBA::Activator_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::Activator_out::operator ::CORBA::Activator_ptr &()
{
  return this->ptr_;
}

::CORBA::Activator_ptr &CORBA::Activator_out::ptr()
{
  return this->ptr_;
}

::CORBA::Activator_ptr CORBA::Activator_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_CORBA_ActivationImplDef[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    32, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x434f5242), ACE_NTOHL(0x412f4163), ACE_NTOHL(0x74697661), ACE_NTOHL(0x74696f6e), ACE_NTOHL(0x496d706c), ACE_NTOHL(0x4465663a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:CORBA/ActivationImplDef:1.0 */,
    18, ACE_NTOHL(0x41637469), ACE_NTOHL(0x76617469), ACE_NTOHL(0x6f6e496d), ACE_NTOHL(0x706c4465), ACE_NTOHL(0x66000000) /* name = ActivationImplDef */
};

static CORBA::TypeCode _tc_TAO_tc_CORBA_ActivationImplDef (CORBA::tk_objref, sizeof(_oc_CORBA_ActivationImplDef), (char *) &_oc_CORBA_ActivationImplDef, 0, sizeof(::CORBA::ActivationImplDef ));

TAO_NAMESPACE_TYPE(CORBA::TypeCode_ptr)
TAO_NAMESPACE_BEGIN (CORBA)
TAO_NAMESPACE_DEFINE (CORBA::TypeCode_ptr, _tc_ActivationImplDef, &_tc_TAO_tc_CORBA_ActivationImplDef)
TAO_NAMESPACE_END

#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<CORBA::ActivationImplDef >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<CORBA::ActivationImplDef >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_duplicate(::CORBA::ActivationImplDef_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return CORBA::ActivationImplDef::_nil();
  if( !obj->_is_a("IDL:CORBA/ActivationImplDef:1.0", _env) )
    return CORBA::ActivationImplDef::_nil();
  return CORBA::ActivationImplDef::_unchecked_narrow(obj, _env);
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(_obj) )
    return CORBA::ActivationImplDef::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (_obj->_is_collocated () && _obj->_servant() != 0)
    servant = _obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new ::CORBA::ActivationImplDef (stub);
  return new POA_CORBA::_tao_collocated_ActivationImplDef(
      ACE_reinterpret_cast(::POA_CORBA::ActivationImplDef_ptr , servant),
      stub
    );
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef::_nil()
{
  return (::CORBA::ActivationImplDef_ptr )NULL;
}

CORBA::Boolean CORBA::ActivationImplDef::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ImplementationDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, "IDL:CORBA/ActivationImplDef:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *CORBA::ActivationImplDef::_interface_repository_id() const
{
  return "IDL:CORBA/ActivationImplDef:1.0";
}

CORBA::ActivationImplDef::ActivationImplDef()
{}

CORBA::ActivationImplDef::~ActivationImplDef()
{}

void operator<<=(CORBA::Any &a, ::CORBA::ActivationImplDef_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = CORBA::ActivationImplDef::_duplicate(o);
    a.replace (CORBA::_tc_ActivationImplDef, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, ::CORBA::ActivationImplDef_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = CORBA::ActivationImplDef::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (CORBA::_tc_ActivationImplDef, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(CORBA::_tc_ActivationImplDef, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = CORBA::ActivationImplDef::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(CORBA::_tc_ActivationImplDef, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

CORBA::ActivationImplDef::ActivationImplDef(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

CORBA::ActivationImplDef_var::ActivationImplDef_var()
  : ptr_(CORBA::ActivationImplDef::_nil())
{}

CORBA::ActivationImplDef_var::ActivationImplDef_var(::CORBA::ActivationImplDef_ptr p)
  : ptr_(p)
{}

CORBA::ActivationImplDef_var::ActivationImplDef_var(const ::CORBA::ActivationImplDef_var &a)
  : ptr_(CORBA::ActivationImplDef::_duplicate(a.ptr()))
{}

CORBA::ActivationImplDef_var::~ActivationImplDef_var()
{
  CORBA::release(this->ptr_);
}

::CORBA::ActivationImplDef_var &CORBA::ActivationImplDef_var::operator=(::CORBA::ActivationImplDef_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

::CORBA::ActivationImplDef_var &CORBA::ActivationImplDef_var::operator=(const ::CORBA::ActivationImplDef_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = CORBA::ActivationImplDef::_duplicate(p.ptr());
  }
  return *this;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::operator->() const
{
  return this->ptr_;
}

CORBA::ActivationImplDef_var::operator const ::CORBA::ActivationImplDef_ptr &() const
{
  return this->ptr_;
}

CORBA::ActivationImplDef_var::operator ::CORBA::ActivationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::in() const
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr &CORBA::ActivationImplDef_var::inout()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr &CORBA::ActivationImplDef_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ActivationImplDef::_nil();
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::_retn()
{
  ::CORBA::ActivationImplDef_ptr  val = this->ptr_;
  this->ptr_ = CORBA::ActivationImplDef::_nil();
  return val;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_var::ptr() const
{
  return this->ptr_;
}

CORBA::ActivationImplDef_out::ActivationImplDef_out(::CORBA::ActivationImplDef_ptr &r)
  : ptr_(r)
{
  this->ptr_ = CORBA::ActivationImplDef::_nil();
}

CORBA::ActivationImplDef_out::ActivationImplDef_out(::CORBA::ActivationImplDef_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = CORBA::ActivationImplDef::_nil();
}

CORBA::ActivationImplDef_out::ActivationImplDef_out(const ::CORBA::ActivationImplDef_out &r)
  : ptr_(ACE_const_cast(::CORBA::ActivationImplDef_out &,r).ptr_)
{}

::CORBA::ActivationImplDef_out &CORBA::ActivationImplDef_out::operator=(const ::CORBA::ActivationImplDef_out &r)
{
  this->ptr_ = ACE_const_cast(::CORBA::ActivationImplDef_out &,r).ptr_;
  return *this;
}

::CORBA::ActivationImplDef_out &CORBA::ActivationImplDef_out::operator=(const ::CORBA::ActivationImplDef_var &r)
{
  this->ptr_ = CORBA::ActivationImplDef::_duplicate(r.ptr());
  return *this;
}

::CORBA::ActivationImplDef_out &CORBA::ActivationImplDef_out::operator=(::CORBA::ActivationImplDef_ptr r)
{
  this->ptr_ = r;
  return *this;
}

CORBA::ActivationImplDef_out::operator ::CORBA::ActivationImplDef_ptr &()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr &CORBA::ActivationImplDef_out::ptr()
{
  return this->ptr_;
}

::CORBA::ActivationImplDef_ptr CORBA::ActivationImplDef_out::operator->()
{
  return this->ptr_;
}

int flick_marshal_stub_CORBA_StringSequence(flick_marshal_stream_t _stream, const ::CORBA::StringSequence *_data)
{
  CORBA::ULong _t3_array_iter;

  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort0);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  for (_t3_array_iter = 0; _t3_array_iter < _data->_length; _t3_array_iter++)
    {
      flick_unsigned32_t _t5_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, _data->_buffer[_t3_array_iter], flick_unsigned32_t , _t5_temp_string_len);

      flick_iiopxx_encode_new_glob(7, _flick_abort10);
      flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
      flick_cdr_encode_unsigned32(0, _t5_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(4);
      flick_iiopxx_encode_end_glob(7);
      flick_iiopxx_encode_new_glob(1 * _t5_temp_string_len, _flick_abort10);
      flick_iiopxx_encode_new_chunk(1 * _t5_temp_string_len);
      flick_cdr_encode_bcopy(0, _data->_buffer[_t3_array_iter], 1 * _t5_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t5_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t5_temp_string_len);
      continue;
      {
      _flick_abort10:
        goto _flick_abort0;
      }
    }
  return 0;
  {
  _flick_abort0:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_StringSequence(flick_marshal_stream_t _stream, ::CORBA::StringSequence *_data)
{
  CORBA::ULong _t9_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort16);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  {
    char **_t_alloc_ptr;

    _t_alloc_ptr = (char **)new (char *[_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort16);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  for (_t9_array_iter = 0; _t9_array_iter < _data->_length; _t9_array_iter++)
    {
      flick_unsigned32_t _t11_temp_string_len;

      flick_iiopxx_decode_new_glob(7);
      flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
      flick_iiopxx_check_span(4, _flick_abort29);
      flick_cdr_decode_unsigned32(0, _t11_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_decode_end_chunk(4);
      flick_iiopxx_decode_end_glob(7);
      flick_iiopxx_decode_new_glob(1 * _t11_temp_string_len);
      flick_iiopxx_check_span(1 * _t11_temp_string_len, _flick_abort29);
      flick_iiopxx_decode_new_chunk(1 * _t11_temp_string_len);
      {
        CORBA::Char *_t_alloc_ptr;

        _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t11_temp_string_len * sizeof(CORBA::Char )));
        if (!_t_alloc_ptr)
          flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort29);
        _data->_buffer[_t9_array_iter] = _t_alloc_ptr;
      }
      flick_cdr_decode_bcopy(0, _data->_buffer[_t9_array_iter], 1 * _t11_temp_string_len);
      flick_iiopxx_decode_end_chunk(1 * _t11_temp_string_len);
      flick_iiopxx_decode_end_glob(1 * _t11_temp_string_len);
      continue;
      {
      _flick_abort39:
        _t9_array_iter--;
        CORBA_string_flick_free(_data->_buffer[_t9_array_iter]);
      _flick_abort29:
        if ((unsigned int )_t9_array_iter > 0)
          goto _flick_abort39;
        goto _flick_abort16;
      }
    }
  return 0;
  {
  _flick_abort16:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_StringSequence_swap(flick_marshal_stream_t _stream, ::CORBA::StringSequence *_data)
{
  CORBA::ULong _t15_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort42);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  {
    char **_t_alloc_ptr;

    _t_alloc_ptr = (char **)new (char *[_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort42);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  for (_t15_array_iter = 0; _t15_array_iter < _data->_length; _t15_array_iter++)
    {
      flick_unsigned32_t _t17_temp_string_len;

      flick_iiopxx_decode_new_glob(7);
      flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
      flick_iiopxx_check_span(4, _flick_abort55);
      flick_cdr_swap_decode_unsigned32(0, _t17_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_decode_end_chunk(4);
      flick_iiopxx_decode_end_glob(7);
      flick_iiopxx_decode_new_glob(1 * _t17_temp_string_len);
      flick_iiopxx_check_span(1 * _t17_temp_string_len, _flick_abort55);
      flick_iiopxx_decode_new_chunk(1 * _t17_temp_string_len);
      {
        CORBA::Char *_t_alloc_ptr;

        _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t17_temp_string_len * sizeof(CORBA::Char )));
        if (!_t_alloc_ptr)
          flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort55);
        _data->_buffer[_t15_array_iter] = _t_alloc_ptr;
      }
      flick_cdr_swap_decode_bcopy(0, _data->_buffer[_t15_array_iter], 1 * _t17_temp_string_len);
      flick_iiopxx_decode_end_chunk(1 * _t17_temp_string_len);
      flick_iiopxx_decode_end_glob(1 * _t17_temp_string_len);
      continue;
      {
      _flick_abort65:
        _t15_array_iter--;
        CORBA_string_flick_free(_data->_buffer[_t15_array_iter]);
      _flick_abort55:
        if ((unsigned int )_t15_array_iter > 0)
          goto _flick_abort65;
        goto _flick_abort42;
      }
    }
  return 0;
  {
  _flick_abort42:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_CORBA_OctetSequence(flick_marshal_stream_t _stream, const ::CORBA::OctetSequence *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort68);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  flick_iiopxx_encode_new_glob(1 * _data->_length, _flick_abort68);
  flick_iiopxx_encode_new_chunk(1 * _data->_length);
  flick_cdr_encode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_encode_end_chunk(1 * _data->_length);
  flick_iiopxx_encode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort68:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_OctetSequence(flick_marshal_stream_t _stream, ::CORBA::OctetSequence *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort71);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort71);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort71);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort71:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_OctetSequence_swap(flick_marshal_stream_t _stream, ::CORBA::OctetSequence *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort74);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort74);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort74);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_swap_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort74:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_CORBA_LongSequence(flick_marshal_stream_t _stream, const ::CORBA::LongSequence *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort77);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  flick_iiopxx_encode_new_glob(4 * _data->_length, _flick_abort77);
  flick_iiopxx_encode_new_chunk(4 * _data->_length);
  flick_cdr_encode_bcopy(0, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_encode_end_chunk(4 * _data->_length);
  flick_iiopxx_encode_end_glob(4 * _data->_length);
  return 0;
  {
  _flick_abort77:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_LongSequence(flick_marshal_stream_t _stream, ::CORBA::LongSequence *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort80);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(4 * _data->_length);
  flick_iiopxx_check_span(4 * _data->_length, _flick_abort80);
  flick_iiopxx_decode_new_chunk(4 * _data->_length);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort80);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_decode_end_chunk(4 * _data->_length);
  flick_iiopxx_decode_end_glob(4 * _data->_length);
  return 0;
  {
  _flick_abort80:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_LongSequence_swap(flick_marshal_stream_t _stream, ::CORBA::LongSequence *_data)
{
  CORBA::ULong _t18_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort83);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(4 * _data->_length);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort83);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_iiopxx_check_span(_data->_length * 4, _flick_abort83);
  for (_t18_array_iter = 0; _t18_array_iter < _data->_length; _t18_array_iter++)
    {
      flick_iiopxx_decode_new_chunk(4);
      flick_cdr_swap_decode_signed32(0, _data->_buffer[_t18_array_iter], CORBA::Long );
      flick_iiopxx_decode_end_chunk(4);
      continue;
    }
  flick_iiopxx_decode_end_glob(4 * _data->_length);
  return 0;
  {
  _flick_abort83:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_CORBA_ReferenceData(flick_marshal_stream_t _stream, const ::CORBA::ReferenceData *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort89);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  flick_iiopxx_encode_new_glob(1 * _data->_length, _flick_abort89);
  flick_iiopxx_encode_new_chunk(1 * _data->_length);
  flick_cdr_encode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_encode_end_chunk(1 * _data->_length);
  flick_iiopxx_encode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort89:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ReferenceData(flick_marshal_stream_t _stream, ::CORBA::ReferenceData *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort92);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort92);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort92);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort92:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ReferenceData_swap(flick_marshal_stream_t _stream, ::CORBA::ReferenceData *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort95);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(1 * _data->_length);
  flick_iiopxx_check_span(1 * _data->_length, _flick_abort95);
  flick_iiopxx_decode_new_chunk(1 * _data->_length);
  {
    CORBA::Octet *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort95);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_swap_decode_bcopy(0, _data->_buffer, 1 * _data->_length);
  flick_iiopxx_decode_end_chunk(1 * _data->_length);
  flick_iiopxx_decode_end_glob(1 * _data->_length);
  return 0;
  {
  _flick_abort95:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_CORBA_ReferenceString(flick_marshal_stream_t _stream, const ::CORBA::ReferenceString *_data)
{
  CORBA::ULong _t22_array_iter;

  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort98);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  for (_t22_array_iter = 0; _t22_array_iter < _data->_length; _t22_array_iter++)
    {
      flick_unsigned32_t _t24_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, _data->_buffer[_t22_array_iter], flick_unsigned32_t , _t24_temp_string_len);

      flick_iiopxx_encode_new_glob(7, _flick_abort108);
      flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
      flick_cdr_encode_unsigned32(0, _t24_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(4);
      flick_iiopxx_encode_end_glob(7);
      flick_iiopxx_encode_new_glob(1 * _t24_temp_string_len, _flick_abort108);
      flick_iiopxx_encode_new_chunk(1 * _t24_temp_string_len);
      flick_cdr_encode_bcopy(0, _data->_buffer[_t22_array_iter], 1 * _t24_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t24_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t24_temp_string_len);
      continue;
      {
      _flick_abort108:
        goto _flick_abort98;
      }
    }
  return 0;
  {
  _flick_abort98:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ReferenceString(flick_marshal_stream_t _stream, ::CORBA::ReferenceString *_data)
{
  CORBA::ULong _t28_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort114);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  {
    char **_t_alloc_ptr;

    _t_alloc_ptr = (char **)new (char *[_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort114);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  for (_t28_array_iter = 0; _t28_array_iter < _data->_length; _t28_array_iter++)
    {
      flick_unsigned32_t _t30_temp_string_len;

      flick_iiopxx_decode_new_glob(7);
      flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
      flick_iiopxx_check_span(4, _flick_abort127);
      flick_cdr_decode_unsigned32(0, _t30_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_decode_end_chunk(4);
      flick_iiopxx_decode_end_glob(7);
      flick_iiopxx_decode_new_glob(1 * _t30_temp_string_len);
      flick_iiopxx_check_span(1 * _t30_temp_string_len, _flick_abort127);
      flick_iiopxx_decode_new_chunk(1 * _t30_temp_string_len);
      {
        CORBA::Char *_t_alloc_ptr;

        _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t30_temp_string_len * sizeof(CORBA::Char )));
        if (!_t_alloc_ptr)
          flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort127);
        _data->_buffer[_t28_array_iter] = _t_alloc_ptr;
      }
      flick_cdr_decode_bcopy(0, _data->_buffer[_t28_array_iter], 1 * _t30_temp_string_len);
      flick_iiopxx_decode_end_chunk(1 * _t30_temp_string_len);
      flick_iiopxx_decode_end_glob(1 * _t30_temp_string_len);
      continue;
      {
      _flick_abort137:
        _t28_array_iter--;
        CORBA_string_flick_free(_data->_buffer[_t28_array_iter]);
      _flick_abort127:
        if ((unsigned int )_t28_array_iter > 0)
          goto _flick_abort137;
        goto _flick_abort114;
      }
    }
  return 0;
  {
  _flick_abort114:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ReferenceString_swap(flick_marshal_stream_t _stream, ::CORBA::ReferenceString *_data)
{
  CORBA::ULong _t34_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort140);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  {
    char **_t_alloc_ptr;

    _t_alloc_ptr = (char **)new (char *[_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort140);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  for (_t34_array_iter = 0; _t34_array_iter < _data->_length; _t34_array_iter++)
    {
      flick_unsigned32_t _t36_temp_string_len;

      flick_iiopxx_decode_new_glob(7);
      flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
      flick_iiopxx_check_span(4, _flick_abort153);
      flick_cdr_swap_decode_unsigned32(0, _t36_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_decode_end_chunk(4);
      flick_iiopxx_decode_end_glob(7);
      flick_iiopxx_decode_new_glob(1 * _t36_temp_string_len);
      flick_iiopxx_check_span(1 * _t36_temp_string_len, _flick_abort153);
      flick_iiopxx_decode_new_chunk(1 * _t36_temp_string_len);
      {
        CORBA::Char *_t_alloc_ptr;

        _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t36_temp_string_len * sizeof(CORBA::Char )));
        if (!_t_alloc_ptr)
          flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort153);
        _data->_buffer[_t34_array_iter] = _t_alloc_ptr;
      }
      flick_cdr_swap_decode_bcopy(0, _data->_buffer[_t34_array_iter], 1 * _t36_temp_string_len);
      flick_iiopxx_decode_end_chunk(1 * _t36_temp_string_len);
      flick_iiopxx_decode_end_glob(1 * _t36_temp_string_len);
      continue;
      {
      _flick_abort163:
        _t34_array_iter--;
        CORBA_string_flick_free(_data->_buffer[_t34_array_iter]);
      _flick_abort153:
        if ((unsigned int )_t34_array_iter > 0)
          goto _flick_abort163;
        goto _flick_abort140;
      }
    }
  return 0;
  {
  _flick_abort140:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_CORBA_ReferenceLong(flick_marshal_stream_t _stream, const ::CORBA::ReferenceLong *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort166);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  flick_iiopxx_encode_new_glob(4 * _data->_length, _flick_abort166);
  flick_iiopxx_encode_new_chunk(4 * _data->_length);
  flick_cdr_encode_bcopy(0, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_encode_end_chunk(4 * _data->_length);
  flick_iiopxx_encode_end_glob(4 * _data->_length);
  return 0;
  {
  _flick_abort166:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ReferenceLong(flick_marshal_stream_t _stream, ::CORBA::ReferenceLong *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort169);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(4 * _data->_length);
  flick_iiopxx_check_span(4 * _data->_length, _flick_abort169);
  flick_iiopxx_decode_new_chunk(4 * _data->_length);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort169);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_decode_end_chunk(4 * _data->_length);
  flick_iiopxx_decode_end_glob(4 * _data->_length);
  return 0;
  {
  _flick_abort169:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ReferenceLong_swap(flick_marshal_stream_t _stream, ::CORBA::ReferenceLong *_data)
{
  CORBA::ULong _t37_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort172);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  flick_iiopxx_decode_new_glob(4 * _data->_length);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [_data->_length]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort172);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = _data->_length;
    _data->_release = 1;
  }
  flick_iiopxx_check_span(_data->_length * 4, _flick_abort172);
  for (_t37_array_iter = 0; _t37_array_iter < _data->_length; _t37_array_iter++)
    {
      flick_iiopxx_decode_new_chunk(4);
      flick_cdr_swap_decode_signed32(0, _data->_buffer[_t37_array_iter], CORBA::Long );
      flick_iiopxx_decode_end_chunk(4);
      continue;
    }
  flick_iiopxx_decode_end_glob(4 * _data->_length);
  return 0;
  {
  _flick_abort172:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_CORBA_ImplementationDef(flick_marshal_stream_t _stream, const ::CORBA::ImplementationDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, CORBA::ImplementationDef , _flick_abort178);
  return 0;
  {
  _flick_abort178:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ImplementationDef(flick_marshal_stream_t _stream, ::CORBA::ImplementationDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, CORBA::ImplementationDef , _flick_abort179);
  return 0;
  {
  _flick_abort179:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ImplementationDef_swap(flick_marshal_stream_t _stream, ::CORBA::ImplementationDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, CORBA::ImplementationDef , _flick_abort180);
  return 0;
  {
  _flick_abort180:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

char *CORBA::ImplementationDef::interface_name(/* ::CORBA::ImplementationDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  char *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort182);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort182);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort182);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort182);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort182);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t41_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort182);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t41_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t41_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t43_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort204);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t43_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t43_temp_string_len);
              flick_iiopxx_check_span(1 * _t43_temp_string_len, _flick_abort204);
              flick_iiopxx_decode_new_chunk(1 * _t43_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t43_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort204);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t43_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t43_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t43_temp_string_len);
              break;
              {
              _flick_abort204:
                goto _flick_abort182;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort208);
              break;
              {
              _flick_abort208:
                goto _flick_abort182;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort209);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort209:
                goto _flick_abort182;
              }
            }
          }
      }
    else
      {
        int _t38_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort182);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t38_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t38_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t40_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort191);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t40_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t40_temp_string_len);
              flick_iiopxx_check_span(1 * _t40_temp_string_len, _flick_abort191);
              flick_iiopxx_decode_new_chunk(1 * _t40_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t40_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort191);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t40_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t40_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t40_temp_string_len);
              break;
              {
              _flick_abort191:
                goto _flick_abort182;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort195);
              break;
              {
              _flick_abort195:
                goto _flick_abort182;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort196);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort196:
                goto _flick_abort182;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort182:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort181);
    _flick_abort181:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::ImplementationDef::interface_name(/* ::CORBA::ImplementationDef *this, */ const char *interface_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort211);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort211);
    }
    {
      flick_unsigned32_t _t45_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, interface_name, flick_unsigned32_t , _t45_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort211);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t45_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t45_temp_string_len, _flick_abort211);
      flick_iiopxx_encode_new_chunk(1 * _t45_temp_string_len);
      flick_cdr_encode_bcopy(0, interface_name, 1 * _t45_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t45_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t45_temp_string_len);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort211);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort211);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t47_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort211);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t47_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t47_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort229);
              break;
              {
              _flick_abort229:
                goto _flick_abort211;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort230);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort230:
                goto _flick_abort211;
              }
            }
          }
      }
    else
      {
        int _t46_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort211);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t46_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t46_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort222);
              break;
              {
              _flick_abort222:
                goto _flick_abort211;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort223);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort223:
                goto _flick_abort211;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort211:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort210);
    _flick_abort210:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

char *CORBA::ImplementationDef::object_name(/* ::CORBA::ImplementationDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  char *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort232);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort232);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort232);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort232);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort232);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t51_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort232);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t51_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t51_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t53_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort254);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t53_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t53_temp_string_len);
              flick_iiopxx_check_span(1 * _t53_temp_string_len, _flick_abort254);
              flick_iiopxx_decode_new_chunk(1 * _t53_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t53_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort254);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t53_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t53_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t53_temp_string_len);
              break;
              {
              _flick_abort254:
                goto _flick_abort232;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort258);
              break;
              {
              _flick_abort258:
                goto _flick_abort232;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort259);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort259:
                goto _flick_abort232;
              }
            }
          }
      }
    else
      {
        int _t48_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort232);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t48_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t48_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t50_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort241);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t50_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t50_temp_string_len);
              flick_iiopxx_check_span(1 * _t50_temp_string_len, _flick_abort241);
              flick_iiopxx_decode_new_chunk(1 * _t50_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t50_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort241);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t50_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t50_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t50_temp_string_len);
              break;
              {
              _flick_abort241:
                goto _flick_abort232;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort245);
              break;
              {
              _flick_abort245:
                goto _flick_abort232;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort246);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort246:
                goto _flick_abort232;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort232:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort231);
    _flick_abort231:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::ImplementationDef::object_name(/* ::CORBA::ImplementationDef *this, */ const char *object_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort261);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort261);
    }
    {
      flick_unsigned32_t _t55_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, object_name, flick_unsigned32_t , _t55_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort261);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t55_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t55_temp_string_len, _flick_abort261);
      flick_iiopxx_encode_new_chunk(1 * _t55_temp_string_len);
      flick_cdr_encode_bcopy(0, object_name, 1 * _t55_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t55_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t55_temp_string_len);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort261);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort261);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t57_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort261);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t57_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t57_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort279);
              break;
              {
              _flick_abort279:
                goto _flick_abort261;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort280);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort280:
                goto _flick_abort261;
              }
            }
          }
      }
    else
      {
        int _t56_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort261);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t56_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t56_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort272);
              break;
              {
              _flick_abort272:
                goto _flick_abort261;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort273);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort273:
                goto _flick_abort261;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort261:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort260);
    _flick_abort260:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

::CORBA::ReferenceData *CORBA::ImplementationDef::id(/* ::CORBA::ImplementationDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ::CORBA::ReferenceData *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort282);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort282);
    }
    {
      flick_iiopxx_encode_new_glob(16, _flick_abort282);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort282);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort282);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t59_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort282);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t59_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t59_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort301);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort301);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort301);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort301);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort301:
                goto _flick_abort282;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort304);
              break;
              {
              _flick_abort304:
                goto _flick_abort282;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort305);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort305:
                goto _flick_abort282;
              }
            }
          }
      }
    else
      {
        int _t58_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort282);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t58_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t58_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort290);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort290);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort290);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort290);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort290:
                goto _flick_abort282;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort293);
              break;
              {
              _flick_abort293:
                goto _flick_abort282;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort294);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort294:
                goto _flick_abort282;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort282:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort281);
    _flick_abort281:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::ImplementationDef::id(/* ::CORBA::ImplementationDef *this, */ const ::CORBA::ReferenceData &id, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort307);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort307);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort307);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(16, id._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_iiopxx_encode_new_glob(1 * id._length, _flick_abort307);
      flick_iiopxx_encode_new_chunk(1 * id._length);
      flick_cdr_encode_bcopy(0, id._buffer, 1 * id._length);
      flick_iiopxx_encode_end_chunk(1 * id._length);
      flick_iiopxx_encode_end_glob(1 * id._length);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort307);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort307);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t61_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort307);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t61_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t61_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort325);
              break;
              {
              _flick_abort325:
                goto _flick_abort307;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort326);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort326:
                goto _flick_abort307;
              }
            }
          }
      }
    else
      {
        int _t60_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort307);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t60_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t60_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort318);
              break;
              {
              _flick_abort318:
                goto _flick_abort307;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort319);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort319:
                goto _flick_abort307;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort307:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort306);
    _flick_abort306:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

int flick_marshal_stub_CORBA_Policy(flick_marshal_stream_t _stream, const enum ::CORBA::Policy *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort327);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_unsigned32(0, *_data, const enum ::CORBA::Policy );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  return 0;
  {
  _flick_abort327:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_Policy(flick_marshal_stream_t _stream, enum ::CORBA::Policy *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort328);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, *_data, enum ::CORBA::Policy );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  return 0;
  {
  _flick_abort328:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_Policy_swap(flick_marshal_stream_t _stream, enum ::CORBA::Policy *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort329);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, *_data, enum ::CORBA::Policy );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  return 0;
  {
  _flick_abort329:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub_CORBA_CreationImplDef(flick_marshal_stream_t _stream, const ::CORBA::CreationImplDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, CORBA::CreationImplDef , _flick_abort330);
  return 0;
  {
  _flick_abort330:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_CreationImplDef(flick_marshal_stream_t _stream, ::CORBA::CreationImplDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, CORBA::CreationImplDef , _flick_abort331);
  return 0;
  {
  _flick_abort331:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_CreationImplDef_swap(flick_marshal_stream_t _stream, ::CORBA::CreationImplDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, CORBA::CreationImplDef , _flick_abort332);
  return 0;
  {
  _flick_abort332:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

char *CORBA::CreationImplDef::path_name(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  char *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort334);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort334);
    }
    {
      flick_iiopxx_encode_new_glob(24, _flick_abort334);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 15, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'p', flick_char8_t );
      flick_cdr_encode_char8(10, 'a', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'h', flick_char8_t );
      flick_cdr_encode_char8(13, '_', flick_char8_t );
      flick_cdr_encode_char8(14, 'n', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'm', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(20, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort334);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort334);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t65_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort334);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t65_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t65_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t67_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort356);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t67_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t67_temp_string_len);
              flick_iiopxx_check_span(1 * _t67_temp_string_len, _flick_abort356);
              flick_iiopxx_decode_new_chunk(1 * _t67_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t67_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort356);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t67_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t67_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t67_temp_string_len);
              break;
              {
              _flick_abort356:
                goto _flick_abort334;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort360);
              break;
              {
              _flick_abort360:
                goto _flick_abort334;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort361);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort361:
                goto _flick_abort334;
              }
            }
          }
      }
    else
      {
        int _t62_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort334);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t62_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t62_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t64_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort343);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t64_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t64_temp_string_len);
              flick_iiopxx_check_span(1 * _t64_temp_string_len, _flick_abort343);
              flick_iiopxx_decode_new_chunk(1 * _t64_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t64_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort343);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t64_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t64_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t64_temp_string_len);
              break;
              {
              _flick_abort343:
                goto _flick_abort334;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort347);
              break;
              {
              _flick_abort347:
                goto _flick_abort334;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort348);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort348:
                goto _flick_abort334;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort334:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort333);
    _flick_abort333:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::CreationImplDef::path_name(/* ::CORBA::CreationImplDef *this, */ const char *path_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort363);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort363);
    }
    {
      flick_unsigned32_t _t69_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, path_name, flick_unsigned32_t , _t69_temp_string_len);

      flick_iiopxx_encode_new_glob(28, _flick_abort363);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 15, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'p', flick_char8_t );
      flick_cdr_encode_char8(10, 'a', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'h', flick_char8_t );
      flick_cdr_encode_char8(13, '_', flick_char8_t );
      flick_cdr_encode_char8(14, 'n', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'm', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(20, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(24, _t69_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
      flick_iiopxx_encode_new_glob(1 * _t69_temp_string_len, _flick_abort363);
      flick_iiopxx_encode_new_chunk(1 * _t69_temp_string_len);
      flick_cdr_encode_bcopy(0, path_name, 1 * _t69_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t69_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t69_temp_string_len);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort363);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort363);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t71_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort363);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t71_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t71_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort381);
              break;
              {
              _flick_abort381:
                goto _flick_abort363;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort382);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort382:
                goto _flick_abort363;
              }
            }
          }
      }
    else
      {
        int _t70_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort363);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t70_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t70_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort374);
              break;
              {
              _flick_abort374:
                goto _flick_abort363;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort375);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort375:
                goto _flick_abort363;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort363:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort362);
    _flick_abort362:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

enum ::CORBA::Policy CORBA::CreationImplDef::activation_policy(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  enum ::CORBA::Policy _return;

  _return = SHARED_SERVER;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort384);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort384);
    }
    {
      flick_iiopxx_encode_new_glob(32, _flick_abort384);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 23, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'i', flick_char8_t );
      flick_cdr_encode_char8(17, 'o', flick_char8_t );
      flick_cdr_encode_char8(18, 'n', flick_char8_t );
      flick_cdr_encode_char8(19, '_', flick_char8_t );
      flick_cdr_encode_char8(20, 'p', flick_char8_t );
      flick_cdr_encode_char8(21, 'o', flick_char8_t );
      flick_cdr_encode_char8(22, 'l', flick_char8_t );
      flick_cdr_encode_char8(23, 'i', flick_char8_t );
      flick_cdr_encode_char8(24, 'c', flick_char8_t );
      flick_cdr_encode_char8(25, 'y', flick_char8_t );
      flick_cdr_encode_char8(26, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(28, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort384);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort384);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t73_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort384);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t73_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t73_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort397);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return, enum ::CORBA::Policy );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort397:
                goto _flick_abort384;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort398);
              break;
              {
              _flick_abort398:
                goto _flick_abort384;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort399);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort399:
                goto _flick_abort384;
              }
            }
          }
      }
    else
      {
        int _t72_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort384);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t72_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t72_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort390);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return, enum ::CORBA::Policy );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort390:
                goto _flick_abort384;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort391);
              break;
              {
              _flick_abort391:
                goto _flick_abort384;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort392);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort392:
                goto _flick_abort384;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort384:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort383);
    _flick_abort383:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::CreationImplDef::activation_policy(/* ::CORBA::CreationImplDef *this, */ enum ::CORBA::Policy activation_policy, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort401);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort401);
    }
    {
      flick_iiopxx_encode_new_glob(36, _flick_abort401);
      flick_iiopxx_encode_new_chunk(36);
      flick_cdr_encode_unsigned32(0, 23, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'i', flick_char8_t );
      flick_cdr_encode_char8(17, 'o', flick_char8_t );
      flick_cdr_encode_char8(18, 'n', flick_char8_t );
      flick_cdr_encode_char8(19, '_', flick_char8_t );
      flick_cdr_encode_char8(20, 'p', flick_char8_t );
      flick_cdr_encode_char8(21, 'o', flick_char8_t );
      flick_cdr_encode_char8(22, 'l', flick_char8_t );
      flick_cdr_encode_char8(23, 'i', flick_char8_t );
      flick_cdr_encode_char8(24, 'c', flick_char8_t );
      flick_cdr_encode_char8(25, 'y', flick_char8_t );
      flick_cdr_encode_char8(26, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(28, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(32, activation_policy, enum ::CORBA::Policy );
      flick_iiopxx_encode_end_chunk(36);
      flick_iiopxx_encode_end_glob(36);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort401);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort401);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t75_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort401);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t75_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t75_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort415);
              break;
              {
              _flick_abort415:
                goto _flick_abort401;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort416);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort416:
                goto _flick_abort401;
              }
            }
          }
      }
    else
      {
        int _t74_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort401);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t74_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t74_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort408);
              break;
              {
              _flick_abort408:
                goto _flick_abort401;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort409);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort409:
                goto _flick_abort401;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort401:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort400);
    _flick_abort400:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

::CORBA::StringSequence *CORBA::CreationImplDef::args(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ::CORBA::StringSequence *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort418);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort418);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort418);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'r', flick_char8_t );
      flick_cdr_encode_char8(11, 'g', flick_char8_t );
      flick_cdr_encode_char8(12, 's', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort418);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort418);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t89_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort418);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t89_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t89_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t99_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort506);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort506);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort506);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t99_array_iter = 0; _t99_array_iter < _return->_length; _t99_array_iter++)
                {
                  flick_unsigned32_t _t101_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort519);
                  flick_cdr_swap_decode_unsigned32(0, _t101_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t101_temp_string_len);
                  flick_iiopxx_check_span(1 * _t101_temp_string_len, _flick_abort519);
                  flick_iiopxx_decode_new_chunk(1 * _t101_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t101_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort519);
                    _return->_buffer[_t99_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_swap_decode_bcopy(0, _return->_buffer[_t99_array_iter], 1 * _t101_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t101_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t101_temp_string_len);
                  continue;
                  {
                  _flick_abort529:
                    _t99_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t99_array_iter]);
                  _flick_abort519:
                    if ((unsigned int )_t99_array_iter > 0)
                      goto _flick_abort529;
                    goto _flick_abort506;
                  }
                }
              break;
              {
              _flick_abort506:
                goto _flick_abort418;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort532);
              break;
              {
              _flick_abort532:
                goto _flick_abort418;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort533);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort533:
                goto _flick_abort418;
              }
            }
          }
      }
    else
      {
        int _t76_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort418);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t76_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t76_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t86_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort449);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort449);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort449);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t86_array_iter = 0; _t86_array_iter < _return->_length; _t86_array_iter++)
                {
                  flick_unsigned32_t _t88_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort462);
                  flick_cdr_decode_unsigned32(0, _t88_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t88_temp_string_len);
                  flick_iiopxx_check_span(1 * _t88_temp_string_len, _flick_abort462);
                  flick_iiopxx_decode_new_chunk(1 * _t88_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t88_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort462);
                    _return->_buffer[_t86_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_decode_bcopy(0, _return->_buffer[_t86_array_iter], 1 * _t88_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t88_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t88_temp_string_len);
                  continue;
                  {
                  _flick_abort472:
                    _t86_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t86_array_iter]);
                  _flick_abort462:
                    if ((unsigned int )_t86_array_iter > 0)
                      goto _flick_abort472;
                    goto _flick_abort449;
                  }
                }
              break;
              {
              _flick_abort449:
                goto _flick_abort418;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort475);
              break;
              {
              _flick_abort475:
                goto _flick_abort418;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort476);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort476:
                goto _flick_abort418;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort418:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort417);
    _flick_abort417:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::CreationImplDef::args(/* ::CORBA::CreationImplDef *this, */ const ::CORBA::StringSequence &args, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort535);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort535);
    }
    {
      CORBA::ULong _t111_array_iter;

      flick_iiopxx_encode_new_glob(24, _flick_abort535);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 10, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'r', flick_char8_t );
      flick_cdr_encode_char8(11, 'g', flick_char8_t );
      flick_cdr_encode_char8(12, 's', flick_char8_t );
      flick_cdr_encode_char8(13, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, args._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
      for (_t111_array_iter = 0; _t111_array_iter < args._length; _t111_array_iter++)
        {
          flick_unsigned32_t _t113_temp_string_len;

          flick_cdr_stringlen(CORBA::Char *, args._buffer[_t111_array_iter], flick_unsigned32_t , _t113_temp_string_len);

          flick_iiopxx_encode_new_glob(7, _flick_abort561);
          flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
          flick_cdr_encode_unsigned32(0, _t113_temp_string_len, flick_unsigned32_t );
          flick_iiopxx_encode_end_chunk(4);
          flick_iiopxx_encode_end_glob(7);
          flick_iiopxx_encode_new_glob(1 * _t113_temp_string_len, _flick_abort561);
          flick_iiopxx_encode_new_chunk(1 * _t113_temp_string_len);
          flick_cdr_encode_bcopy(0, args._buffer[_t111_array_iter], 1 * _t113_temp_string_len);
          flick_iiopxx_encode_end_chunk(1 * _t113_temp_string_len);
          flick_iiopxx_encode_end_glob(1 * _t113_temp_string_len);
          continue;
          {
          _flick_abort561:
            goto _flick_abort535;
          }
        }
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort535);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort535);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t115_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort535);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t115_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t115_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort579);
              break;
              {
              _flick_abort579:
                goto _flick_abort535;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort580);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort580:
                goto _flick_abort535;
              }
            }
          }
      }
    else
      {
        int _t114_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort535);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t114_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t114_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort572);
              break;
              {
              _flick_abort572:
                goto _flick_abort535;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort573);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort573:
                goto _flick_abort535;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort535:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort534);
    _flick_abort534:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

::CORBA::StringSequence *CORBA::CreationImplDef::env(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ::CORBA::StringSequence *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort582);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort582);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort582);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'e', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'v', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort582);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort582);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t129_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort582);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t129_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t129_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t139_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort670);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort670);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort670);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t139_array_iter = 0; _t139_array_iter < _return->_length; _t139_array_iter++)
                {
                  flick_unsigned32_t _t141_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort683);
                  flick_cdr_swap_decode_unsigned32(0, _t141_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t141_temp_string_len);
                  flick_iiopxx_check_span(1 * _t141_temp_string_len, _flick_abort683);
                  flick_iiopxx_decode_new_chunk(1 * _t141_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t141_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort683);
                    _return->_buffer[_t139_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_swap_decode_bcopy(0, _return->_buffer[_t139_array_iter], 1 * _t141_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t141_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t141_temp_string_len);
                  continue;
                  {
                  _flick_abort693:
                    _t139_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t139_array_iter]);
                  _flick_abort683:
                    if ((unsigned int )_t139_array_iter > 0)
                      goto _flick_abort693;
                    goto _flick_abort670;
                  }
                }
              break;
              {
              _flick_abort670:
                goto _flick_abort582;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort696);
              break;
              {
              _flick_abort696:
                goto _flick_abort582;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort697);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort697:
                goto _flick_abort582;
              }
            }
          }
      }
    else
      {
        int _t116_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort582);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t116_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t116_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t126_array_iter;

              /* Begin decode phase on parameters */
              {
                ::CORBA::StringSequence *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::StringSequence *)new ::CORBA::StringSequence ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort613);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort613);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                char **_t_alloc_ptr;

                _t_alloc_ptr = (char **)new (char *[_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort613);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t126_array_iter = 0; _t126_array_iter < _return->_length; _t126_array_iter++)
                {
                  flick_unsigned32_t _t128_temp_string_len;

                  flick_iiopxx_decode_new_glob(7);
                  flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
                  flick_iiopxx_check_span(4, _flick_abort626);
                  flick_cdr_decode_unsigned32(0, _t128_temp_string_len, flick_unsigned32_t );
                  flick_iiopxx_decode_end_chunk(4);
                  flick_iiopxx_decode_end_glob(7);
                  flick_iiopxx_decode_new_glob(1 * _t128_temp_string_len);
                  flick_iiopxx_check_span(1 * _t128_temp_string_len, _flick_abort626);
                  flick_iiopxx_decode_new_chunk(1 * _t128_temp_string_len);
                  {
                    CORBA::Char *_t_alloc_ptr;

                    _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t128_temp_string_len * sizeof(CORBA::Char )));
                    if (!_t_alloc_ptr)
                      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort626);
                    _return->_buffer[_t126_array_iter] = _t_alloc_ptr;
                  }
                  flick_cdr_decode_bcopy(0, _return->_buffer[_t126_array_iter], 1 * _t128_temp_string_len);
                  flick_iiopxx_decode_end_chunk(1 * _t128_temp_string_len);
                  flick_iiopxx_decode_end_glob(1 * _t128_temp_string_len);
                  continue;
                  {
                  _flick_abort636:
                    _t126_array_iter--;
                    CORBA_string_flick_free(_return->_buffer[_t126_array_iter]);
                  _flick_abort626:
                    if ((unsigned int )_t126_array_iter > 0)
                      goto _flick_abort636;
                    goto _flick_abort613;
                  }
                }
              break;
              {
              _flick_abort613:
                goto _flick_abort582;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort639);
              break;
              {
              _flick_abort639:
                goto _flick_abort582;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort640);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort640:
                goto _flick_abort582;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort582:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort581);
    _flick_abort581:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::CreationImplDef::env(/* ::CORBA::CreationImplDef *this, */ const ::CORBA::StringSequence &env, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort699);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort699);
    }
    {
      CORBA::ULong _t151_array_iter;

      flick_iiopxx_encode_new_glob(24, _flick_abort699);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'e', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 'v', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, env._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
      for (_t151_array_iter = 0; _t151_array_iter < env._length; _t151_array_iter++)
        {
          flick_unsigned32_t _t153_temp_string_len;

          flick_cdr_stringlen(CORBA::Char *, env._buffer[_t151_array_iter], flick_unsigned32_t , _t153_temp_string_len);

          flick_iiopxx_encode_new_glob(7, _flick_abort725);
          flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
          flick_cdr_encode_unsigned32(0, _t153_temp_string_len, flick_unsigned32_t );
          flick_iiopxx_encode_end_chunk(4);
          flick_iiopxx_encode_end_glob(7);
          flick_iiopxx_encode_new_glob(1 * _t153_temp_string_len, _flick_abort725);
          flick_iiopxx_encode_new_chunk(1 * _t153_temp_string_len);
          flick_cdr_encode_bcopy(0, env._buffer[_t151_array_iter], 1 * _t153_temp_string_len);
          flick_iiopxx_encode_end_chunk(1 * _t153_temp_string_len);
          flick_iiopxx_encode_end_glob(1 * _t153_temp_string_len);
          continue;
          {
          _flick_abort725:
            goto _flick_abort699;
          }
        }
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort699);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort699);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t155_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort699);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t155_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t155_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort743);
              break;
              {
              _flick_abort743:
                goto _flick_abort699;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort744);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort744:
                goto _flick_abort699;
              }
            }
          }
      }
    else
      {
        int _t154_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort699);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t154_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t154_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort736);
              break;
              {
              _flick_abort736:
                goto _flick_abort699;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort737);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort737:
                goto _flick_abort699;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort699:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort698);
    _flick_abort698:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

char *CORBA::CreationImplDef::interface_name(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  char *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort746);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort746);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort746);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort746);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort746);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t159_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort746);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t159_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t159_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t161_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort768);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t161_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t161_temp_string_len);
              flick_iiopxx_check_span(1 * _t161_temp_string_len, _flick_abort768);
              flick_iiopxx_decode_new_chunk(1 * _t161_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t161_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort768);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t161_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t161_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t161_temp_string_len);
              break;
              {
              _flick_abort768:
                goto _flick_abort746;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort772);
              break;
              {
              _flick_abort772:
                goto _flick_abort746;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort773);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort773:
                goto _flick_abort746;
              }
            }
          }
      }
    else
      {
        int _t156_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort746);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t156_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t156_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t158_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort755);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t158_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t158_temp_string_len);
              flick_iiopxx_check_span(1 * _t158_temp_string_len, _flick_abort755);
              flick_iiopxx_decode_new_chunk(1 * _t158_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t158_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort755);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t158_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t158_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t158_temp_string_len);
              break;
              {
              _flick_abort755:
                goto _flick_abort746;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort759);
              break;
              {
              _flick_abort759:
                goto _flick_abort746;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort760);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort760:
                goto _flick_abort746;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort746:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort745);
    _flick_abort745:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::CreationImplDef::interface_name(/* ::CORBA::CreationImplDef *this, */ const char *interface_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort775);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort775);
    }
    {
      flick_unsigned32_t _t163_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, interface_name, flick_unsigned32_t , _t163_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort775);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t163_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t163_temp_string_len, _flick_abort775);
      flick_iiopxx_encode_new_chunk(1 * _t163_temp_string_len);
      flick_cdr_encode_bcopy(0, interface_name, 1 * _t163_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t163_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t163_temp_string_len);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort775);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort775);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t165_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort775);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t165_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t165_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort793);
              break;
              {
              _flick_abort793:
                goto _flick_abort775;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort794);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort794:
                goto _flick_abort775;
              }
            }
          }
      }
    else
      {
        int _t164_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort775);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t164_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t164_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort786);
              break;
              {
              _flick_abort786:
                goto _flick_abort775;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort787);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort787:
                goto _flick_abort775;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort775:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort774);
    _flick_abort774:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

char *CORBA::CreationImplDef::object_name(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  char *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort796);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort796);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort796);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort796);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort796);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t169_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort796);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t169_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t169_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t171_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort818);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t171_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t171_temp_string_len);
              flick_iiopxx_check_span(1 * _t171_temp_string_len, _flick_abort818);
              flick_iiopxx_decode_new_chunk(1 * _t171_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t171_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort818);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t171_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t171_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t171_temp_string_len);
              break;
              {
              _flick_abort818:
                goto _flick_abort796;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort822);
              break;
              {
              _flick_abort822:
                goto _flick_abort796;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort823);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort823:
                goto _flick_abort796;
              }
            }
          }
      }
    else
      {
        int _t166_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort796);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t166_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t166_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t168_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort805);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t168_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t168_temp_string_len);
              flick_iiopxx_check_span(1 * _t168_temp_string_len, _flick_abort805);
              flick_iiopxx_decode_new_chunk(1 * _t168_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t168_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort805);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t168_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t168_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t168_temp_string_len);
              break;
              {
              _flick_abort805:
                goto _flick_abort796;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort809);
              break;
              {
              _flick_abort809:
                goto _flick_abort796;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort810);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort810:
                goto _flick_abort796;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort796:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort795);
    _flick_abort795:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::CreationImplDef::object_name(/* ::CORBA::CreationImplDef *this, */ const char *object_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort825);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort825);
    }
    {
      flick_unsigned32_t _t173_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, object_name, flick_unsigned32_t , _t173_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort825);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t173_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t173_temp_string_len, _flick_abort825);
      flick_iiopxx_encode_new_chunk(1 * _t173_temp_string_len);
      flick_cdr_encode_bcopy(0, object_name, 1 * _t173_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t173_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t173_temp_string_len);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort825);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort825);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t175_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort825);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t175_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t175_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort843);
              break;
              {
              _flick_abort843:
                goto _flick_abort825;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort844);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort844:
                goto _flick_abort825;
              }
            }
          }
      }
    else
      {
        int _t174_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort825);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t174_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t174_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort836);
              break;
              {
              _flick_abort836:
                goto _flick_abort825;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort837);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort837:
                goto _flick_abort825;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort825:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort824);
    _flick_abort824:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

::CORBA::ReferenceData *CORBA::CreationImplDef::id(/* ::CORBA::CreationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ::CORBA::ReferenceData *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort846);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort846);
    }
    {
      flick_iiopxx_encode_new_glob(16, _flick_abort846);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort846);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort846);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t177_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort846);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t177_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t177_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort865);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort865);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort865);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort865);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort865:
                goto _flick_abort846;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort868);
              break;
              {
              _flick_abort868:
                goto _flick_abort846;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort869);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort869:
                goto _flick_abort846;
              }
            }
          }
      }
    else
      {
        int _t176_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort846);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t176_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t176_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort854);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort854);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort854);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort854);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort854:
                goto _flick_abort846;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort857);
              break;
              {
              _flick_abort857:
                goto _flick_abort846;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort858);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort858:
                goto _flick_abort846;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort846:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort845);
    _flick_abort845:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::CreationImplDef::id(/* ::CORBA::CreationImplDef *this, */ const ::CORBA::ReferenceData &id, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort871);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort871);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort871);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(16, id._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_iiopxx_encode_new_glob(1 * id._length, _flick_abort871);
      flick_iiopxx_encode_new_chunk(1 * id._length);
      flick_cdr_encode_bcopy(0, id._buffer, 1 * id._length);
      flick_iiopxx_encode_end_chunk(1 * id._length);
      flick_iiopxx_encode_end_glob(1 * id._length);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort871);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort871);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t179_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort871);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t179_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t179_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort889);
              break;
              {
              _flick_abort889:
                goto _flick_abort871;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort890);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort890:
                goto _flick_abort871;
              }
            }
          }
      }
    else
      {
        int _t178_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort871);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t178_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t178_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort882);
              break;
              {
              _flick_abort882:
                goto _flick_abort871;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort883);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort883:
                goto _flick_abort871;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort871:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort870);
    _flick_abort870:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

int flick_marshal_stub_CORBA_Activator(flick_marshal_stream_t _stream, const ::CORBA::Activator_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, CORBA::Activator , _flick_abort891);
  return 0;
  {
  _flick_abort891:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_Activator(flick_marshal_stream_t _stream, ::CORBA::Activator_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, CORBA::Activator , _flick_abort892);
  return 0;
  {
  _flick_abort892:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_Activator_swap(flick_marshal_stream_t _stream, ::CORBA::Activator_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, CORBA::Activator , _flick_abort893);
  return 0;
  {
  _flick_abort893:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

::CORBA::Object_ptr CORBA::Activator::activate(/* ::CORBA::Activator *this, */ ::CORBA::ImplementationDef_ptr impl, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ::CORBA::Object_ptr _return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort895);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort895);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort895);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 9, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'a', flick_char8_t );
      flick_cdr_encode_char8(5, 'c', flick_char8_t );
      flick_cdr_encode_char8(6, 't', flick_char8_t );
      flick_cdr_encode_char8(7, 'i', flick_char8_t );
      flick_cdr_encode_char8(8, 'v', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 't', flick_char8_t );
      flick_cdr_encode_char8(11, 'e', flick_char8_t );
      flick_cdr_encode_char8(12, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_cdrxx_encode_IOR(iiopxx, impl, 0, CORBA::ImplementationDef , _flick_abort895);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort895);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort895);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t181_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort895);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t181_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t181_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdr_swapxx_decode_IOR(iiopxx, _return, 1, CORBA::Object , _flick_abort908);
              break;
              {
              _flick_abort908:
                goto _flick_abort895;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort909);
              break;
              {
              _flick_abort909:
                goto _flick_abort895;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort910);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort910:
                goto _flick_abort895;
              }
            }
          }
      }
    else
      {
        int _t180_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort895);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t180_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t180_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdrxx_decode_IOR(iiopxx, _return, 1, CORBA::Object , _flick_abort901);
              break;
              {
              _flick_abort901:
                goto _flick_abort895;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort902);
              break;
              {
              _flick_abort902:
                goto _flick_abort895;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort903);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort903:
                goto _flick_abort895;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort895:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort894);
    _flick_abort894:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::Activator::deactivate(/* ::CORBA::Activator *this, */ ::CORBA::Object_ptr obj, ::CORBA::ImplementationDef_ptr impl, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort912);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort912);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort912);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 11, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'd', flick_char8_t );
      flick_cdr_encode_char8(5, 'e', flick_char8_t );
      flick_cdr_encode_char8(6, 'a', flick_char8_t );
      flick_cdr_encode_char8(7, 'c', flick_char8_t );
      flick_cdr_encode_char8(8, 't', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'v', flick_char8_t );
      flick_cdr_encode_char8(11, 'a', flick_char8_t );
      flick_cdr_encode_char8(12, 't', flick_char8_t );
      flick_cdr_encode_char8(13, 'e', flick_char8_t );
      flick_cdr_encode_char8(14, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_cdrxx_encode_IOR(iiopxx, obj, 0, CORBA::Object , _flick_abort912);
      flick_cdrxx_encode_IOR(iiopxx, impl, 0, CORBA::ImplementationDef , _flick_abort912);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort912);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort912);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t183_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort912);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t183_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t183_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort926);
              break;
              {
              _flick_abort926:
                goto _flick_abort912;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort927);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort927:
                goto _flick_abort912;
              }
            }
          }
      }
    else
      {
        int _t182_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort912);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t182_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t182_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort919);
              break;
              {
              _flick_abort919:
                goto _flick_abort912;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort920);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort920:
                goto _flick_abort912;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort912:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort911);
    _flick_abort911:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

int flick_marshal_stub_CORBA_ActivationImplDef(flick_marshal_stream_t _stream, const ::CORBA::ActivationImplDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, CORBA::ActivationImplDef , _flick_abort928);
  return 0;
  {
  _flick_abort928:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ActivationImplDef(flick_marshal_stream_t _stream, ::CORBA::ActivationImplDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, CORBA::ActivationImplDef , _flick_abort929);
  return 0;
  {
  _flick_abort929:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_CORBA_ActivationImplDef_swap(flick_marshal_stream_t _stream, ::CORBA::ActivationImplDef_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, CORBA::ActivationImplDef , _flick_abort930);
  return 0;
  {
  _flick_abort930:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

::CORBA::Activator_ptr CORBA::ActivationImplDef::activator_obj(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ::CORBA::Activator_ptr _return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort932);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort932);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort932);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 19, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'o', flick_char8_t );
      flick_cdr_encode_char8(17, 'r', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'o', flick_char8_t );
      flick_cdr_encode_char8(20, 'b', flick_char8_t );
      flick_cdr_encode_char8(21, 'j', flick_char8_t );
      flick_cdr_encode_char8(22, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort932);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort932);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t185_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort932);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t185_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t185_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdr_swapxx_decode_IOR(iiopxx, _return, 1, CORBA::Activator , _flick_abort945);
              break;
              {
              _flick_abort945:
                goto _flick_abort932;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort946);
              break;
              {
              _flick_abort946:
                goto _flick_abort932;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort947);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort947:
                goto _flick_abort932;
              }
            }
          }
      }
    else
      {
        int _t184_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort932);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t184_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t184_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              flick_cdrxx_decode_IOR(iiopxx, _return, 1, CORBA::Activator , _flick_abort938);
              break;
              {
              _flick_abort938:
                goto _flick_abort932;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort939);
              break;
              {
              _flick_abort939:
                goto _flick_abort932;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort940);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort940:
                goto _flick_abort932;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort932:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort931);
    _flick_abort931:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::ActivationImplDef::activator_obj(/* ::CORBA::ActivationImplDef *this, */ ::CORBA::Activator_ptr activator_obj, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort949);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort949);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort949);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 19, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'a', flick_char8_t );
      flick_cdr_encode_char8(10, 'c', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'i', flick_char8_t );
      flick_cdr_encode_char8(13, 'v', flick_char8_t );
      flick_cdr_encode_char8(14, 'a', flick_char8_t );
      flick_cdr_encode_char8(15, 't', flick_char8_t );
      flick_cdr_encode_char8(16, 'o', flick_char8_t );
      flick_cdr_encode_char8(17, 'r', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'o', flick_char8_t );
      flick_cdr_encode_char8(20, 'b', flick_char8_t );
      flick_cdr_encode_char8(21, 'j', flick_char8_t );
      flick_cdr_encode_char8(22, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
      flick_cdrxx_encode_IOR(iiopxx, activator_obj, 0, CORBA::Activator , _flick_abort949);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort949);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort949);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t187_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort949);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t187_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t187_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort963);
              break;
              {
              _flick_abort963:
                goto _flick_abort949;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort964);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort964:
                goto _flick_abort949;
              }
            }
          }
      }
    else
      {
        int _t186_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort949);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t186_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t186_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort956);
              break;
              {
              _flick_abort956:
                goto _flick_abort949;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort957);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort957:
                goto _flick_abort949;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort949:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort948);
    _flick_abort948:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

char *CORBA::ActivationImplDef::interface_name(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  char *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort966);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort966);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort966);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort966);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort966);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t191_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort966);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t191_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t191_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t193_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort988);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t193_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t193_temp_string_len);
              flick_iiopxx_check_span(1 * _t193_temp_string_len, _flick_abort988);
              flick_iiopxx_decode_new_chunk(1 * _t193_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t193_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort988);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t193_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t193_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t193_temp_string_len);
              break;
              {
              _flick_abort988:
                goto _flick_abort966;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort992);
              break;
              {
              _flick_abort992:
                goto _flick_abort966;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort993);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort993:
                goto _flick_abort966;
              }
            }
          }
      }
    else
      {
        int _t188_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort966);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t188_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t188_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t190_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort975);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t190_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t190_temp_string_len);
              flick_iiopxx_check_span(1 * _t190_temp_string_len, _flick_abort975);
              flick_iiopxx_decode_new_chunk(1 * _t190_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t190_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort975);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t190_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t190_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t190_temp_string_len);
              break;
              {
              _flick_abort975:
                goto _flick_abort966;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort979);
              break;
              {
              _flick_abort979:
                goto _flick_abort966;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort980);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort980:
                goto _flick_abort966;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort966:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort965);
    _flick_abort965:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::ActivationImplDef::interface_name(/* ::CORBA::ActivationImplDef *this, */ const char *interface_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort995);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort995);
    }
    {
      flick_unsigned32_t _t195_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, interface_name, flick_unsigned32_t , _t195_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort995);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 20, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'n', flick_char8_t );
      flick_cdr_encode_char8(11, 't', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'f', flick_char8_t );
      flick_cdr_encode_char8(15, 'a', flick_char8_t );
      flick_cdr_encode_char8(16, 'c', flick_char8_t );
      flick_cdr_encode_char8(17, 'e', flick_char8_t );
      flick_cdr_encode_char8(18, '_', flick_char8_t );
      flick_cdr_encode_char8(19, 'n', flick_char8_t );
      flick_cdr_encode_char8(20, 'a', flick_char8_t );
      flick_cdr_encode_char8(21, 'm', flick_char8_t );
      flick_cdr_encode_char8(22, 'e', flick_char8_t );
      flick_cdr_encode_char8(23, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t195_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t195_temp_string_len, _flick_abort995);
      flick_iiopxx_encode_new_chunk(1 * _t195_temp_string_len);
      flick_cdr_encode_bcopy(0, interface_name, 1 * _t195_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t195_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t195_temp_string_len);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort995);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort995);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t197_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort995);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t197_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t197_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort1013);
              break;
              {
              _flick_abort1013:
                goto _flick_abort995;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1014);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort1014:
                goto _flick_abort995;
              }
            }
          }
      }
    else
      {
        int _t196_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort995);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t196_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t196_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort1006);
              break;
              {
              _flick_abort1006:
                goto _flick_abort995;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1007);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort1007:
                goto _flick_abort995;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort995:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort994);
    _flick_abort994:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

char *CORBA::ActivationImplDef::object_name(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  char *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1016);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1016);
    }
    {
      flick_iiopxx_encode_new_glob(28, _flick_abort1016);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1016);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1016);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t201_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1016);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t201_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t201_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t203_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort1038);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t203_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t203_temp_string_len);
              flick_iiopxx_check_span(1 * _t203_temp_string_len, _flick_abort1038);
              flick_iiopxx_decode_new_chunk(1 * _t203_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t203_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort1038);
                _return = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_bcopy(0, _return, 1 * _t203_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t203_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t203_temp_string_len);
              break;
              {
              _flick_abort1038:
                goto _flick_abort1016;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort1042);
              break;
              {
              _flick_abort1042:
                goto _flick_abort1016;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1043);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort1043:
                goto _flick_abort1016;
              }
            }
          }
      }
    else
      {
        int _t198_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1016);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t198_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t198_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              flick_unsigned32_t _t200_temp_string_len;

              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort1025);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t200_temp_string_len, flick_unsigned32_t );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _t200_temp_string_len);
              flick_iiopxx_check_span(1 * _t200_temp_string_len, _flick_abort1025);
              flick_iiopxx_decode_new_chunk(1 * _t200_temp_string_len);
              {
                CORBA::Char *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Char *)(CORBA_string_flick_alloc(_t200_temp_string_len * sizeof(CORBA::Char )));
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort1025);
                _return = _t_alloc_ptr;
              }
              flick_cdr_decode_bcopy(0, _return, 1 * _t200_temp_string_len);
              flick_iiopxx_decode_end_chunk(1 * _t200_temp_string_len);
              flick_iiopxx_decode_end_glob(1 * _t200_temp_string_len);
              break;
              {
              _flick_abort1025:
                goto _flick_abort1016;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort1029);
              break;
              {
              _flick_abort1029:
                goto _flick_abort1016;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1030);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort1030:
                goto _flick_abort1016;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort1016:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort1015);
    _flick_abort1015:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::ActivationImplDef::object_name(/* ::CORBA::ActivationImplDef *this, */ const char *object_name, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1045);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1045);
    }
    {
      flick_unsigned32_t _t205_temp_string_len;

      flick_cdr_stringlen(CORBA::Char *, object_name, flick_unsigned32_t , _t205_temp_string_len);

      flick_iiopxx_encode_new_glob(32, _flick_abort1045);
      flick_iiopxx_encode_new_chunk(32);
      flick_cdr_encode_unsigned32(0, 17, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'o', flick_char8_t );
      flick_cdr_encode_char8(10, 'b', flick_char8_t );
      flick_cdr_encode_char8(11, 'j', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'c', flick_char8_t );
      flick_cdr_encode_char8(14, 't', flick_char8_t );
      flick_cdr_encode_char8(15, '_', flick_char8_t );
      flick_cdr_encode_char8(16, 'n', flick_char8_t );
      flick_cdr_encode_char8(17, 'a', flick_char8_t );
      flick_cdr_encode_char8(18, 'm', flick_char8_t );
      flick_cdr_encode_char8(19, 'e', flick_char8_t );
      flick_cdr_encode_char8(20, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(24, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(28, _t205_temp_string_len, flick_unsigned32_t );
      flick_iiopxx_encode_end_chunk(32);
      flick_iiopxx_encode_end_glob(32);
      flick_iiopxx_encode_new_glob(1 * _t205_temp_string_len, _flick_abort1045);
      flick_iiopxx_encode_new_chunk(1 * _t205_temp_string_len);
      flick_cdr_encode_bcopy(0, object_name, 1 * _t205_temp_string_len);
      flick_iiopxx_encode_end_chunk(1 * _t205_temp_string_len);
      flick_iiopxx_encode_end_glob(1 * _t205_temp_string_len);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1045);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1045);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t207_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort1045);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t207_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t207_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort1063);
              break;
              {
              _flick_abort1063:
                goto _flick_abort1045;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1064);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort1064:
                goto _flick_abort1045;
              }
            }
          }
      }
    else
      {
        int _t206_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort1045);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t206_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t206_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort1056);
              break;
              {
              _flick_abort1056:
                goto _flick_abort1045;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1057);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort1057:
                goto _flick_abort1045;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort1045:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort1044);
    _flick_abort1044:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

::CORBA::ReferenceData *CORBA::ActivationImplDef::id(/* ::CORBA::ActivationImplDef *this, */ CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  ::CORBA::ReferenceData *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1066);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1066);
    }
    {
      flick_iiopxx_encode_new_glob(16, _flick_abort1066);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 'g', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1066);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1066);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t209_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1066);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t209_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t209_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort1085);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort1085);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort1085);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort1085);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_swap_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort1085:
                goto _flick_abort1066;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort1088);
              break;
              {
              _flick_abort1088:
                goto _flick_abort1066;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1089);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort1089:
                goto _flick_abort1066;
              }
            }
          }
      }
    else
      {
        int _t208_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort1066);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t208_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t208_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                ::CORBA::ReferenceData *_t_alloc_ptr;

                _t_alloc_ptr = (::CORBA::ReferenceData *)new ::CORBA::ReferenceData ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort1074);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort1074);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_iiopxx_decode_new_glob(1 * _return->_length);
              flick_iiopxx_check_span(1 * _return->_length, _flick_abort1074);
              flick_iiopxx_decode_new_chunk(1 * _return->_length);
              {
                CORBA::Octet *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Octet *)new (CORBA::Octet [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort1074);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              flick_cdr_decode_bcopy(0, _return->_buffer, 1 * _return->_length);
              flick_iiopxx_decode_end_chunk(1 * _return->_length);
              flick_iiopxx_decode_end_glob(1 * _return->_length);
              break;
              {
              _flick_abort1074:
                goto _flick_abort1066;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort1077);
              break;
              {
              _flick_abort1077:
                goto _flick_abort1066;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1078);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort1078:
                goto _flick_abort1066;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort1066:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort1065);
    _flick_abort1065:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

void CORBA::ActivationImplDef::id(/* ::CORBA::ActivationImplDef *this, */ const ::CORBA::ReferenceData &id, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1091);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1091);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort1091);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 8, flick_unsigned32_t );
      flick_cdr_encode_char8(4, '_', flick_char8_t );
      flick_cdr_encode_char8(5, 's', flick_char8_t );
      flick_cdr_encode_char8(6, 'e', flick_char8_t );
      flick_cdr_encode_char8(7, 't', flick_char8_t );
      flick_cdr_encode_char8(8, '_', flick_char8_t );
      flick_cdr_encode_char8(9, 'i', flick_char8_t );
      flick_cdr_encode_char8(10, 'd', flick_char8_t );
      flick_cdr_encode_char8(11, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(16, id._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
      flick_iiopxx_encode_new_glob(1 * id._length, _flick_abort1091);
      flick_iiopxx_encode_new_chunk(1 * id._length);
      flick_cdr_encode_bcopy(0, id._buffer, 1 * id._length);
      flick_iiopxx_encode_end_chunk(1 * id._length);
      flick_iiopxx_encode_end_glob(1 * id._length);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1091);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1091);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t211_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort1091);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t211_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t211_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort1109);
              break;
              {
              _flick_abort1109:
                goto _flick_abort1091;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1110);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort1110:
                goto _flick_abort1091;
              }
            }
          }
      }
    else
      {
        int _t210_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort1091);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t210_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t210_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_decode_end_glob(4);
              break;
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort1102);
              break;
              {
              _flick_abort1102:
                goto _flick_abort1091;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort1103);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort1103:
                goto _flick_abort1091;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return;
    {
    _flick_abort1091:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort1090);
    _flick_abort1090:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return;
}

